<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Call_To_Action extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'call-to-action';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Call To Action', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'call_to_action',
			[
				'label' => __( 'Call To Action', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1'  => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style2'],
				]
			]
		);
		
		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button Url', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'gridvalley-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		
		$this->add_control(
			'section_image',
			[
				'label' => __('Section Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		if($settings['select_style'] == 'style1'){ ?>
			<div class="section-full p-t0 p-b50 get-in-touch-wraper">
				<div class="get-in-touch">
					<div class="row justify-content-between d-flex align-items-center">
						<div class="col-lg-6 col-md-12">
							<div class="get-in-touch-pic">
								<img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="img">
								<!-- Circle Animation Start-->
									<div class='ripple-background'>
										<div class='ls-circle ls-xxlarge ls-shade1'></div>
										<div class='ls-circle ls-xlarge ls-shade2'></div>
										<div class='ls-circle ls-large ls-shade3'></div>
										<div class='ls-circle ls-medium ls-shade4'></div>
										<div class='ls-circle ls-small ls-shade5'></div>
									</div>
								<!-- Circle Animation End-->   
							</div>  
						</div>
						<div class="col-lg-6 col-md-12">
							<div class="get-in-touch-info">
								<h2 class="wt-title"><?php echo esc_attr($settings['title']); ?></h2>
								<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
							</div>
						</div>
					</div>
				</div>
			</div> 
			<?php
		}else if($settings['select_style'] == 'style2'){ 
			
			$custom_css ='.ap-section-outer{background-image: url('.esc_url($settings['section_image']['url']).');}';
					
			wp_enqueue_style('industroz-inline-style',get_template_directory_uri() . '/assets/css/inline-style.css');
			wp_add_inline_style( 'industroz-inline-style', $custom_css);
			?>
			<div class="section-full p-t80 p-b50 bg-center ap-section-outer">
				<div class="container">
					<div class="section-content">
						<div class="ap-section m-b30">
							<h2 class="m-b15 m-b0"><?php echo esc_attr($settings['title']); ?></h2>
							<p class="m-t0 m-b20"><?php echo esc_attr($settings['description']); ?></p>
							<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
	}
}