<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Call_Us extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name(){
		return 'call-us';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Call Us', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'call_us',
			[
				'label' => __( 'Call Us', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		$this->add_control(
			'caption',
			[
				'label' => __( 'Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'info_title', [
				'label' => __( 'Enter Info Title', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Info Title' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'info_description', [
				'label' => __( 'Enter Info Description', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Info Description' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'info_icon', [
				'label' => __( 'Enter Info Icon Class', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Info Icon Class' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);


		$this->add_control(
			'information',
			[
				'label' => __( 'Information', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'info_title' => __( 'Enter Info Title', 'gridvalley-core' ),
					],
				],
				'title_field' => '{{{ info_title }}}',
			]
		);
		
		$this->add_control(
			'person_image',
			[
				'label' => __('Person Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => [ 'style1'],
				]
			]
		);
		$this->add_control(
			'section_image',
			[
				'label' => __('Section Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => [ 'style1'],
				]
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		global $industroz_allowed_html;
		
		if($settings['select_style'] == 'style1'){ ?>
			<div class="section-full self-intro-section-outer overlay-wraper" style="background-image:url(<?php echo esc_url($settings['section_image']['url']); ?>)">                                 
				<div class="overlay-main site-bg-secondry opacity-09"></div>
				<div class="self-intro-top bg-gray p-t80 p-b30">
					<div class="container">
						<div class="row justify-content-end">

							<div class="col-lg-6 col-md-12">
								<!-- TITLE START-->
								<div class="left wt-small-separator-outer">
									<div class="wt-small-separator site-text-primary">
										<div class="sep-leaf-left"></div>
										<div><?php echo esc_attr($settings['caption']); ?></div>
										<div class="sep-leaf-right"></div>
									</div>
									<h2><?php echo esc_attr($settings['title']); ?></h2>
									<p><?php echo esc_attr($settings['description']); ?></p>
								</div>
								<!-- TITLE END-->
							</div>                              

						</div>
					</div>
				</div> 
				<div class="self-intro-bottom p-t80 p-b70">
					<div class="container">
						<div class="row justify-content-end">
							<div class="col-lg-6 col-md-6">
								<div class="self-info-detail">
									<?php
									foreach($settings['information'] as $index => $info){
										?>
										<div class="wt-icon-box-wraper p-b10 left">
											<div class="icon-md m-b20">
												<span class="icon-cell site-text-primary"><i class="<?php echo esc_attr($info['info_icon']); ?>"></i></span>
											</div>
											<div class="icon-content text-white">
												<h3 class="wt-tilte"><?php echo esc_attr($info['info_title']); ?></h3>
												<?php echo wp_kses($info['info_description'],$industroz_allowed_html); ?>
											</div>
										</div>
										<?php
									} ?>
								</div>
							</div>
						</div>
					</div>
				</div>  
				<div class="container">
					<div class="self-intro-pic-block">
						<div class="wt-media"><img src="<?php echo esc_url($settings['person_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>"></div>
					</div>
				</div>

			</div>	
			<?php
		}else{ ?>
			<div class="section-full p-t80 p-b50">
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer text-center">
					<div class="wt-small-separator site-text-primary">
						<div class="sep-leaf-left"></div>
						<div><?php echo esc_attr($settings['caption']); ?></div>
						<div class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['title']); ?></h2>
				</div>
				<!-- TITLE END-->
				<div class="section-content">
					<div class="icon-circle-box-outer bg-white p-a30 m-b30">
						<div class="row justify-content-center ">
							<?php
							$custom_counter = 1;
							foreach($settings['information'] as $index => $info){
								?>
								<div class="col-lg-4 col-md-6 col-sm-12 ">
									<div class="icon-circle-box v-icon-effect">
										<div class="wt-icon-box-wraper center">
											<div class="icon-md icon-circle">
												<span class="icon-cell">
													<i class="<?php echo esc_attr($info['info_icon']); ?> v-icon "></i>
												</span>
											</div>
											<div class="icon-content relative">
												<h4 class="wt-tilte"><?php echo esc_attr($info['info_title']); ?></h4>
												<span class="icon-count-number"><?php echo esc_attr($custom_counter); ?></span>
												<p><?php echo wp_kses($info['info_description'],$industroz_allowed_html); ?></p>
											</div>
										</div>
									</div>                          
								</div>
								<?php
								$custom_counter++;
							} ?>
						</div>                          
					</div>                                                            
				</div>
            </div>
			<?php
		} ?>
		<?php
	}
}