<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Facts extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'facts';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Facts', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'facts',
			[
				'label' => __( 'Facts', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1'  => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => 'style2',
				]
			]
		);
		$this->add_control(
			'caption',
			[
				'label' => __( 'Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => 'style2',
				]
			]
		);
		$this->add_control(
			'section_image',
			[
				'label' => __('Section Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => 'style2',
				]
			]
		);
		
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'title',
			[
				'label' => __( 'Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$repeater->add_control(
			'value',
			[
				'label' => __( 'Value', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'project_facts',
			[
				'label' => __( 'Facts List', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'title' => __( 'Enter Title', 'gridvalley-core' ),
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);
		
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();	
		
		if($settings['select_style'] == 'style1'){ ?>
			<!-- OUR PLAN US START -->
			<div class="section-full p-t70 p-b30">
				<div class="counter2-section-outer-bottom"> 
					<div class="counter-outer">
						<div class="row justify-content-center">
							<?php
							$custom_counter = 0;
							foreach($settings['project_facts'] as $index => $fact_item){
								$tab_title_setting_key = $this->get_repeater_setting_key( 'title', 'project_facts', $index );
								$this->add_inline_editing_attributes( $tab_title_setting_key, 'none' );
								
								$tab_value_setting_key = $this->get_repeater_setting_key( 'value', 'project_facts', $index );
								$this->add_inline_editing_attributes( $tab_value_setting_key, 'none' );
								?>    
								<div class="col-lg-3 col-md-6 col-sm-6 m-b30 ">
									<div class="wt-icon-box-wraper center">
										<h2 class="counter site-text-primary"><span <?php echo $this->get_render_attribute_string( $tab_value_setting_key ); ?>><?php echo esc_attr($fact_item['value']); ?></span></h2>
										<span class="site-text-secondry title-style-2"><span <?php echo $this->get_render_attribute_string( $tab_title_setting_key ); ?>><?php echo esc_attr($fact_item['title']); ?></span></span>
									</div>
								</div>
								<?php
							} ?>
						</div>
					</div>   
				</div>    
			</div>
			<?php
		}else if($settings['select_style'] == 'style2'){ ?>
			<div class="section-full p-t80 p-b40  overlay-wraper bg-cover bg-no-repeat bg-parallax" data-stellar-background-ratio="0.5" style="background-image:url(<?php echo esc_url($settings['section_image']['url']); ?>);">
				<div class="overlay-main site-bg-secondry opacity-09"></div>                                       
				<div class="container">
					<!-- TITLE START-->
					<div class="section-head center wt-small-separator-outer text-center text-white">
						<div class="wt-small-separator site-text-primary">
							<div  class="sep-leaf-left"></div>
							<div><?php echo esc_attr($settings['caption']); ?></div>
							<div  class="sep-leaf-right"></div>
						</div>
						<h2><?php echo esc_attr($settings['title']); ?></h2>
					</div>
					<!-- TITLE END--> 

					<div class="counter3-section-outer-top">
						<div class="counter-outer">                            
							
							<div class="row justify-content-center">
								<?php
								$custom_counter = 0;
								foreach($settings['project_facts'] as $index => $fact_item){
									$tab_title_setting_key = $this->get_repeater_setting_key( 'title', 'project_facts', $index );
									$this->add_inline_editing_attributes( $tab_title_setting_key, 'none' );
									
									$tab_value_setting_key = $this->get_repeater_setting_key( 'value', 'project_facts', $index );
									$this->add_inline_editing_attributes( $tab_value_setting_key, 'none' );
									?>    
									<div class="col-lg-3 col-md-6 col-sm-6 m-b30 ">
										<div class="wt-icon-box-wraper center">
											<h2 class="counter site-text-primary"><span <?php echo $this->get_render_attribute_string( $tab_value_setting_key ); ?>><?php echo esc_attr($fact_item['value']); ?></span></h2>
											<span class="site-text-white title-style-2"><span <?php echo $this->get_render_attribute_string( $tab_title_setting_key ); ?>><?php echo esc_attr($fact_item['title']); ?></span></span>
										</div>
									</div>
									<?php
								} ?>
							</div>
						</div>   
					</div>	
			   </div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style3'){ ?>
			
			<?php
		}
		?>
		<?php
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		?>
		<#
		if ( 'style1' === settings.select_style) { #>
			<div class="section-full p-t80 p-b40">
				<div class="counter2-section-outer-bottom"> 
					<div class="counter-outer">
						<div class="row justify-content-center">
							<#
							if ( settings.project_facts ) {
								_.each( settings.project_facts, function( item, index ) {
									#>    
									<div class="col-lg-3 col-md-6 col-sm-6 m-b30 ">
										<div class="wt-icon-box-wraper center">
											<h2 class="counter site-text-primary"><span>{{{ item.value }}}</span></h2>
											<span class="site-text-secondry title-style-2"><span>{{{ item.title }}}</span></span>
										</div>
									</div>
								<#
								});
							} #>
						</div>
					</div>   
				</div>
			</div>
			<#
		}else{ #>
			<div class="section-full p-t80 p-b40  overlay-wraper bg-cover bg-no-repeat bg-parallax" data-stellar-background-ratio="0.5" style="background-image:url({{{ settings.section_image.url }}});">
				<div class="overlay-main site-bg-secondry opacity-09"></div>                                       
				<div class="container">
					<!-- TITLE START-->
					<div class="section-head center wt-small-separator-outer text-center text-white">
						<div class="wt-small-separator site-text-primary">
							<div  class="sep-leaf-left"></div>
							<div>{{{ settings.caption }}}</div>
							<div  class="sep-leaf-right"></div>
						</div>
						<h2>{{{ settings.title }}}</h2>
					</div>
					<!-- TITLE END--> 

					<div class="counter3-section-outer-top">
						<div class="counter-outer">
							<div class="row justify-content-center">
								<#
								if ( settings.project_facts ) {
									_.each( settings.project_facts, function( item, index ) {
										#>    
										<div class="col-lg-3 col-md-6 col-sm-6 m-b30 ">
											<div class="wt-icon-box-wraper center">
												<h2 class="counter site-text-primary"><span>{{{ item.value }}}</span></h2>
												<span class="site-text-white title-style-2"><span>{{{ item.title }}}</span></span>
											</div>
										</div>
									<#
									});
								} #>
							</div>
						</div>   
					</div>	
			   </div>
			</div>
			<#
		} #>
		<?php
	}
}