<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Info_Section extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'info-section';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Info Section', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'info_section',
			[
				'label' => __( 'Info Section', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
					'style3' => __( 'Style 3', 'gridvalley-core' ),
					'style4' => __( 'Style 4', 'gridvalley-core' ),
					'style5' => __( 'Style 5', 'gridvalley-core' ),
					'style6' => __( 'Style 6', 'gridvalley-core' ),
					'style7' => __( 'Style 7', 'gridvalley-core' ),
					'style8' => __( 'Style 8', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'element_title',
			[
				'label' => __( 'Element Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		$this->add_control(
			'element_caption',
			[
				'label' => __( 'Element Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'video_url',
			[
				'label' => __( 'Video Url', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'gridvalley-core' ),
				'show_external' => false,
				'default' => [
					'url' => '',
				],
			]
		);
		
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'fact_title', [
				'label' => __( 'Fact Title', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Fact Title' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'fact_value', [
				'label' => __( 'Enter Fact Value', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => __( 'Fact Value' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);
		

		$this->add_control(
			'facts',
			[
				'label' => __( 'Facts', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'fact_title' => __( 'Enter Fact Title', 'gridvalley-core' ),
					],
				],
				'title_field' => '{{{ fact_title }}}',
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style5', 'style6', 'style7', 'style8'],
				]
			]
		);
		
		$this->add_control(
			'quote',
			[
				'label' => __( 'Quote', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		
		
		$this->add_control(
			'quote_by',
			[
				'label' => __( 'Quote By', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3', 'style4', 'style5', 'style6'],
				]
			]
		);
		
		$this->add_control(
			'info_title',
			[
				'label' => __('Info Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3'],
				]
			]
		);
		
		$this->add_control(
			'info_description',
			[
				'label' => __('Info Description', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3', 'style4'],
				]
			]
		);
		
		$this->add_control(
			'info_button_text',
			[
				'label' => __('Info Button Text', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3'],
				]
			]
		);
		
		$this->add_control(
			'info_button_url',
			[
				'label' => __( 'Info Button Url', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'gridvalley-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3'],
				]
			]
		);
		
		$this->add_control(
			'video_poster_image',
			[
				'label' => __('Video Poster Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => ['style6','style8'],
				]
			]
		);
		
		$this->add_control(
			'contact_form',
			[
				'label' => __('Contact Form Shortcode', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'description' => __( 'Enter contact form 7 shortcode from here. You can get it from Contact/Contact Forms. Leave blank to hide this.', 'gridvalley-core' ),
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => 'style4',
				]
			]
		);
		
		$this->add_control(
			'section_image',
			[
				'label' => __('Section Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => [ 'style1', 'style3', 'style4', 'style5', 'style6', 'style7'],
				]
			]
		);
		
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		if($settings['select_style'] == 'style1'){ ?>
			<!-- VIDEO SECTION START -->
			<div class="section-full video-counter-section bg-white"> 
				<div class="video-counter-bg-white"> 
					<div class="container">
						<!-- TITLE START-->
						<div class="section-head center wt-small-separator-outer text-center">
							<div class="wt-small-separator site-text-primary">
								<div  class="sep-leaf-left"></div>
								<div><?php echo esc_attr($settings['element_caption']); ?></div>
								<div  class="sep-leaf-right"></div>
							</div>
							<h2><?php echo esc_attr($settings['element_title']); ?></h2>
						</div>
						<!-- TITLE END--> 
					</div>
				 </div>
				 
				<div class="video-counter-bg-image overlay-wraper bg-cover bg-no-repeat" style="background-image:url(<?php echo esc_url($settings['section_image']['url']); ?>);">
					<div class="overlay-main site-bg-secondry opacity-09"></div>

					<div class="video-section-outer mfp-gallery">
						<div class="video-section">
							 <a href="<?php echo esc_url($settings['video_url']['url']); ?>" class="mfp-video play-now">
								<i class="icon fa fa-play"></i>
								<span class="ripple"></span>
							</a>                                              
						</div>	    
					</div>
					<div class="container">
						<div class="counter-section-outer-top">
							<div class="counter-outer">   
								<div class="row justify-content-center">
									<?php
									foreach($settings['facts'] as $index => $fact_item){
										?>
										<div class="col-lg-4 col-md-4 m-b30 ">
											<div class="wt-icon-box-wraper center">
												<h2 class="counter site-text-primary"><?php echo esc_attr($fact_item['fact_value']); ?></h2>
												<span class="site-text-white title-style-2"><?php echo esc_attr($fact_item['fact_title']); ?></span>
											</div>
										</div>
										<?php
									} ?>
								</div>
							</div>   
						</div>
						<div class="counter-section-outer-bottom">
								<div class="row justify-content-center">
									<div class="col-lg-5 col-md-6 m-b30 ">
										<div class="video-section-info site-bg-primary site-text-white">
											<h3 class="wt-tilte site-text-white"><?php echo esc_attr($settings['info_title']); ?></h3>
											<p><?php echo esc_attr($settings['info_description']); ?></p>
											<a href="<?php echo esc_url($settings['info_button_url']['url']); ?>" class="site-button-link"><?php echo esc_attr($settings['info_button_text']); ?></a>
										</div>
									</div>
									
									<div class="col-lg-7 col-md-6 m-b30">
										<div class="video-section-blockquote">
											<i class="fa fa-quote-left"></i>
											<span class="q-author-detail site-text-white title-style-2"><?php echo esc_attr($settings['quote']); ?></span>
											<div class="q-author-name site-text-primary title-style-2"><?php echo esc_attr($settings['quote_by']); ?></div>
										</div>
									</div>
								</div> 
						</div>                                
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style2'){ ?>
			<div class="section-full video2-counter-section p-t80 p-b40">
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer text-center text-white">
					<div class="wt-small-separator site-text-primary">
						<div  class="sep-leaf-left"></div>
						<div><?php echo esc_attr($settings['element_caption']); ?></div>
						<div  class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['element_title']); ?></h2>
				</div>
				<!-- TITLE END--> 

				<div class="counter2-section-outer-top">
					<div class="row justify-content-center">
							
						<div class="col-lg-5 col-md-12 m-b30 ">
							<div class="video2-section-info bg-white site-text-secondry">
								<h3 class="wt-tilte site-text-secondry"><?php echo esc_attr($settings['info_title']); ?></h3>
								<p><?php echo esc_attr($settings['info_description']); ?></p>
								<a href="<?php echo esc_url($settings['info_button_url']['url']); ?>" class="site-button-link"><?php echo esc_attr($settings['info_button_text']); ?></a>
							</div>
						</div>
						<div class="col-lg-7 col-md-12 m-b30">
						
							<div class="video-section2-outer mfp-gallery">
								<div class="video-section">
									 <a href="<?php echo esc_url($settings['video_url']['url']); ?>" class="mfp-video play-now">
										<i class="icon fa fa-play"></i>
										<span class="ripple"></span>
									</a>                                              
								</div>	    
							</div>                                            
							<div class="video-section-blockquote">
								<i class="fa fa-quote-left"></i>
								<span class="q-author-detail site-text-white title-style-2"><?php echo esc_attr($settings['quote']); ?></span>
								<div class="q-author-name site-text-primary title-style-2"><?php echo esc_attr($settings['quote_by']); ?></div>
							</div>
						</div>
					</div>
				</div>
				<div class="counter2-section-outer-bottom">
					<div class="counter-outer">
						<div class="row justify-content-center">
							<?php
							foreach($settings['facts'] as $index => $fact_item){
								?>	
								<div class="col-lg-3 col-md-6 col-sm-6 m-b30 ">
									<div class="wt-icon-box-wraper center">
										<h2 class="counter site-text-primary"><?php echo esc_attr($fact_item['fact_value']); ?></h2>
										<span class="site-text-white title-style-2"><?php echo esc_attr($fact_item['fact_title']); ?></span>
									</div>
								</div>
								<?php
							} ?>
						</div>
					</div>   
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style3'){ ?>
			<div class="section-full video2-counter-section p-t80 p-b40  overlay-wraper bg-cover bg-no-repeat bg-parallax" data-stellar-background-ratio="0.5" style="background-image:url(<?php echo esc_url($settings['section_image']['url']) ?>);">
				<div class="overlay-main bg-black opacity-04"></div>                                       

				<div class="container">
					<!-- TITLE START-->
					<div class="section-head center wt-small-separator-outer text-center text-white">
						<div class="wt-small-separator site-text-primary">
							<div  class="sep-leaf-left"></div>
							<div><?php echo esc_attr($settings['element_caption']); ?></div>
							<div  class="sep-leaf-right"></div>
						</div>
						<h2><?php echo esc_attr($settings['element_title']); ?></h2>
					</div>
					<!-- TITLE END--> 
					<div class="counter2-section-outer-top">
						<div class="row justify-content-center">
							<div class="col-lg-5 col-md-12 m-b30 ">
								<div class="video2-section-info site-bg-secondry site-text-white">
									<h3 class="wt-tilte site-text-primary"><?php echo esc_attr($settings['info_title']); ?></h3>
									<p><?php echo esc_attr($settings['info_description']); ?></p>
									<a href="<?php echo esc_url($settings['info_button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['info_button_text']); ?></a>
								</div>
							</div>
							<div class="col-lg-7 col-md-12 m-b30">
								<div class="video-section2-outer mfp-gallery">
									<div class="video-section">
										 <a href="<?php echo esc_url($settings['video_url']['url']); ?>" class="mfp-video play-now">
											<i class="icon fa fa-play"></i>
											<span class="ripple"></span>
										</a>                                              
									</div>	    
								</div>                                            
								<div class="video-section-blockquote2">
									<i class="fa fa-quote-left"></i>
									<span class="q-author-detail site-text-white title-style-2"><?php echo esc_attr($settings['quote']); ?></span>
									<div class="q-author-name site-text-primary title-style-2"><?php echo esc_attr($settings['quote_by']); ?></div>
								</div>
							</div>
						</div> 
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style4'){ ?>
			<div class="section-full  p-t80 p-b50 bg-white  bg-bottom-right bg-no-repeat" style="background-image:url(<?php echo esc_url($settings['section_image']['url']) ?>)">
                <div class="container">
                    <div class="row d-flex justify-content-center">
                        <div class="col-lg-6 col-md-12 m-b30">
                            <!-- TITLE START-->
                            <div class="left wt-small-separator-outer">
                                <div class="wt-small-separator site-text-primary">
                                    <div  class="sep-leaf-left"></div>
                                    <div><?php echo esc_attr($settings['element_caption']); ?></div>
                                    <div  class="sep-leaf-right"></div>
                                </div>
                                <h2><?php echo esc_attr($settings['element_title']); ?></h2>
                                <p><?php echo esc_attr($settings['info_description']); ?></p>
                            </div>
                            <!-- TITLE END-->
                            <div class="video-3-section-outer-bottom">
                                <div class="video-section2-outer mfp-gallery">
                                    <div class="video-section">
                                         <a href="<?php echo esc_url($settings['video_url']['url']); ?>" class="mfp-video play-now">
                                            <i class="icon fa fa-play"></i>
                                            <span class="ripple"></span>
                                        </a>                                              
                                    </div>	    
                                </div> 
                                <div class="video3-section-blockquote">
                                    <i class="fa fa-quote-left"></i>
                                    <span class="q-author-detail site-text-secondry title-style-2"><?php echo esc_attr($settings['quote']); ?></span>
                                    <div class="q-author-name site-text-primary title-style-2"><?php echo esc_attr($settings['quote_by']); ?></div>
                                </div>
                            </div>                                                                                  
                        </div>
                        <div class="col-lg-6 col-md-12 m-b30">
                             <div class="home-contact-section site-bg-primary p-a40">
                                <?php echo do_shortcode($settings['contact_form']); ?>                                       
                            </div>
                        </div>
                   </div>
				</div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style5'){ ?>
			<div class="section-full video2-counter-section p-t80 p-b40  overlay-wraper bg-cover bg-no-repeat" style="background-image:url(<?php echo esc_url($settings['section_image']['url']) ?>);">
				<div class="overlay-main site-bg-secondry opacity-09"></div>                                       
				<div class="container">
					<!-- TITLE START-->
					<div class="section-head center wt-small-separator-outer text-center text-white">
						<div class="wt-small-separator site-text-primary">
							<div  class="sep-leaf-left"></div>
							<div><?php echo esc_attr($settings['element_caption']); ?></div>
							<div  class="sep-leaf-right"></div>
						</div>
						<h2><?php echo esc_attr($settings['element_title']); ?></h2>
					</div>
					<!-- TITLE END--> 

					<div class="counter2-section-outer-top">
						<div class="counter-outer">                            
							
							<div class="row justify-content-center">
								<?php
								foreach($settings['facts'] as $index => $fact_item){
									?>	
									<div class="col-lg-3 col-md-6 m-b30 ">
										<div class="wt-icon-box-wraper center">
											<h2 class="counter site-text-primary"><?php echo esc_attr($fact_item['fact_value']); ?></h2>
											<span class="site-text-white title-style-2"><?php echo esc_attr($fact_item['fact_title']); ?></span>
										</div>
									</div>
									<?php
								} ?>
							</div>
						</div>   
					</div> 
					<?php 
					if($settings['quote'] <> '' && $settings['video_url']['url'] <> ''){ ?>
						<div class="counter2-section-outer-bottom">
							<div class="row justify-content-center">
								<div class="col-lg-4 col-md-6 m-b30 ">
									<div class="video-section2-outer mfp-gallery">
										<div class="video-section">
											<a href="<?php echo esc_url($settings['video_url']['url']); ?>" class="mfp-video play-now">
												<i class="icon fa fa-play"></i>
												<span class="ripple"></span>
											</a>                                              
										</div>	    
									</div>      
								</div>
								<div class="col-lg-8 col-md-6 m-b30">
									<div class="video-section-blockquote">
										<i class="fa fa-quote-left"></i>
										<span class="q-author-detail site-text-white title-style-2"><?php echo esc_attr($settings['quote']); ?></span>
										<div class="q-author-name site-text-primary title-style-2"><?php echo esc_attr($settings['quote_by']); ?></div>
									</div>
								</div>
							</div>                            
						</div>
						<?php
					} ?>	
			   </div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style6'){ ?>
			<!-- VIDEO SECTION START -->
            <div class="section-full video3-counter-section p-t80 bg-gray-light">
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer text-center">
					<div class="wt-small-separator site-text-primary">
						<div  class="sep-leaf-left"></div>
						<div><?php echo esc_attr($settings['element_caption']); ?></div>
						<div  class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['element_title']); ?></h2>
				</div>
				<!-- TITLE END-->
				<div class="counter3-section-outer-top">
					<div class="row justify-content-center">
						<div class="col-lg-4 col-md-5  col-sm-6 col-6">
							<div class="video3-left-section">
								<div class="wt-media"><img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>"></div>
							</div>
						</div>
						<div class="col-lg-8 col-md-12">
							<div class="video-section-new-outer mfp-gallery">
								<div class="video-section">
									<img src="<?php echo esc_url($settings['video_poster_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
									 <a href="<?php echo esc_url($settings['video_url']['url']); ?>" class="mfp-video play-now">
										<i class="icon fa fa-play"></i>
										<span class="ripple"></span>
									</a>
								</div>  
							</div>
							<div class="counter3-outer">
								<div class="row justify-content-center">
									<?php
									foreach($settings['facts'] as $index => $fact_item){
										?>	
										<div class="col-lg-4 col-md-4 col-sm-6 m-b30 ">
											<div class="wt-icon-box-wraper center">
												<h2 class="counter site-text-primary"><?php echo esc_attr($fact_item['fact_value']); ?></h2>
												<span class="site-text-secondry title-style-2"><?php echo esc_attr($fact_item['fact_title']); ?></span>
											</div>
										</div>
										<?php
									} ?>
								</div>
							</div>
						</div>
					</div>
				</div> 
			</div>
            <!-- VIDEO  SECTION END --> 
			<?php
		}else if($settings['select_style'] == 'style7'){ ?>
			<!-- QUALITY SECTION START -->
            <div class="section-full p-t80 overlay-wraper bg-top-center bg-center" style="background-image:url(<?php echo esc_url($settings['section_image']['url']); ?>)">
                <div class="overlay-main bg-black opacity-01"></div>
                <div class="container">
                    <!-- TITLE START-->
                    <div class="section-head center wt-small-separator-outer text-center text-white">
                        <div class="wt-small-separator site-text-white">
                            <div  class="sep-leaf-left"></div>
                            <div><?php echo esc_attr($settings['element_caption']); ?></div>
                            <div  class="sep-leaf-right"></div>
                        </div>
                        <h2><?php echo esc_attr($settings['element_title']); ?></h2>
                    </div>
                    <!-- TITLE END-->
                </div>    
                <div class="section-content quality-section-outer bg-gray-light" style="background-image:url(<?php echo esc_url(get_template_directory_uri()); ?>/assets/images/bg-map.png)">
                    <div class="container">
                        <div class="quality-section-content">
                            <div class="counter-outer">
                                <div class="row justify-content-center">
                                    <?php
									foreach($settings['facts'] as $index => $fact_item){
										?>
										<div class="col-lg-3 col-md-6 col-sm-6 m-b30 ">
											<div class="wt-icon-box-wraper center bg-gray-light p-a20">
												<h2 class="counter site-text-primary m-b0"><?php echo esc_attr($fact_item['fact_value']); ?></h2>
												<span class="site-text-secondry title-style-2"><?php echo esc_attr($fact_item['fact_title']); ?></span>
											</div>
										</div>
										<?php
									} ?>  
                                </div>
                            </div>
                        </div>
                        <div class="quality-video-section">
                            <span><?php echo esc_attr($settings['quote']); ?></span>
                            <div class="quality-video">
                                <a href="<?php echo esc_url($settings['video_url']['url']); ?>" class="mfp-video play-now">
                                    <i class="icon fa fa-play"></i>
                                    <span class="ripple"></span>
                                </a>                                  
                            </div>
                        </div>
                    </div>
                </div>      
            </div> 
			<?php
		}else if($settings['select_style'] == 'style8'){ ?>
			<!-- QUALITY SECTION START -->
            <div class="section-full p-t80">
                <div class="container">
                    <!-- TITLE START-->
                    <div class="section-head center wt-small-separator-outer text-center">
                        <div class="wt-small-separator site-text-primary">
                            <div  class="sep-leaf-left"></div>
                            <div><?php echo esc_attr($settings['element_caption']); ?></div>
                            <div  class="sep-leaf-right"></div>
                        </div>
                        <h2><?php echo esc_attr($settings['element_title']); ?></h2>
                    </div>
                    <!-- TITLE END-->
                </div>  
                            
                <div class="section-content quality-section-outer bg-gray-light">
                    <div class="container">
                        <div class="quality-section-content">
                            <div class="counter-outer">
                                <div class="row justify-content-center">
									<?php
									foreach($settings['facts'] as $index => $fact_item){
										?>
										<div class="col-lg-3 col-md-6 col-sm-6 m-b30 ">
											<div class="wt-icon-box-wraper center bg-gray-light p-a20">
												<h2 class="counter site-text-primary m-b0"><?php echo esc_attr($fact_item['fact_value']); ?></h2>
												<span class="site-text-secondry title-style-2"><?php echo esc_attr($fact_item['fact_title']); ?></span>
											</div>
										</div>
										<?php
									} ?> 
                                </div>
                            </div>
                        </div>
                        <div class="quality-video2-section p-t20 p-b80">
                            <div class="quality-video2">
                                <img src="<?php echo esc_url($settings['video_poster_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
                                <a href="<?php echo esc_url($settings['video_url']['url']); ?>" class="mfp-video play-now">
                                    <i class="icon fa fa-play"></i>
                                    <span class="ripple"></span>
                                </a>                                  
                            </div>
                        </div>
                    </div>
                </div>      
            </div>   
            <!-- QUALITY SECTION END --> 
			<?php
		}
	}
}