<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class News_Section extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'news-section';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'News Section', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'news_section',
			[
				'label' => __( 'News Section', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
					'style3' => __( 'Style 3', 'gridvalley-core' ),
					'style4' => __( 'Style 4', 'gridvalley-core' ),
					'style5' => __( 'Style 5', 'gridvalley-core' ),
					'style6' => __( 'Style 6', 'gridvalley-core' ),
					'style7' => __( 'Style 7', 'gridvalley-core' ),
					'style8' => __( 'Style 8', 'gridvalley-core' ),
					'style9' => __( 'Style 9', 'gridvalley-core' ),
					'style10' => __( 'Style 10', 'gridvalley-core' ),
					'style11' => __( 'Style 11', 'gridvalley-core' ),
				],
			]
		);
		
		$post_categories = get_terms( array(
			'taxonomy' => 'category',
			'hide_empty' => false
		) );
		$options = [];
		foreach ( $post_categories as $category ) {
			$options[ $category->term_id ] = $category->name;
		}

		$this->add_control(
			'post_categories',
			[
				'label' => __( 'Categories', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT2,
				'options' => $options,
				'default' => [],
				'label_block' => true,
				'multiple' => true,
			]
		);
		
		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Posts Per Page', 'gridvalley-core' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 6,
			]
		);
		
		$this->add_control(
			'orderby',
			[
				'label' => __( 'Order By', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'name',
				'options' => [
					'title' => __( 'Title', 'gridvalley-core' ),
					'name' => __( 'Name', 'gridvalley-core' ),
					'date' => __( 'Date', 'gridvalley-core' ),
					'comment_count' => __( 'Comment Count', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'order',
			[
				'label' => __( 'Order', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'asc' => __( 'ASC', 'gridvalley-core' ),
					'desc' => __( 'DESC', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'title_characters',
			[
				'label' => __( 'Title Characters to Fetch', 'gridvalley-core' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 50,
			]
		);
		
		$this->add_control(
			'description_characters',
			[
				'label' => __( 'Description Characters to Fetch', 'gridvalley-core' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 50,
			]
		);
		
		$this->add_control(
			'pagination',
			[
				'label' => __( 'Show Pagination', 'gridvalley-core' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_off' => __( 'Off', 'gridvalley-core' ),
				'label_on' => __( 'On', 'gridvalley-core' ),
				'condition' => [
					'select_style' => ['style1', 'style3', 'style4', 'style5'],
				]
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		$this->add_control(
			'caption',
			[
				'label' => __( 'Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button Url', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'gridvalley-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		
		$paged = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;

		$args = array(
			'post_type' => 'post',
			'posts_per_page' => $settings['posts_per_page'],
			'orderby' => $settings['orderby'],
			'order' => $settings['order'],
			'paged' => $paged,
			'tax_query' => array(
				array(
					'taxonomy' => 'category',
					'field'    => 'post_id',
					'terms'    => $settings['post_categories'],
				),
			)
		);
		
		$the_query = new \WP_Query($args);
		if($settings['select_style'] == 'style1'){ ?>
			<div class="section-full  p-t80 blog-post-outer-3 ">
				<div class="container">
					<?php
					if($settings['title'] <> ''){ ?>
						<div class="wt-separator-two-part">
							<div class="row wt-separator-two-part-row">
								<div class="col-lg-8 col-md-7 wt-separator-two-part-left">
									<!-- TITLE START-->
									<div class="section-head left wt-small-separator-outer">
										<div class="wt-small-separator site-text-primary">
											<div class="sep-leaf-left"></div>
											<div><?php echo esc_attr($settings['caption']); ?></div>
											<div class="sep-leaf-right"></div>
										</div>
										<h2><?php echo esc_attr($settings['title']); ?></h2>
									</div>
									<!-- TITLE END-->
								</div>
								<div class="col-lg-4 col-md-5 wt-separator-two-part-right text-right">
									<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
								</div>
							</div>
						</div>	
						<?php
					} ?>
					
					<!-- BLOG SECTION START -->
					<div class="section-content">
						<div class="row d-flex justify-content-center">
							<?php
							$current_size = 1;
							while($the_query->have_posts()){ 
								$the_query->the_post();
								global $post;
								$comment_count = wp_count_comments( $post->ID );
								$comment_count = $comment_count->total_comments;
								if($comment_count == 1){
									$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
								}else{
									$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
								}
								$post_categories = wp_get_post_categories( $post->ID );
								
								?>
								<div class="col-lg-4 col-md-6 col-sm-12">
									<!--Block one-->
									<div class="blog-post industroz-blog-grid style1 date-style-2">
										<div class="wt-post-media wt-img-effect zoom-slow">
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>">
												<?php echo get_the_post_thumbnail($post->ID,'full'); ?>
											</a>
										</div>
										<div class="wt-post-info p-t30">
											<div class="wt-post-meta ">
												<ul>
													<?php 
													if(isset($post_categories) && $post_categories <> ''){
														foreach($post_categories as $c){
															$cat = get_category( $c ); ?>
															<li class="post-category"><a href="<?php echo esc_url(get_term_link($c)); ?>"><span><?php echo esc_attr($cat->name); ?></span></a> </li>
															<?php
															break;
														}
													} ?>
													<li class="post-date"><?php echo esc_attr(get_the_date(get_option('date_format'))); ?></li>
													<li class="post-comment"><?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?></li>
												</ul>
											</div>                                 
											<div class="wt-post-title ">
												<h4 class="post-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(substr(get_the_title($post->ID),0,$settings['title_characters'])); ?></a></h4>
												<p><?php echo esc_attr(strip_tags(get_the_excerpt($post->ID))); ?></p>
											</div>
											<div class="wt-post-readmore ">
												<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link black"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
											</div>                                        
										</div>                                
									</div>
								</div>
								<?php
							} ?>
						</div>
						<?php 
						if($settings['pagination'] == 'yes'){
							echo industroz_pagination($the_query);
						} ?>
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style2'){ ?>
			<div class="section-full  p-t80 p-b50 blog-post-outer-2">
				<?php
				if($settings['title'] <> ''){ ?>
					<div class="wt-separator-two-part">
						<div class="row wt-separator-two-part-row d-flex justify-content-center">
							<div class="col-lg-8 col-md-7 wt-separator-two-part-left">
								<!-- TITLE START-->
								<div class="section-head left wt-small-separator-outer">
									<div class="wt-small-separator site-text-primary">
										<div class="sep-leaf-left"></div>
										<div><?php echo esc_attr($settings['caption']); ?></div>
										<div class="sep-leaf-right"></div>
									</div>
									<h2><?php echo esc_attr($settings['title']); ?></h2>
								</div>
								<!-- TITLE END-->
							</div>
							<div class="col-lg-4 col-md-5 wt-separator-two-part-right text-right">
								<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
							</div>
						</div>
					</div>
					<?php
				} ?>
				<!-- BLOG SECTION START -->
				<div class="section-content">
					<div class="row d-flex justify-content-center">
						<?php
						while($the_query->have_posts()){ 
								$the_query->the_post();
								global $post;
							$comment_count = wp_count_comments( $post->ID );
							$comment_count = $comment_count->total_comments;
							if($comment_count == 1){
								$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
							}else{
								$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
							}
							$post_categories = wp_get_post_categories( $post->ID );
							
							?>
							<div class="col-lg-6 col-md-12 col-sm-12">
								<!--Block one-->
								<div class="blog-post date-style-2 industroz-blog-modern">
									<div class="wt-post-media wt-img-effect zoom-slow">
										<a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo get_the_post_thumbnail($post->ID,'full'); ?></a>
									</div>
									<div class="wt-post-info bg-white p-t30">
										<div class="wt-post-meta ">
											<ul>
												<?php 
												if(isset($post_categories) && $post_categories <> ''){
													foreach($post_categories as $c){
														$cat = get_category( $c ); ?>
														<li class="post-category"><span><?php echo esc_attr($cat->name); ?></span> </li>
														<?php
														break;
													}
												} ?>
												<li class="post-date"><?php echo esc_attr(get_the_date(get_option('date_format'))); ?></li>
												<li class="post-comment"><?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?></li>
											</ul>
										</div>                                 
										<div class="wt-post-title ">
											<h4 class="post-title"><?php echo esc_attr(get_the_title($post->ID)); ?></h4>
										</div>
										<div class="wt-post-readmore ">
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link black"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
										</div>                                        
								   </div>                                
								</div>
							</div>
							<?php
							break;
						} ?>
						<div class="col-lg-6 col-md-12 col-sm-12">
							<?php
							$current_size = 1;
							while($the_query->have_posts()){
								$the_query->the_post();
								global $post;
								$comment_count = wp_count_comments( $post->ID );
								$comment_count = $comment_count->total_comments;
								if($comment_count == 1){
									$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
								}else{
									$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
								}
								$post_categories = wp_get_post_categories( $post->ID );
								
								 ?>
								<div class="blog-post date-style-2 blog-without-image industroz-blog-modern-right">
									<div class="wt-post-info bg-white">
										<div class="wt-post-meta ">
											<ul>
												<?php 
												if(isset($post_categories) && $post_categories <> ''){
													foreach($post_categories as $c){
														$cat = get_category( $c ); ?>
														<li class="post-category"><span><?php echo esc_attr($cat->name); ?></span> </li>
														<?php
														break;
													}
												} ?>
												<li class="post-date"><?php echo esc_attr(get_the_date(get_option('date_format'))); ?></li>
												<li class="post-comment"><?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?></li>
											</ul>
										</div>                                  
										<div class="wt-post-title ">
											<h4 class="post-title"><?php echo esc_attr(get_the_title($post->ID)); ?></h4>
										</div>
										<div class="wt-post-readmore ">
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link black"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
										</div>
									</div>                                
								</div>
								<?php
								$current_size++;
							} ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style3'){ ?>
			<div class="section-full style-construction p-t80 ">
				<?php
				if($settings['title'] <> ''){ ?>
					<div class="wt-separator-two-part">
						<div class="row wt-separator-two-part-row">
							<div class="col-lg-8 col-md-7 wt-separator-two-part-left">
								<!-- TITLE START-->
								<div class="section-head left wt-small-separator-outer">
									<div class="wt-small-separator site-text-primary">
										<div class="sep-leaf-left"></div>
										<div><?php echo esc_attr($settings['caption']); ?></div>
										<div class="sep-leaf-right"></div>
									</div>
									<h2><?php echo esc_attr($settings['title']); ?></h2>
								</div>
								<!-- TITLE END-->
							</div>
							<div class="col-lg-4 col-md-5 wt-separator-two-part-right text-right">
								<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
							</div>
						</div>
					</div>
					<?php
				} ?>
				<!-- BLOG SECTION START -->
				<div class="section-content">
					<div class="row d-flex justify-content-center">
						<?php
						while($the_query->have_posts()){ 
								$the_query->the_post();
								global $post;
							$comment_count = wp_count_comments( $post->ID );
							$comment_count = $comment_count->total_comments;
							if($comment_count == 1){
								$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
							}else{
								$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
							}
							$post_categories = wp_get_post_categories( $post->ID );
							
							?>
							<div class="col-lg-4 col-md-6 col-sm-12 m-b30">
								<div class="blog-post industroz-blog-grid date-style-2">
									<div class="wt-post-media wt-img-effect zoom-slow">
										<a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo get_the_post_thumbnail($post->ID,'industroz-projects-medium'); ?></a>
									</div>
									<div class="wt-post-info p-t30">
										<div class="wt-post-meta ">
											<ul>
												<?php 
												if(isset($post_categories) && $post_categories <> ''){
													foreach($post_categories as $c){
														$cat = get_category( $c ); ?>
														<li class="post-category"><a href="<?php echo esc_url(get_term_link($c)); ?>"><span><?php echo esc_attr($cat->name); ?></span></a> </li>
														<?php
														break;
													}
												} ?>
												<li class="post-date"><?php echo esc_attr(get_the_date(get_option('date_format'))); ?></li>
												<li class="post-comment"><?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?></li>
											</ul>
										</div>                                 
										<div class="wt-post-title ">
											<h4 class="post-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a></h4>
											<p><?php echo esc_attr(strip_tags(get_the_excerpt($post->ID))); ?></p>
										</div>
										<div class="wt-post-readmore ">
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link black"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
										</div>                                        
									</div>                                
								</div>
							</div>
							<?php
						} ?>
					</div>
					<?php 
					if($settings['pagination'] == 'yes'){
						echo industroz_pagination($the_query);
					} ?>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style4'){ ?>
			<div class="section-full  p-t80  blog-post-outer-3 ">
				<div class="container">
					<?php
					if($settings['title'] <> ''){ ?>
						<div class="wt-separator-two-part">
							<div class="row wt-separator-two-part-row">
								<div class="col-lg-8 col-md-7 wt-separator-two-part-left">
									<!-- TITLE START-->
									<div class="section-head left wt-small-separator-outer">
										<div class="wt-small-separator site-text-primary">
											<div class="sep-leaf-left"></div>
											<div><?php echo esc_attr($settings['caption']); ?></div>
											<div class="sep-leaf-right"></div>
										</div>
										<h2><?php echo esc_attr($settings['title']); ?></h2>
									</div>
									<!-- TITLE END-->
								</div>
								<div class="col-lg-4 col-md-5 wt-separator-two-part-right text-right">
									<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
								</div>
							</div>
						</div>
						<?php
					} ?>
					<!-- BLOG SECTION START -->
					<div class="section-content">
						<div class="row d-flex justify-content-center">
							<?php
							while($the_query->have_posts()){ 
								$the_query->the_post();
								global $post;
								$comment_count = wp_count_comments( $post->ID );
								$comment_count = $comment_count->total_comments;
								if($comment_count == 1){
									$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
								}else{
									$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
								}
								$post_categories = wp_get_post_categories( $post->ID );
								
								?>
								<div class="col-lg-4 col-md-6 col-sm-12 m-b30">
									<!--Block one-->
									<div class="blog-post date-style-2">
										<div class="wt-post-media wt-img-effect zoom-slow">
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo get_the_post_thumbnail($post->ID,'industroz-news-medium'); ?></a>
										</div>
										<div class="wt-post-info bg-white p-t30">
											<div class="wt-post-meta ">
												<ul>
													<li class="post-date"><?php echo esc_attr(get_the_date(get_option('date_format'))); ?></li>
													<li class="post-comment"><?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?></li>
												</ul>
											</div>                                 
											<div class="wt-post-title ">
												<h4 class="post-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a></h4>
												<p><?php echo esc_attr(strip_tags(get_the_excerpt($post->ID))); ?></p>
											</div>
											<div class="wt-post-readmore ">
												<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link black"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
											</div>                                        
									   </div>                                
									</div>
								</div>
								<?php
							} ?>
						</div>
						<?php 
						if($settings['pagination'] == 'yes'){
							echo industroz_pagination($the_query);
						} ?>
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style5'){ ?>
			<div class="news-default-post">
				<?php
				while($the_query->have_posts()){ 
					$the_query->the_post();
					global $post;
					$comment_count = wp_count_comments( $post->ID );
					$comment_count = $comment_count->total_comments;
					if($comment_count == 1){
						$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
					}else{
						$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
					}
					$post_categories = wp_get_post_categories( $post->ID );
					
					?>
					<div class="blog-post date-style-2 blog-full">
						<div class="wt-post-media wt-img-effect zoom-slow">
							<a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo get_the_post_thumbnail($post->ID,'full'); ?></a>
						</div>
						<div class="wt-post-info">
							<div class="wt-post-meta ">
								<ul>
									<li class="post-date"><?php echo esc_attr(get_the_date(get_option('date_format'))); ?></li>
									<li class="post-comment"><?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?></li>                                      
								</ul>
							</div>                                  
							<div class="wt-post-title ">
								<h3 class="post-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-text-secondry"><?php echo esc_attr(get_the_title($post->ID)); ?></a></h3>
								<p class="post-content"><?php echo esc_attr(substr(strip_tags($post->post_content),0,195)); ?>...</p>
							</div>
							<div class="wt-post-readmore ">
								<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button site-btn-effect"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
							</div>                                        
						</div>                                
					</div>
					<?php
				} ?>
				<?php 
				if($settings['pagination'] == 'yes'){
					echo industroz_pagination($the_query);
				} ?>
			</div>	
			<?php
		}else if($settings['select_style'] == 'style6'){ ?>
			<!-- OUR BLOG START -->
            <div class="section-full p-t80 p-b50 ">
				
				<div class="wt-separator-two-part">
					<div class="row wt-separator-two-part-row">
						<div class="col-lg-6 col-md-7 wt-separator-two-part-left">
							<!-- TITLE START-->
							<div class="section-head left wt-small-separator-outer">
								<div class="wt-small-separator site-text-primary">
									<div  class="sep-leaf-left"></div>
									<div><?php echo esc_attr($settings['caption']); ?></div>
									<div  class="sep-leaf-right"></div>
								</div>
								<h2><?php echo esc_attr($settings['title']); ?></h2>
							</div>
							<!-- TITLE END-->
						</div>
						<div class="col-lg-6 col-md-5 wt-separator-two-part-right text-right">
							<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
						</div>
					</div>
				</div>
 
				<!-- BLOG SECTION START -->
				<div class="section-content">
					<div class="row d-flex justify-content-center">
						<?php
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post;
							$comment_count = wp_count_comments( $post->ID );
							$comment_count = $comment_count->total_comments;
							if($comment_count == 1){
								$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
							}else{
								$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
							}
							$post_categories = wp_get_post_categories( $post->ID );
							
							?>
							<div class="col-lg-4 col-md-6 col-sm-12 m-b30">
								<!--Block one-->
								<div class="blog-post date-style-3">
									<div class="wt-post-media wt-img-effect zoom-slow">
										<a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo get_the_post_thumbnail($post->ID,'full'); ?></a>
									</div>
									<div class="wt-post-info bg-white">
										<div class="wt-post-meta ">
											<ul>
												<?php 
												if(isset($post_categories) && $post_categories <> ''){
													foreach($post_categories as $c){
														$cat = get_category( $c ); ?>
														<li class="post-category"><a href="<?php echo esc_url(get_term_link($c)); ?>"><span><?php echo esc_attr($cat->name); ?></span></a> </li>
														<?php
														break;
													}
												} ?>
												<li class="post-author"><?php echo esc_attr(get_the_date(get_option('date_format'))); ?></li>
												<li class="post-comment"><?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?> </li>
											</ul>
										</div>                                 
										<div class="wt-post-title ">
											<h3 class="post-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a></h3>
										</div>
										<div class="wt-post-readmore ">
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link black"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
										</div>                                        
								   </div>                                
								</div>
							</div>
							<?php
						} ?>
					</div>
				</div>
			</div>   
            <!-- OUR BLOG END -->	
			<?php
		}else if($settings['select_style'] == 'style7'){ ?>
			<!-- OUR BLOG START -->
            <div class="related-post">
				<div class="section-head center wt-small-separator-outer text-center">
					<div class="wt-small-separator site-text-primary">
						<div class="sep-leaf-left"></div>
						<div> <?php echo esc_attr($settings['caption']); ?> </div>
						<div class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['title']); ?></h2>
				</div>
				<div class="row justify-content-center">    
					<?php
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post;
							$comment_count = wp_count_comments( $post->ID );
							$comment_count = $comment_count->total_comments;
							if($comment_count == 1){
								$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
							}else{
								$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
							}
							$post_categories = wp_get_post_categories( $post->ID );
							
							?>
							<div class="gv_news_slider col-lg-4 col-md-6 col-sm-12">
								<div class="item">
									<div class="gv_blog_wrap">
										<figure>
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo get_the_post_thumbnail($post->ID,'full'); ?></a>	
										</figure>
										<div class="gv_blog_des_wrap">
											<div class="entry-meta test">
												<div class="byline"><i class="fa fa-user"></i> <?php echo get_the_author_link(); ?>	</div>
												<div class="post-comment">
													<i class="fa fa fa-comments"></i>
													<a href="#"> <?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?> </a>
												</div>
											</div>
											<h3 class="post-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a></h3>
										</div>
									</div>
								</div>
							</div>
							<?php
						} ?>
				</div>
			</div>  
            <!-- OUR BLOG END -->	
			<?php
		}else if($settings['select_style'] == 'style8'){ ?>
			<!-- OUR BLOG START -->
            <div class="section-full  p-t80 p-b50 ">
				<div class="wt-separator-two-part">
					<div class="row wt-separator-two-part-row">
						<div class="col-lg-6 col-md-7 wt-separator-two-part-left">
							<!-- TITLE START-->
							<div class="section-head left wt-small-separator-outer">
								<div class="wt-small-separator site-text-primary">
									<div  class="sep-leaf-left"></div>
									<div><?php echo esc_attr($settings['caption']); ?></div>
									<div  class="sep-leaf-right"></div>
								</div>
								<h2><?php echo esc_attr($settings['title']); ?></h2>
							</div>
							<!-- TITLE END-->
						</div>
						<div class="col-lg-6 col-md-5 wt-separator-two-part-right text-right">
							<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
						</div>
					</div>
				</div>
				<!-- BLOG SECTION START -->
				<div class="section-content">
					<div class="row d-flex justify-content-center">
						<?php
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post;
							$comment_count = wp_count_comments( $post->ID );
							$comment_count = $comment_count->total_comments;
							if($comment_count == 1){
								$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
							}else{
								$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
							}
							$post_categories = wp_get_post_categories( $post->ID );
							$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),'industroz-news-large-grid');
							?>
							<div class="col-lg-6 col-md-6 col-sm-12">
								<!--Block one-->
								<div class="latest-blog-3-pattern">
									<div class="blog-post latest-blog-3 overlay-wraper post-overlay  large-date bg-cover bg-no-repeat bg-top-center" style="background-image:url(<?php echo esc_url($img_src[0]); ?>);">
										<div class="overlay-main opacity-05 bg-black"></div>
										<div class="wt-post-info p-a30 text-white">
											<div class="post-overlay-position">
												<div class="post-content-outer">
													<div class="wt-post-meta ">
														<ul>
															<li class="post-date"><strong><?php echo esc_attr(get_the_date('d')); ?></strong><span><?php echo esc_attr(get_the_date('M Y')); ?></span></li>
															<li class="post-author"><i class="fa fa-user-o"></i><?php echo esc_attr__('By','gridvalley-core'); ?> <a href="#"><?php echo get_the_author_link(); ?></a> </li>
															<li class="post-comment"><i class="fa fa-comments-o"></i> <a href="#"><?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?></a> </li>
														</ul>
													</div>                                    
													<div class="wt-post-title ">
														<h3 class="post-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="text-white text-capitalize"><?php echo esc_attr(get_the_title($post->ID)); ?></a></h3>
													</div>
													<div class="wt-post-readmore ">
														<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link white"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
													</div>
												</div>
											</div>
										</div>
									</div>
								</div>
							</div>
							<?php
						} ?>	
					</div>
				</div>
			</div>   
            <!-- OUR BLOG END -->   	
			<?php
		}else if($settings['select_style'] == 'style9'){ ?>
			<!-- OUR BLOG START -->
            <div class="section-full  p-t80 p-b50 latest-blog-2-wraper">
				<div class="wt-separator-two-part">
					<div class="row wt-separator-two-part-row">
						<div class="col-lg-6 col-md-7 wt-separator-two-part-left">
							<!-- TITLE START-->
							<div class="section-head left wt-small-separator-outer">
								<div class="wt-small-separator site-text-primary">
									<div  class="sep-leaf-left"></div>
									<div><?php echo esc_attr($settings['caption']); ?></div>
									<div  class="sep-leaf-right"></div>
								</div>
								<h2><?php echo esc_attr($settings['title']); ?></h2>
							</div>
							<!-- TITLE END-->
						</div>
						<div class="col-lg-6 col-md-5 wt-separator-two-part-right text-right">
							<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
						</div>
					</div>
				</div>
				<!-- BLOG SECTION START -->
				<div class="section-content">
					<div class="row justify-content-center">
						<?php
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post;
							$comment_count = wp_count_comments( $post->ID );
							$comment_count = $comment_count->total_comments;
							if($comment_count == 1){
								$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
							}else{
								$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
							}
							$post_categories = wp_get_post_categories( $post->ID );
							$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),'full');
							?>
							<div class="col-lg-5 col-md-12">
								 <!--Block one-->
								<div class="latest-blog-3-pattern">
									<div class="blog-post latest-blog-3 overlay-wraper post-overlay  large-date bg-cover bg-no-repeat bg-top-center" style="background-image:url(<?php echo esc_url($img_src[0]); ?>);">
										<div class="overlay-main opacity-05 bg-black"></div>
										<div class="wt-post-info p-a30 text-white">
											<div class="post-overlay-position">
												<div class="post-content-outer">
													<div class="wt-post-meta ">
														<ul>
															<li class="post-date"><strong><?php echo esc_attr(get_the_date('d')); ?></strong><span><?php echo esc_attr(get_the_date('M Y')); ?></span></li>
															<li class="post-author"><i class="fa fa-user-o"></i><?php echo esc_attr__('By','gridvalley-core'); ?> <a href="#"><?php echo get_the_author_link(); ?></a> </li>
															<li class="post-comment"><i class="fa fa-comments-o"></i> <a href="#"><?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?></a> </li>
														</ul>
													</div>                                    
													<div class="wt-post-title ">
														<h3 class="post-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="text-white text-capitalize"><?php echo esc_attr(get_the_title($post->ID)); ?></a></h3>
													</div>
													<div class="wt-post-readmore ">
														<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link white"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
													</div>
												</div>  
								
											</div>
										</div>
									</div>
								</div>
							</div>
							<?php
							break;
						} ?>
						<div class="col-lg-7 col-md-12">
							<div class="row latest-blog-2-outer justify-content-center">
								<?php
								while($the_query->have_posts()){ 
									$the_query->the_post();
									global $post;
									$comment_count = wp_count_comments( $post->ID );
									$comment_count = $comment_count->total_comments;
									if($comment_count == 1){
										$industroz_comment_format = esc_attr__('Comment','gridvalley-core');
									}else{
										$industroz_comment_format = esc_attr__('Comments','gridvalley-core');
									}
									$post_categories = wp_get_post_categories( $post->ID );
									
									?>
									<div class="col-lg-6 col-md-6 col-sm-6">
										<div class="blog-post latest-blog-2 bg-white bdr-1 bdr-solid bdr-gray p-a20">
											<div class="wt-post-info">
												<div class="wt-post-meta ">
													<ul>
														<li class="post-date"><?php echo esc_attr(get_the_date(get_option('date_format'))); ?></li>
														<li class="post-comment"><i class="fa fa-comments-o"></i> <a href="#"><?php echo esc_attr($comment_count); ?> <?php echo esc_attr($industroz_comment_format); ?></a> </li>
													</ul>
												</div>
												<div class="wt-post-title ">
													<h3 class="post-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-text-secondry"><?php echo esc_attr(get_the_title($post->ID)); ?></a></h3>
												</div> 
												<div class="wt-post-text ">
													<p><?php echo esc_attr(strip_tags(get_the_excerpt($post->ID))); ?></p>
												</div>                                                                               
												<div class="wt-post-readmore ">
													<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link black"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
												</div>
											</div>
										</div>
									</div>
									<?php
								} ?>
							</div>
						</div>
					</div>
				</div>
			</div>	
			<?php
		}else if($settings['select_style'] == 'style10'){ ?>
			<!-- OUR BLOG START -->
            <div class="section-full p-t80 p-b80 blog-gallery-block-wrap  overflow-hide">
                <div class="blog-gallery-block-outer">
                    <div class="container">
                        <div class="wt-separator-two-part">
                            <div class="row wt-separator-two-part-row">
                                <div class="col-lg-6 col-md-12 wt-separator-two-part-left">
                                    <!-- TITLE START-->
                                    <div class="section-head left wt-small-separator-outer when-bg-dark">
                                        <div class="wt-small-separator site-text-primary">
                                            <div><?php echo esc_attr($settings['caption']); ?></div>
                                        </div>
                                        <h2 class="wt-title"><?php echo esc_attr($settings['title']); ?></h2>
                                    </div>
                                    <!-- TITLE END-->
                                </div> 
                            </div>
                        </div>
                        <div class="section-content">
                            <div class="blog-gallery-style1">
                                <div class="owl-carousel blog-gallery-one owl-btn-vertical-center ">
									<?php
									while($the_query->have_posts()){ 
										$the_query->the_post();
										global $post; ?>
										<!-- COLUMNS 1 --> 
										<div class="item ">
											<div class="blog-post latest-blog-11  block-shadow">
												<div class="wt-post-media wt-img-effect zoom-slow">
													<a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo get_the_post_thumbnail($post->ID,'industroz-news-vertical'); ?></a>
												</div>
												<div class="wt-post-info  bg-white">
													<div class="wt-post-meta ">
														<ul>
															<li class="post-date"><?php echo esc_attr(get_the_date(get_option('date_format'))); ?></li>
														</ul>
													</div>                                    
													<div class="wt-post-title ">
														<h4 class="post-title"><?php echo esc_attr(get_the_title($post->ID)); ?></h4>
													</div>
													<div class="wt-post-readmore">
														<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link site-text-primary"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
													</div>
												</div>
											</div>
										</div>
										<?php
									} ?>
                                </div>
                            </div>
                        </div>                              
                    </div>
                </div>
            </div>	
			<?php
		}else if($settings['select_style'] == 'style11'){ ?>
			<!-- OUR BLOG START -->
            <div class="section-full  p-t80 p-b50">
				<div class="wt-separator-two-part">
					<div class="row wt-separator-two-part-row">
						<div class="col-lg-8 col-md-7 wt-separator-two-part-left">
							<!-- TITLE START-->
							<div class="section-head left wt-small-separator-outer">
								<div class="wt-small-separator site-text-primary">
									<div><?php echo esc_attr($settings['caption']); ?></div>
								</div>
								<h2><?php echo esc_attr($settings['title']); ?></h2>
							</div>
							<!-- TITLE END-->
						</div>
						<div class="col-lg-4 col-md-5 wt-separator-two-part-right text-right">
							<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
						</div>
					</div>
				</div>

				<!-- BLOG SECTION START -->
				<div class="section-content">
					<div class="row d-flex justify-content-center">
						<?php
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post; ?>
							<div class="col-lg-4 col-md-6 col-sm-12">
								<!--Block one-->
								<div class="blog-post post-style-12">
									<div class="wt-post-media wt-img-effect zoom-slow">
										<a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo get_the_post_thumbnail($post->ID,'full'); ?></a>
									</div>
									<div class="wt-post-info text-center">
										<div class="wt-post-content">
											<div class="wt-post-meta ">
												<ul>
													<li class="post-date"><span><?php echo esc_attr(get_the_date(get_option('date_format'))); ?></span> </li>
													<li class="post-user"> <a href="#"><?php echo esc_attr__('By','gridvalley-core'); ?> <?php echo get_the_author_link(); ?></a> </li>
												</ul>
											</div>                                 
											<div class="wt-post-title ">
												<h3 class="post-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a></h3>
											</div>
										</div>
									</div>                                
								</div>
							</div>
							<?php
						} ?>
					</div>
				</div> 
            </div>	
			<?php
		}
		
		wp_reset_postdata();
	}
}