<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Projects_Section extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'projects-section';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Projects Section', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'projects_section',
			[
				'label' => __( 'Projects Section', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
					'style3' => __( 'Style 3', 'gridvalley-core' ),
					'style4' => __( 'Style 4', 'gridvalley-core' ),
					'style5' => __( 'Style 5', 'gridvalley-core' ),
					'style6' => __( 'Style 6', 'gridvalley-core' ),
					'style7' => __( 'Style 7', 'gridvalley-core' ),
					'style8' => __( 'Style 8', 'gridvalley-core' ),
					'style9' => __( 'Style 9', 'gridvalley-core' ),
					'style10' => __( 'Style 10', 'gridvalley-core' ),
				],
			]
		);
		
		$service_categories = get_terms( array(
			'taxonomy' => 'projects_category',
			'hide_empty' => false
		) );
		$options = [];
		foreach ( $service_categories as $category ) {
			$options[ $category->term_id ] = $category->name;
		}

		$this->add_control(
			'project_categories',
			[
				'label' => __( 'Categories', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT2,
				'options' => $options,
				'default' => [],
				'label_block' => true,
				'multiple' => true,
			]
		);
		
		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Posts Per Page', 'gridvalley-core' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 6,
			]
		);
		
		$this->add_control(
			'orderby',
			[
				'label' => __( 'Order By', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'name',
				'options' => [
					'title' => __( 'Title', 'gridvalley-core' ),
					'name' => __( 'Name', 'gridvalley-core' ),
					'date' => __( 'Date', 'gridvalley-core' ),
					'comment_count' => __( 'Comment Count', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'order',
			[
				'label' => __( 'Order', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'asc' => __( 'ASC', 'gridvalley-core' ),
					'desc' => __( 'DESC', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'element_title',
			[
				'label' => __( 'Element Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3', 'style4', 'style6','style7','style8','style9','style10'],
				]
			]
		);
		$this->add_control(
			'element_caption',
			[
				'label' => __( 'Element Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3', 'style4', 'style6','style7','style8','style9','style10'],
				]
			]
		);
		
		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1'],
				]
			]
		);
		
		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1','style7','style8','style9'],
				]
			]
		);
		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button Url', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'gridvalley-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition' => [
					'select_style' => [ 'style1','style7','style8','style9'],
				]
			]
		);
		
		$this->add_control(
			'section_image',
			[
				'label' => __('Section Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => [ 'style1'],
				]
			]
		);
		
		
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		
		$paged = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;

		$args = array(
			'post_type' => 'projects',
			'posts_per_page' => $settings['posts_per_page'],
			'orderby' => $settings['orderby'],
			'order' => $settings['order'],
			'paged' => $paged,
			'tax_query' => array(
				array(
					'taxonomy' => 'projects_category',
					'field'    => 'post_id',
					'terms'    => $settings['project_categories'],
				),
			)
		);
		
		$the_query = get_posts( $args );
		
		if($settings['select_style'] == 'style1'){ ?>
			<!-- OUR PROJECTS START -->
			<div class="section-full project-1-outer-main p-t80">
				<div class="container">	
					<div class="section-head center wt-small-separator-outer text-center">
						<div class="wt-small-separator site-text-primary">
							<div class="sep-leaf-left"></div>
							<div> <?php echo esc_attr($settings['element_caption']); ?> </div>
							<div class="sep-leaf-right"></div>
						</div>
						<h2><?php echo esc_attr($settings['element_title']); ?></h2>
					</div>
				</div>
				<div class="project-1-outer-section bg-gray bg-center" style="background-image:url(<?php echo esc_url(get_template_directory_uri()); ?>/assets/images/bg-1.png)">
					<div class="container">
						<!-- PROJECT SLIDER START -->
						<div class="section-content">
							<div class="project-1-outer clearfix">
								<div class="project-1-left">
									<div class="crane-image-section">
										<img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
									</div>
								</div>	
								<div class="project-1-right">
									<div class="owl-carousel project-1-slider owl-btn-top-right long-arrow-next-prev">
										<?php
										$current_size = 1;
										foreach($the_query as $query){
											$project_name = get_field('project_name', $query->ID);
											
											?>
											<div class="item">
												<div class="pproject-1-inner-block clearfix">
													<div class="project-1-inner-media">
														<div class="project-1-inner-pic">
															<?php echo get_the_post_thumbnail($query->ID,'industroz-projects-carousel2'); ?>
														</div>
													</div>
													<div class="project-1-inner-info">
														<h4 class="site-text-primary"><?php echo esc_attr($project_name); ?></h4>
														<h3 class="wt-title"><?php echo esc_attr(get_the_title($query->ID)); ?></h3>
														<p><?php echo esc_attr(substr(strip_tags($query->post_content),0,120)); ?></p>
														<a href="<?php echo esc_url(get_permalink($query->ID)); ?>" class="site-button site-btn-effect"><?php echo esc_attr__('More Detail','gridvalley-core'); ?></a>
													</div>
												</div>
											</div>
											<?php
										} ?>
									</div> 
								</div>	
							</div>
						</div>
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style2'){
			$cat_count = count($settings['project_categories']);
			?>
			<!-- PROJECTS SECTION START -->
            <div class="section-full p-t80 p-b50">
				<div class="container">
					<!-- TITLE START-->
					<div class="section-head center wt-small-separator-outer text-center text-white">
						<div class="wt-small-separator site-text-primary">
							<div  class="sep-leaf-left"></div>
							<div><?php echo esc_attr($settings['element_caption']); ?></div>
							<div  class="sep-leaf-right"></div>
						</div>
						<h2><?php echo esc_attr($settings['element_title']); ?></h2>
					</div>
					<!-- TITLE END--> 

					<div class="section-content">
						<div class="masonry-wrap row mfp-gallery project-stamp clearfix d-flex justify-content-center">
							<!-- COLUMNS 1 -->
							<div class="stamp col-xl-3 col-lg-4 col-md-6 col-sm-12 m-b30">
								<div class="project-stamp-list bg-white">
									<div class="filter-wrap">
										<ul class="filter-navigation masonry-filter text-uppercase">
											<li class="active"><a data-filter="*" data-hover="All" href="#"><i class="flaticon-layers"></i><?php echo esc_attr__('All Cases','gridvalley-core'); ?></a></li>
											<?php
											for($i=0; $i<$cat_count; $i++){
												$c = get_term($settings['project_categories'][$i]);
												$icon_class = get_field('icon_class', $c);
												$term_name = get_term( $settings['project_categories'][$i] )->name;
												?>
												<li><a data-filter=".cat-<?php echo esc_attr($settings['project_categories'][$i]); ?>" href="javascript:;"><i class="<?php echo esc_attr($icon_class); ?>"></i><?php echo esc_attr($term_name); ?></a></li>
												<?php
											} ?>
										</ul>
									</div>                          
								</div>            
							</div>
							<!-- COLUMNS 2 -->
							<?php
							$current_size = 1;
							
							foreach($the_query as $query){
								$cat_ids = '';
								$project_name = get_field('project_name', $query->ID);
								
								$project_terms = get_the_terms( $query->ID, 'projects_category' );
								
								foreach($project_terms as $project_term){
									$cat_ids .=  'cat-' . $project_term->term_id . ' ';
								}
								
								?>
								<div class="masonry-item  <?php echo esc_attr($cat_ids); ?> col-xl-3 col-lg-4 col-md-6 col-sm-12 m-b30">
									<div class="wt-box bg-white  p-a10 project-2-block">
										<div class="wt-thum-bx">
											<?php echo get_the_post_thumbnail($query->ID,'industroz-projects-masonary'); ?>
										</div>
										<div class="wt-info">
											<h4 class="wt-title m-b0 m-t15">
												<a href="<?php echo esc_url(get_permalink($query->ID)); ?>"><?php echo esc_attr(get_the_title($query->ID)); ?></a>
											</h4>
										</div>
							   
									</div>
								</div>
								<?php
								$current_size++;
							} ?>
						 </div>
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style3'){ ?>
			<!-- PROJECTS SECTION START -->
            <div class="section-full p-t80 p-b50">
                    
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer text-center">
					<div class="wt-small-separator site-text-primary">
						<div  class="sep-leaf-left"></div>
						<div><?php echo esc_attr($settings['element_caption']); ?></div>
						<div  class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['element_title']); ?></h2>
				</div>
				<!-- TITLE END--> 

				<div class="section-content">
					<div class="owl-carousel h3-project-slider  mfp-gallery">
						<!-- COLUMNS 1 --> 
						<?php
						foreach($the_query as $query){
							$project_name = get_field('project_name', $query->ID);
							
							$project_terms = get_the_terms( $query->ID, 'projects_category' );
							
							$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($query->ID),'full');
							
							?>
							<div class="item">
                                <div class="line-filter-outer">
									<div class="line-filter-media">
                                        <a href="<?php echo esc_url(get_permalink($query->ID)); ?>">
											<?php echo get_the_post_thumbnail($query->ID,'industroz-projects-carousel'); ?>
                                        </a>
										<div class="hover-effect-1">
                                            <div class="hover-effect-content text-white">
                                                <?php
												foreach($project_terms as $project_term){
													?>
													<h3 class="m-tb0 h-category"><a href="<?php echo esc_url(get_term_link($project_term->term_id)); ?>"><?php echo esc_attr($project_term->name); ?></a></h3>
													<?php
													break;
												} ?>
												
                                                <p><?php echo esc_attr(substr(strip_tags($query->post_content),0,116)); ?></p>
                                                <a href="<?php echo esc_url($img_src[0]); ?>" class="mfp-link"><i class="fa fa-search-plus"></i></a>
                                            </div>
                                        </div>     
                                    </div>
                                    <div class="line-filter  bg-white p-a30">
                                        <div class="filter-content">
                                            <h3 class="m-t0 m-b20 text-capitalize"> <a href="<?php echo esc_url(get_permalink($query->ID)); ?>"><?php echo esc_attr(get_the_title($query->ID)); ?></a></h3>
                                            <a href="<?php echo esc_url(get_permalink($query->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
                                        </div>
                                    </div>
                                </div>
                            </div> 
							<?php
						} ?>
					</div>
				</div> 
            </div>
			<?php
		}else if($settings['select_style'] == 'style4'){ ?>
			<!-- GALLERY SECTION START -->
            <div class="section-full p-t80 p-b40">
            	<div class="container">
                    <!-- TITLE START-->
                    <div class="section-head center wt-small-separator-outer text-white">
                        <div class="wt-small-separator site-text-primary">
                            <div class="sep-leaf-left"></div>
                            <div><?php echo esc_attr($settings['element_caption']); ?></div>
                            <div class="sep-leaf-right"></div>
                        </div>
                        <h2><?php echo esc_attr($settings['element_title']); ?></h2>
                    </div>
                    <!-- TITLE END-->
                </div>  
                <div class="section-content container-fluid">
                    <div class="owl-carousel gallery-slider owl-btn-vertical-center mfp-gallery">
						<?php
						foreach($the_query as $query){
							$project_name = get_field('project_name', $query->ID);
							
							$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($query->ID),'full');
							
							?>
							<div class="item">
								<div class="project-img-effect-1">
									<?php echo get_the_post_thumbnail($query->ID,'industroz-projects-carousel2'); ?>
									<div class="wt-info">
										<h3 class="wt-tilte m-b10 m-t0"><?php echo esc_attr(get_the_title($query->ID)); ?></h3>
										<p><?php echo esc_attr(substr(strip_tags($query->post_content),0,70)); ?></p>
										<a href="<?php echo esc_url(get_permalink($query->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
									</div>
									<a href="<?php echo esc_url($img_src[0]); ?>" class="mfp-link"><i class="fa fa-search-plus"></i></a>
								</div>
							</div>
							<?php
						} ?>
                    </div>
                </div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style5'){
			
			$cat_count = count($settings['project_categories']); ?>
			<!-- GALLERY SECTION START -->
            <div class="section-full p-t80 p-b50">
				<!-- PAGINATION START -->
				<div class="filter-wrap work-grid p-b30 text-center">
					<ul class="masonry-filter link-style ">
						<li class="active"><a data-filter="*" data-hover="All" href="#"><?php echo esc_attr__('All Cases','gridvalley-core'); ?></a></li>
						<?php
						for($i=0; $i<$cat_count; $i++){
							$c = get_term($settings['project_categories'][$i]);
							$icon_class = get_field('icon_class', $c);
							$term_name = get_term( $settings['project_categories'][$i] )->name;
							?>
							<li><a data-filter=".cat-<?php echo esc_attr($settings['project_categories'][$i]); ?>" href="#"><?php echo esc_attr($term_name); ?></a></li>
							<?php
						} ?>
					</ul>
				</div>
				<!-- PAGINATION END -->
				
				<!-- GALLERY CONTENT START -->
				<div class="masonry-wrap mfp-gallery  row clearfix d-flex justify-content-center flex-wrap">
					<!-- COLUMNS 1 -->
					<?php
					$current_size = 1;
					
					foreach($the_query as $query){
						$cat_ids = '';
						$project_name = get_field('project_name', $query->ID);
						
						$project_terms = get_the_terms( $query->ID, 'projects_category' );
						$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($query->ID),'full');
						foreach($project_terms as $project_term){
							$cat_ids .=  'cat-' . $project_term->term_id . ' ';
						}
						
						?>
						<div class="masonry-item <?php echo esc_attr($cat_ids); ?> col-lg-4 col-md-6 col-sm-6 m-b30">
							<div class="project-img-effect-1">
								<?php echo get_the_post_thumbnail($query->ID,'industroz-projects-medium'); ?>
								<div class="wt-info">
									<h3 class="wt-tilte m-b10 m-t0"><?php echo esc_attr(get_the_title($query->ID)); ?></h3>
									<p><?php echo esc_attr(substr(strip_tags($query->post_content),0,70)); ?></p>
									<a href="<?php echo esc_url(get_permalink($query->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
								</div>
								
								<a href="<?php echo esc_url($img_src[0]); ?>" class="mfp-link"><i class="fa fa-search-plus"></i></a>
							</div>
						</div>
						<?php
					} ?>
				 </div>
				<!-- GALLERY CONTENT END --> 
            </div>
			<?php
		}else if($settings['select_style'] == 'style6'){
			
			$cat_count = count($settings['project_categories']);
			
			?>
			<!-- LATEST PRJECTS SLIDER START -->
            <div class="section-full p-t80 p-b40 p-lr30 project-style-new site-bg-primary">
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer text-center">
					<div class="wt-small-separator site-text-white">
						<div  class="sep-leaf-left"></div>
						<div><?php echo esc_attr($settings['element_caption']); ?></div>
						<div  class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['element_title']); ?></h2>
				</div>
				<!-- TITLE END--> 

                <!-- IMAGE CAROUSEL START -->
                <div class="section-content">
                    <div class="owl-carousel owl-carousel-filter  owl-btn-vertical-center">
						<?php
						
						foreach($the_query as $query){
							$project_name = get_field('project_name', $query->ID);
							$project_terms = get_the_terms( $query->ID, 'projects_category' );
							$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($query->ID),'full');
							?>
							<div class="item">
								<div class="imghvr-zoom-out-down">
									<?php echo get_the_post_thumbnail($query->ID,'industroz-projects-carousel2'); ?>
									<div class="imghvr-content">
										<div class="imghvr-mid">
											<?php
											foreach($project_terms as $project_term){
												?>
												<span class="project-new-category"><i class="fa fa-list"></i> <?php echo esc_attr($project_term->name); ?></span>	
												<?php
												break;
											} ?>
											<h3 class="wt-title"><a href="<?php echo esc_url(get_permalink($query->ID)); ?>" class="site-text-secondry"><?php echo esc_attr(get_the_title($query->ID)); ?></a></h3>
											<?php 
											if(has_excerpt($query->ID)){ ?>
												<p><?php echo esc_attr(strip_tags(get_the_excerpt($query->ID))); ?></p>
												<?php
											} ?>
											<a href="<?php echo esc_url(get_permalink($query->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
										</div>
									</div>
								</div>
							</div>
							<?php
						} ?>
                	</div>
                </div>
             </div>   
            <!-- LATEST PRJECTS SLIDER END --> 
			<?php
		}else if($settings['select_style'] == 'style7'){ ?>
		
			<div class="section-full p-t80 p-b20">
				<div class="section-content">
					<div class="wt-separator-two-part">
						<div class="row wt-separator-two-part-row">
							<div class="col-lg-8 col-md-7 wt-separator-two-part-left">
								<!-- TITLE START-->
								<div class="section-head left wt-small-separator-outer">
									<div class="wt-small-separator site-text-primary">
										<div class="sep-leaf-left"></div>
										<div><?php echo esc_attr($settings['element_caption']); ?></div>
										<div class="sep-leaf-right"></div>
									</div>
									<h2><?php echo esc_attr($settings['element_title']); ?></h2>
								</div>
								<!-- TITLE END-->
							</div>
							<div class="col-lg-4 col-md-5 wt-separator-two-part-right text-right">
								<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
							</div>
						</div>
					</div>
					<div class="row d-flex justify-content-center">
						<?php
						
						foreach($the_query as $query){
							$project_name = get_field('project_name', $query->ID);
							$project_terms = get_the_terms( $query->ID, 'projects_category' );
							$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($query->ID),'full');
							?>
							<div class="col-lg-4 col-md-6 col-sm-12 m-b50">
								<div class="wt-box service-box-2 bg-white">
									<div class="service-box-2-media m-b20">
										<?php echo get_the_post_thumbnail($query->ID,'industroz-projects-carousel2'); ?>
									</div>      
									<div class="service-box-title title-style-2 site-text-secondry">
										<a href="<?php echo esc_url(get_permalink($query->ID)); ?>"><span class="s-title-one"><?php echo esc_attr(get_the_title($query->ID)); ?></span></a>
									</div>
									<div class="service-box2-content">
										<?php 
										if(has_excerpt($query->ID)){ ?>
											<p><?php echo esc_attr(strip_tags(get_the_excerpt($query->ID))); ?></p>
											<?php
										} ?>
										<a href="<?php echo esc_url(get_permalink($query->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
									</div>
								</div>
							</div>
							<?php
						} ?>
					</div>
				</div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style8'){ ?>
		
			<!-- PROJECT SECTION START -->
            <div class="section-full  p-t80 p-b50">
                <div class="container">
                    <div class="wt-separator-two-part">
                    	<div class="row wt-separator-two-part-row">
                        	<div class="col-lg-8 col-md-7 wt-separator-two-part-left">
                                <!-- TITLE START-->
                                <div class="section-head left wt-small-separator-outer text-white">
                                    <div class="wt-small-separator site-text-white">
                                        <div class="sep-leaf-left"></div>
                                        <div><?php echo esc_attr($settings['element_caption']); ?></div>
                                        <div class="sep-leaf-right"></div>
                                    </div>
                                    <h2><?php echo esc_attr($settings['element_title']); ?></h2>
                                </div>
                                <!-- TITLE END-->
                            </div>
                            <div class="col-lg-4 col-md-5 wt-separator-two-part-right text-right">
                            	<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
                            </div>
                    	</div>
                    </div>
				</div>
				<div class="section-content"> 
					<div class="project-gallery-block-outer m-b30">
						<div class="container">
							<div class="project-gallery-style1">
								<div class="owl-carousel project-gallery-one owl-btn-vertical-center ">
                                    <?php
									foreach($the_query as $query){
										$project_name = get_field('project_name', $query->ID);
										$project_terms = get_the_terms( $query->ID, 'projects_category' );
										$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($query->ID),'full');
										
										
										foreach($project_terms as $project_term){
											$term_name =  esc_attr($project_term->name);
											break;
										}  ?>
                                        <!-- COLUMNS 1 --> 
                                        <div class="item ">
                                            <div class="project-box-style1">
                                                <div class="project-content">
													<div class="project-title">  <?php echo esc_attr($term_name); ?>  </div>
                                                    <h3 class="project-title-large"><a href="<?php echo esc_url(get_permalink($query->ID)); ?>"><?php echo esc_attr(get_the_title($query->ID)); ?></a></h3>
                                                </div>
                                                <div class="project-media">
                                                    <?php echo get_the_post_thumbnail($query->ID,'industroz-news-projects-new'); ?>
                                                </div>
                                                <div class="project-view">
                                                    <a class="elem pic-long project-view-btn" href="<?php echo esc_url($img_src[0]); ?>" title="<?php echo esc_attr($term_name); ?>" 
                                                    data-lcl-txt="<?php echo esc_attr(get_the_title($query->ID)); ?>" data-lcl-author="<?php echo get_the_author_link(); ?>" data-lcl-thumb="<?php echo esc_url($img_src[0]); ?>">
                                                    <i></i>    
                                                    </a> 
                                                </div>                                    
                                            </div>
                                        </div>
										<?php
									} ?>   
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
            <!-- PROJECT SECTION END -->
			<?php
		}else if($settings['select_style'] == 'style9'){ ?>
		
			<!-- OUR PROJECTS SECTION START -->
            <div class="section-full  p-t80 p-b80">
                <div class="container">
                    <div class="wt-separator-two-part">
                    	<div class="row wt-separator-two-part-row">
                        	<div class="col-lg-8 col-md-7 wt-separator-two-part-left">
                                <!-- TITLE START-->
                                <div class="section-head left wt-small-separator-outer">
                                    <div class="wt-small-separator site-text-primary">
                                        <div class="sep-leaf-left"></div>
                                        <div><?php echo esc_attr($settings['element_caption']); ?></div>
                                        <div class="sep-leaf-right"></div>
                                    </div>
                                    <h2><?php echo esc_attr($settings['element_title']); ?></h2>
                                </div>
                                <!-- TITLE END-->
                            </div>
                            <div class="col-lg-4 col-md-5 wt-separator-two-part-right text-right">
                            	<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
                            </div>
                    	</div>
                    </div>
                </div> 
                <div class="section-content">
                    <div class="container-fluid">	
                        <div class="projects-slider-two">
                            <div class="owl-carousel projects-carousel-two owl-btn-vertical-center">
                                <?php
								$current_size = 1;
								foreach($the_query as $query){
									$project_name = get_field('project_name', $query->ID);
									$project_terms = get_the_terms( $query->ID, 'projects_category' );
									$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($query->ID),'full');
									
									
									foreach($project_terms as $project_term){
										$term_name =  esc_attr($project_term->name);
										break;
									}  ?>
									<div class="item">
										<div class="projects-two-info bg-white">
											<div class="wt-media img-reflection">
												 <?php echo get_the_post_thumbnail($query->ID,'industroz-projects-new-carousel'); ?>
											</div>
											<h3 class="wt-tilte m-t0" data-title="0<?php echo esc_attr($current_size); ?>">
												<a href="<?php echo esc_url(get_permalink($query->ID)); ?>"><?php echo esc_attr(get_the_title($query->ID)); ?></a>
											</h3>
										</div>
									</div>
									<!-- COLUMNS 2 -->
									<?php
									$current_size++;
								} ?>
                            </div>                        
                        </div>
                    </div>
                </div>
            </div>   
            <!-- OUR PROJECTS SECTION END -->
			<?php
		}else if($settings['select_style'] == 'style10'){ ?>
			<!-- LATEST PRJECTS SLIDER START -->
            <div class="section-full p-t90 p-b50 p-lr30 project-style-new ">
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer">
					<div class="wt-small-separator site-text-primary">
						<div><?php echo esc_attr($settings['element_caption']); ?></div>
					</div>
					<h2><?php echo esc_attr($settings['element_title']); ?></h2>
				</div>
				<!-- TITLE END-->
                <!-- IMAGE CAROUSEL START -->
                <div class="section-content">
					<div class="owl-carousel project-carousel owl-btn-vertical-center m-b30">
					   <?php
						foreach($the_query as $query){
							$project_name = get_field('project_name', $query->ID);
							$project_terms = get_the_terms( $query->ID, 'projects_category' );
							$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($query->ID),'full');
							
							foreach($project_terms as $project_term){
								$term_name =  esc_attr($project_term->name);
								break;
							}  ?>
							<!-- COLUMNS 1 --> 
                            <div class="item">
                                <div class="project-new-2">
                                    <div class="wt-img-effect">
                                         <?php echo get_the_post_thumbnail($query->ID,'industroz-projects-new-carousel'); ?>
                                        <div class="project-view">
                                            <a class="elem pic-long project-view-btn" href="<?php echo esc_url($img_src[0]); ?>" title="<?php echo esc_attr(get_the_title($query->ID)); ?>" 
                                            data-lcl-txt="" data-lcl-author="" data-lcl-thumb="<?php echo esc_url($img_src[0]); ?>">
                                            <i class="fa fa-search-plus"></i>     
                                            </a> 
                                        </div> 
                                    </div>
                                    <div class="project-new-content2">
                                        <span class="project-new-category"><?php echo esc_attr($term_name); ?></span>	
                                        <h3 class="wt-title"><a href="<?php echo esc_url(get_permalink($query->ID)); ?>"><?php echo esc_attr(get_the_title($query->ID)); ?></a></h3>
                                        <?php 
										if(has_excerpt($query->ID)){ ?>
											<p><?php echo esc_attr(strip_tags(get_the_excerpt($query->ID))); ?></p>
											<?php
										} ?>
                                        <a href="<?php echo esc_url(get_permalink($query->ID)); ?>" class="site-button-link site-text-primary"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
                                    </div>
                                </div>
                            </div>
                            <?php
						} ?>
					</div>
                </div>
            </div>
			<?php
		}  
		wp_reset_postdata();
	}
}