<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Services_Section extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'services-section';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Services Section', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'services_section',
			[
				'label' => __( 'Services Section', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
					'style3' => __( 'Style 3', 'gridvalley-core' ),
					'style4' => __( 'Style 4', 'gridvalley-core' ),
					'style5' => __( 'Style 5', 'gridvalley-core' ),
					'style6' => __( 'Style 6', 'gridvalley-core' ),
					'style7' => __( 'Style 7', 'gridvalley-core' ),
					'style8' => __( 'Style 8', 'gridvalley-core' ),
					'style9' => __( 'Style 9', 'gridvalley-core' ),
					'style10' => __( 'Style 10', 'gridvalley-core' ),
					'style11' => __( 'Style 11', 'gridvalley-core' ),
					'style12' => __( 'Style 12', 'gridvalley-core' ),
					'style13' => __( 'Style 13', 'gridvalley-core' ),
					'style14' => __( 'Style 14', 'gridvalley-core' ),
					'style15' => __( 'Style 15', 'gridvalley-core' ),
				],
			]
		);
		
		$service_categories = get_terms( array(
			'taxonomy' => 'services_category',
			'hide_empty' => false
		) );
		$options = [];
		foreach ( $service_categories as $category ) {
			$options[ $category->term_id ] = $category->name;
		}

		$this->add_control(
			'service_categories',
			[
				'label' => __( 'Categories', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT2,
				'options' => $options,
				'default' => [],
				'label_block' => true,
				'multiple' => true,
			]
		);
		
		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Posts Per Page', 'gridvalley-core' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 6,
			]
		);
		
		$this->add_control(
			'description_characters',
			[
				'label' => __( 'Description Characters To Fetch', 'gridvalley-core' ),
				'type' => Controls_Manager::NUMBER,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'orderby',
			[
				'label' => __( 'Order By', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'name',
				'options' => [
					'title' => __( 'Title', 'gridvalley-core' ),
					'name' => __( 'Name', 'gridvalley-core' ),
					'date' => __( 'Date', 'gridvalley-core' ),
					'comment_count' => __( 'Comment Count', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'order',
			[
				'label' => __( 'Order', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'asc' => __( 'ASC', 'gridvalley-core' ),
					'desc' => __( 'DESC', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'pagination',
			[
				'label' => __( 'Show Pagination', 'gridvalley-core' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'label_off' => __( 'Off', 'gridvalley-core' ),
				'label_on' => __( 'On', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style5'],
				]
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => ['style1','style2','style3','style4','style5','style6','style8','style10','style11','style12','style13','style14','style15'],
				]
			]
		);
		$this->add_control(
			'caption',
			[
				'label' => __( 'Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => ['style1','style2','style3','style4','style5','style6','style8','style10','style11','style12','style13','style14','style15'],
				]
			]
		);
		
		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style4', 'style13'],
				]
			]
		);
		
		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => ['style1', 'style4', 'style5', 'style13'],
				]
			]
		);
		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button Url', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'gridvalley-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition' => [
					'select_style' => [ 'style1', 'style4', 'style5', 'style13'],
				]
			]
		);
		
		$this->add_control(
			'section_image',
			[
				'label' => __( 'Sectiom Image', 'gridvalley-core' ),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => [ 'style8'],
				]
			]
		);
		
		
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		
		$settings['description_characters'] = !empty($settings['description_characters']) ? $settings['description_characters'] : 100 ;
		
		if($settings['select_style'] == 'style1'|| $settings['select_style'] == 'style2' ||
			$settings['select_style'] == 'style3'|| $settings['select_style'] == 'style4' ||
			$settings['select_style'] == 'style5'|| $settings['select_style'] == 'style6' ||
			$settings['select_style'] == 'style7'|| $settings['select_style'] == 'style8' ||
			$settings['select_style'] == 'style9'|| $settings['select_style'] == 'style10' ||
			$settings['select_style'] == 'style11'|| $settings['select_style'] == 'style12' ||
			$settings['select_style'] == 'style13'|| $settings['select_style'] == 'style14'){
			
			$paged = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;

			$args = array(
				'post_type' => 'services',
				'posts_per_page' => $settings['posts_per_page'],
				'orderby' => $settings['orderby'],
				'order' => $settings['order'],
				'paged' => $paged,
				'tax_query' => array(
					array(
						'taxonomy' => 'services_category',
						'field'    => 'post_id',
						'terms'    => $settings['service_categories'],
					),
				)
			);
			
			$the_query = new \WP_Query($args);	
		}
		
		if($settings['select_style'] == 'style1' ){ ?>
			<div class="section-content services-section-content">
				<div class="row">
					<div class="col-xl-6 col-lg-12 col-md-12">
						<div class="services-section-content-left">
							<!-- TITLE START-->
							<div class="left wt-small-separator-outer text-white">
								<div class="wt-small-separator site-text-primary">
									<div  class="sep-leaf-left"></div>
									<div><?php echo esc_attr($settings['caption']); ?></div>
									<div  class="sep-leaf-right"></div>
								</div>
								<h2><?php echo esc_attr($settings['title']); ?></h2>
								<p><?php echo esc_attr($settings['description']); ?></p>
								<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
							</div>
							<!-- TITLE END-->
						</div>                        
					</div> 
				
					<div class="col-xl-6 col-lg-12 col-md-12">
						<div class="services-section-content-right">
							<div class="owl-carousel services-slider owl-btn-vertical-center">
							<?php
							$current_size = 1;
							while($the_query->have_posts()){ 
								$the_query->the_post();
								global $post;
								$icon_class = get_field('service_icon', $post->ID);
								$icon_img = get_field('service_icon_image', $post->ID);
								?>
								<div class="item">
									<div class="wt-box service-box-1-new bg-white">
										<div class="wt-icon-box-wraper-new">
											<div class="icon-xl inline-icon">
												<?php 
												if($icon_img <> ''){ ?>
													<img src="<?php echo esc_url($icon_img); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
													<?php
												}else{ ?>
													<span class="icon-cell site-text-primary"><i class="<?php echo esc_attr($icon_class); ?>"></i></span>
													<?php
												} ?>
											</div>
											<div class="wt-icon-number-new"><span>0<?php echo esc_attr($current_size); ?></span></div>
										</div>   
										<div class="service-box-title-new title-style-2 site-text-secondry">
											<span class="s-title-one"><?php echo esc_attr($post->post_title); ?></span>
										</div>
										
										<div class="service-box-content-new">
											<p><?php echo esc_attr(substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
										</div>
										<div class="service-box-new-link">
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
										</div>
									</div>
								</div>
								<?php
								$current_size++;
							} ?>
							</div>
						</div>
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style2'){ ?>
			<div class="section-full small-device p-b40 top-half-section-outer">
				<!-- IMAGE CAROUSEL START -->
				<div class="section-content clearfix">
					<?php
					if($settings['title'] <> ''){ ?>
						<div class="section-head center wt-small-separator-outer text-center">
							<div class="wt-small-separator site-text-primary">
								<div class="sep-leaf-left"></div>
								<div><?php echo esc_attr($settings['caption']); ?></div>
								<div class="sep-leaf-right"></div>
							</div>
							<h2><?php echo esc_attr($settings['title']); ?></h2>
						</div>	
						<?php
					} ?>
					
					<div class="row d-flex justify-content-center">
						<?php
						$current_size = 1;
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post;
							$icon_class = get_field('service_icon', $post->ID);
							$icon_img = get_field('service_icon_image', $post->ID);
							?>
							<div class="col-lg-4 col-md-6 m-b50">
								<div class="service-border-box">
									<div class="wt-box service-box-1">
										<div class="wt-icon-box-wraper">
											<div class="wt-icon-box-md site-bg-primary">
												<?php 
												if($icon_img <> ''){ ?>
													<img src="<?php echo esc_url($icon_img); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
													<?php
												}else{ ?>
													
													<span class="icon-cell text-white"><i class="<?php echo esc_attr($icon_class); ?>"></i></span>
													<?php
												} ?>
											</div>
											<div class="wt-icon-number"><span>0<?php echo esc_attr($current_size); ?></span></div>
										</div>
										<div class="service-box-title title-style-2 site-text-secondry">
											<span class="s-title-one"><?php echo esc_attr($post->post_title); ?></span>     
										</div>
										<div class="service-box-content">
											<p><?php echo esc_attr(substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
										</div>
									</div>
								</div>    
							</div>
							<?php
							$current_size++;
						} ?>
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style3'){ ?>
			<div class="section-full  p-t80 p-b50 services-style3">
				<!-- IMAGE CAROUSEL START -->
				<div class="section-content clearfix">
					<?php
					if($settings['title'] <> ''){ ?>
						<div class="section-head center wt-small-separator-outer text-center">
							<div class="wt-small-separator site-text-primary">
								<div class="sep-leaf-left"></div>
								<div><?php echo esc_attr($settings['caption']); ?></div>
								<div class="sep-leaf-right"></div>
							</div>
							<h2><?php echo esc_attr($settings['title']); ?></h2>
						</div>	
						<?php
					} ?>
					<div class="top-half2-section">
						<div class="row d-flex justify-content-center">
							<?php
							$current_size = 1;
							while($the_query->have_posts()){ 
								$the_query->the_post();
								global $post;
								$icon_class = get_field('service_icon', $post->ID);
								$icon_img = get_field('service_icon_image', $post->ID);
								?>
								<div class="col-lg-4 col-md-6 animate_line">
									<div class="service-border-box3 shadow text-center">
										<div class="wt-icon-box-wraper bg-white p-tb50 p-lr20">
											<div class="icon-lg inline-icon	 m-b50">
												<?php 
												if($icon_img <> ''){ ?>
													<img src="<?php echo esc_url($icon_img); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
													<?php
												}else{ ?>
													<span class="icon-cell site-text-primary"><i class="<?php echo esc_attr($icon_class); ?>"></i></span>
													<?php
												} ?>
											</div>
											<div class="icon-content">
												<h3 class="wt-tilte m-b20"><?php echo esc_attr($post->post_title); ?></h3>
												<p><?php echo esc_attr(substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
												<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link"><?php echo esc_attr__('More Detail','gridvalley-core'); ?></a>
											</div>
										</div>
									</div>
								</div>
								<?php
								$current_size++;
							} ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style4'){ ?>
			<!-- SERVICES SECTION START -->
            <div class="section-full p-t60 overlay-wraper services-main-section bg-white">
                <div class="section-content services-section-content">
                	<div class="row">
                        <div class="col-xl-6 col-lg-12 col-md-12">
                        	<div class="services-section-content-left">
                                <!-- TITLE START-->
                                <div class="left wt-small-separator-outer">
                                    <div class="wt-small-separator site-text-primary">
                                        <div  class="sep-leaf-left"></div>
                                        <div><?php echo esc_attr($settings['caption']); ?></div>
                                        <div  class="sep-leaf-right"></div>
                                    </div>
                                    <h2><?php echo esc_attr($settings['title']); ?></h2>
                                    <p><?php echo esc_attr($settings['description']); ?></p>
                                    <a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
                                </div>
                                <!-- TITLE END-->
                            </div>                        
                        </div> 
                        <div class="col-xl-6 col-lg-12 col-md-12">
                        	<div class="services-section-content-right2">
                                <div class="owl-carousel services-slider owl-btn-vertical-center">
									<?php
									$current_size = 1;
									while($the_query->have_posts()){ 
										$the_query->the_post();
										global $post;
										?>
										<div class="item">
											<div class="wt-box bg-gray  p-a10 project-2-block">
												<div class="wt-thum-bx">
													<?php echo get_the_post_thumbnail($post->ID,'industroz-projects-masonary'); ?>
												</div>
												<div class="wt-info">
													<h4 class="wt-title m-b0 m-t15"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr($post->post_title); ?></a></h4>
												</div>
											</div>
										</div>
										<?php
										$current_size++;
									} ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div> 
            </div>
			<?php
		}else if($settings['select_style'] == 'style5'){ ?>
			<div class="section-full p-t80 p-b40">
				<div class="section-content">

					<div class="wt-separator-two-part">
						<div class="row wt-separator-two-part-row">
							<div class="col-lg-8 col-md-7 wt-separator-two-part-left">
								<!-- TITLE START-->
								<div class="section-head left wt-small-separator-outer">
									<div class="wt-small-separator site-text-primary">
										<div class="sep-leaf-left"></div>
										<div><?php echo esc_attr($settings['caption']); ?></div>
										<div class="sep-leaf-right"></div>
									</div>
									<h2><?php echo esc_attr($settings['title']); ?></h2>
								</div>
								<!-- TITLE END-->
							</div>
							<div class="col-lg-4 col-md-5 wt-separator-two-part-right text-right">
								<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
							</div>
						</div>
					</div>
					<div class="row d-flex justify-content-center">
						<?php
						$current_size = 1;
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post;
							?>
						
							<div class="col-lg-4 col-md-6 col-sm-12 m-b50">
								<div class="service-border-box service-image-box">
									<div class="wt-box service-box-1 bg-white">
										<div class="service-box-1-media m-b20">
											<?php echo get_the_post_thumbnail($post->ID,'full'); ?>
										</div>
										<div class="service-box-title title-style-2 site-text-secondry">
											<span class="s-title-one"><?php echo esc_attr($post->post_title); ?></span>
											<span class="s-title-two"></span>     
										</div>
										<div class="service-box-content">
											<p><?php echo esc_attr(substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
										</div>

									</div>
								</div>                     
							</div>
							<?php
							$current_size++;
						} ?>
					</div>
					<?php 
					if($settings['pagination'] == 'yes'){
						echo industroz_pagination($the_query);
					} ?>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style6'){ ?>
			<!-- SERVICE SECTION START -->
			<div class="section-full p-t80 p-b80">
				<div class="container">
					<!-- TITLE START-->
					<div class="m-b30 center wt-small-separator-outer text-center">
						<div class="wt-small-separator site-text-primary">
							<div  class="sep-leaf-left"></div>
							<div><?php echo esc_attr($settings['caption']); ?></div>
							<div  class="sep-leaf-right"></div>
						</div>
						<h2><?php echo esc_attr($settings['title']); ?></h2>
					</div>
					<!-- TITLE END--> 

				   <div class="section-content">
						<div class="services-style-new owl-btn-vertical-center row justify-content-center">
							<!-- COLUMNS 1 --> 
							<?php
							$current_size = 1;
							while($the_query->have_posts()){ 
								$the_query->the_post();
								global $post;
								$icon_class = get_field('service_icon', $post->ID);
								$icon_img = get_field('service_icon_image', $post->ID);
								?>
								<div class="col-lg-4 col-md-6 col-sm-12 animate_line">
									<div class="wt-box service-box-1-new bg-white">
										<div class="wt-icon-box-wraper-new">
											<div class="icon-xl inline-icon">
												<?php 
												if($icon_img <> ''){ ?>
													<img src="<?php echo esc_url($icon_img); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
													<?php
												}else{ ?>
													<span class="icon-cell site-text-primary"><i class="<?php echo esc_attr($icon_class); ?>"></i></span>
													<?php
												} ?>
											</div>
											<div class="wt-icon-number-new"><span>0<?php echo esc_attr($current_size); ?></span></div>
										</div>   
										<div class="service-box-title-new title-style-2 site-text-secondry">
											<span class="s-title-one"><?php echo esc_attr($post->post_title); ?></span>
										</div>
										
										<div class="service-box-content-new">
											<p><?php echo esc_attr(substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
										</div>
										<div class="service-box-new-link">
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
										</div>
									</div>
								</div>
								<?php
								$current_size++;
							} ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style7'){ ?>
			<div class="section-full bg-white p-t80 p-b50 full-container-margin">
				<div class="container-fluid">
                    <!-- IMAGE CAROUSEL START -->
                    <div class="section-content clearfix">
                    	<div class="top-half2-section">
                        	<div class="row d-flex justify-content-center">
								<?php
								$current_size = 1;
								while($the_query->have_posts()){ 
									$the_query->the_post();
									global $post;
									$icon_img = get_field('service_icon_image', $post->ID);
									
									?>
									<div class="col-xl-3 col-lg-6 col-md-6 animate_line">
										<div class="service-border-box3 shadow text-center">
											<div class="wt-icon-box-wraper bg-white p-tb50 p-lr20">
												<div class="icon-lg inline-icon	 m-b50">
													<img src="<?php echo esc_url($icon_img); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
												</div>
												<div class="icon-content">
													<h3 class="wt-tilte m-b20"><?php echo esc_attr($post->post_title); ?></h3>
													<p><?php echo esc_attr(substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
													<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link"><?php echo esc_attr__('More Detail','gridvalley-core'); ?></a>
												</div>
											</div>
										</div>  
									</div>
									<?php
								} ?>
                            </div>
                        </div>
                    </div>
                </div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style8'){ ?>
			
			<!-- ABOUT SECTION START -->
            <div class="section-full p-t80 p-b50">
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer text-center">
					<div class="wt-small-separator site-text-primary">
						<div  class="sep-leaf-left"></div>
						<div><?php echo esc_attr($settings['caption']); ?></div>
						<div  class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['title']); ?></h2>
				</div>
				<!-- TITLE END-->                        
					
				<div class="section-content hover-block-outer">
					<div class="row d-flex justify-content-center">
					
						<div class="col-md-7 col-sm-12 m-b30 top-bottom-animation ">
							<div class="Safe-mid-section">
								<div class="wt-box">
									<div class="wt-media text-primary text-center">
										<img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="" class="img-top-bottom-aanimation">
									</div>
								</div>
							 </div>  
						</div>                                
					
						<div class="col-md-5 col-sm-12 m-b30  p-t30">
							<?php
							$current_size = 1;
							while($the_query->have_posts()){ 
								$the_query->the_post();
								global $post;
								$icon_img = get_field('service_icon_image', $post->ID);
								?>
								<div class="wt-icon-box-wraper left p-a20">
									<div class="icon-xl text-primary">
										<span class="icon-cell"><img src="<?php echo esc_url($icon_img); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>"></span>
									</div>
									<div class="icon-content">
										<h3 class="wt-tilte text-uppercase"><?php echo esc_attr($post->post_title); ?></h3>
										<p><?php echo esc_attr(substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
									</div>
								</div>                            
								<?php
							} ?>
						</div>
					</div>
				</div>
            </div> 
			<?php
		}else if($settings['select_style'] == 'style9'){ ?>
			
			<div class="box-style1-outer">
                <div class="row d-flex justify-content-center no-gutters">
					<?php
					$current_size = 1;
					while($the_query->have_posts()){ 
						$the_query->the_post();
						global $post;
						$icon_img = get_field('service_icon_image', $post->ID);
						?>
						<div class="col-xl-2 col-lg-2 col-md-6 col-sm-6">
							<div class="box-style1">
								<div class="wt-box ">
									<div class="box-style1-title title-style-2">
										<span class="o-title-one"><?php echo esc_attr($post->post_title); ?></span>
									</div>
									<div class="box-style1-content">
										<p><?php echo esc_attr(mb_substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
										<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
									</div>
									<div class="wt-icon-box-wraper">
										<div class="wt-icon-box-md bg-gray">
											<span class="icon-cell site-text-primary"><img src="<?php echo esc_url($icon_img); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>"></span>
										</div>
										<div class="wt-icon-number"><span>0<?php echo esc_attr($current_size); ?></span></div>
									</div>                                  
								</div>
							</div>
						</div>
						<?php
						$current_size++;
					} ?>
                </div>
            </div> 
			<?php
		}else if($settings['select_style'] == 'style10'){ ?>
			
			<div class="section-full p-t80 p-b50">
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer text-center">
					<div class="wt-small-separator site-text-primary">
						<div class="sep-leaf-left"></div>
						<div><?php echo esc_attr($settings['caption']); ?></div>
						<div class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['title']); ?></h2>
				</div>
				<!-- TITLE END--> 

				<div class="section-content">
					<div class="row justify-content-center">
						<?php
						$current_size = 1;
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post;
							$icon_class = get_field('service_icon', $post->ID);
							$icon_img = get_field('service_icon_image', $post->ID);
							?>
							<!-- COLUMNS 1 --> 
							<div class="col-lg-4 col-md-6 m-b30">
								<div class="wt-box service-box-1-new bg-white card1">
									<div class="wt-icon-box-wraper-new">
										<div class="icon-xl inline-icon">
											<?php 
											if($icon_img <> ''){ ?>
												<img src="<?php echo esc_url($icon_img); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
												<?php
											}else{ ?>
												<span class="icon-cell site-text-primary"><i class="<?php echo esc_attr($icon_class); ?>"></i></span>
												<?php
											} ?>
										</div>
										<div class="wt-icon-number-new"><span>0<?php echo esc_attr($current_size); ?></span></div>
									</div> 	
									<div class="service-box-title-new title-style-2 site-text-secondry">
										<h3 class="s-title-one"><?php echo esc_attr($post->post_title); ?></h3>
									</div>
									<div class="service-box-content-new">
										<p><?php echo esc_attr(mb_substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
									</div>
									<div class="service-box-new-link">
										<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link"><?php echo esc_attr__('More Detail','gridvalley-core'); ?></a>
									</div>
								</div>
							</div>
							<?php
							$current_size++;
						} ?>   
					</div>
				</div>
            </div> 
			<?php
		}else if($settings['select_style'] == 'style11'){ ?>
			<div class="section-full p-t80 p-b50">
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer text-center">
					<div class="wt-small-separator site-text-primary">
						<div class="sep-leaf-left"></div>
						<div><?php echo esc_attr($settings['caption']); ?></div>
						<div class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['title']); ?></h2>
				</div>
				<!-- TITLE END--> 

				<div class="section-content">
					<div class="row justify-content-center">
						<?php
						$current_size = 1;
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post;
							$icon_class = get_field('service_icon', $post->ID);
							$icon_img = get_field('service_icon_image', $post->ID);
							
							$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),'full');
							?>
							<!-- COLUMNS 1 --> 
							<div class="col-lg-4 col-md-6 m-b30 animate_line">

								<div class="wt-box service-box-1-new bg-white cardbg">
									<div class="wt-icon-box-wraper-new">
										<div class="icon-xl inline-icon">
											<?php 
											if($icon_img <> ''){ ?>
												<img src="<?php echo esc_url($icon_img); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
												<?php
											}else{ ?>
												<span class="icon-cell site-text-primary"><i class="<?php echo esc_attr($icon_class); ?>"></i></span>
												<?php
											} ?>
										</div>
										<div class="wt-icon-number-new"><span>0<?php echo esc_attr($current_size); ?></span></div>
									</div>   	
									<div class="service-box-title-new title-style-2 site-text-secondry">
										<h3 class="s-title-one"><?php echo esc_attr($post->post_title); ?></h3>
									</div>
									
									<div class="service-box-content-new">
										<p><?php echo esc_attr(mb_substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
									</div>
									<div class="service-box-new-link">
										<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
									</div>
									<div class="cardbg-pic" style="background-image: url(<?php echo esc_url($img_src[0]); ?>);"></div>
								</div>
							</div>
							<?php
							$current_size++;
						} ?>	
					</div>
				</div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style12'){ ?>
			<div class="section-full p-t90 p-b50">
				<!-- TITLE START-->
				<div class="section-head center  wt-small-separator-outer">
					<div class="wt-small-separator site-text-primary">
						<div><?php echo esc_attr($settings['caption']); ?></div>
					</div>
					<h2 class="wt-title"><?php echo esc_attr($settings['title']); ?></h2>
				</div>
				<!-- TITLE END-->
				<div class="s-section">
					<div class="row">  
						<?php
						$current_size = 1;
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post;
							$icon_class = get_field('service_icon', $post->ID);
							$icon_img = get_field('service_icon_image', $post->ID);
							
							$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),'full');
							?>
                            <div class="col-lg-3 col-md-6  col-sm-6 m-b30">
                                <div class="service-icon-box-three shadow-bx text-center">
                                    <div class="wt-icon-box-wraper circle-bg  scale-up-center">
                                        <div class="icon-lg inline-icon">
											<?php 
											if($icon_img <> ''){ ?>
												<span class="icon-cell">
													<img src="<?php echo esc_url($icon_img); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
												</span>
												<?php
											}else{ ?>
												<span class="icon-cell site-text-primary"><i class="<?php echo esc_attr($icon_class); ?>"></i></span>
												<?php
											} ?>
                                        </div>
                                    </div>  
                                    <div class="service-icon-box-title">
                                        <h4 class="wt-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr($post->post_title); ?></a></h4>
                                    </div>
                                    <div class="service-icon-box-content">
                                        <p><?php echo esc_attr(mb_substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
                                        <a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link site-text-primary"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
                                    </div>
                                </div>
                            </div>
							<?php
						} ?>
					</div>
				</div> 
            </div>
			<?php
		}else if($settings['select_style'] == 'style13'){ ?>
			<div class="section-full  service-gallery-style1-wrapper">
				<div class="services-gallery-block-outer">
					<div class="container half-wide-bg-outer p-t90 p-b50 ">
						<div class="half-wide-bg"></div>
						<div class="section-content"> 
							<div class="row">
								<div class="col-lg-4 col-md-12 m-b30">
									<!-- TITLE START-->
									<div class="section-head left wt-small-separator-outer text-white">
										<div class="wt-small-separator site-text-white">
											<div><?php echo esc_attr($settings['caption']); ?></div>
										</div>
										<h2 class="wt-title"><?php echo esc_attr($settings['title']); ?></h2>
										<p><?php echo esc_attr($settings['description']); ?></p>
										<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button-secondry site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
									</div>
									<!-- TITLE END--> 
								</div>
								<div class="col-lg-8 col-md-12">
									<div class="services-gallery-style2">
										<div class="owl-carousel services-gallery-two owl-btn-vertical-center ">
											<?php
											$current_size = 1;
											while($the_query->have_posts()){ 
												$the_query->the_post();
												global $post;
												$icon_class = get_field('service_icon', $post->ID);
												$icon_img = get_field('service_icon_image', $post->ID);
												
												$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),'full');
												?>
												<!-- COLUMNS 5 --> 
												<div class="item ">
													<div class="service-box-style2">
														<div class="service-media">
															<?php echo get_the_post_thumbnail($post->ID,'industroz-services-half'); ?>
														</div>
														<div class="service-content">
															<h3 class="service-title-large"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr($post->post_title); ?></a></h3>
															<p><?php echo esc_attr(mb_substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
															<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button site-btn-effect"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
														</div>
													</div>
												</div>                                            
												<?php
											} ?>
										</div>
									</div>
								</div>  
							</div>
						</div>                              
					</div>
				</div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style14'){ ?>
			<div class="section-full p-t80 p-b50">
				<!-- TITLE START-->
				<div class="section-head center  wt-small-separator-outer">
					<div class="wt-small-separator site-text-primary">
						<div><?php echo esc_attr($settings['caption']); ?></div>
					</div>
					<h2 class="wt-title"><?php echo esc_attr($settings['title']); ?></h2>
				</div>
				<!-- TITLE END-->
				<div class="s-section">
					<div class="row justify-content-center">
						<?php
						$current_size = 1;
						while($the_query->have_posts()){ 
							$the_query->the_post();
							global $post;
							$icon_class = get_field('service_icon', $post->ID);
							$icon_img = get_field('service_icon_image', $post->ID);
							
							$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),'full');
							?>
							<div class="col-lg-4 col-md-6  col-sm-6 m-b30">
								<div class="imghvr1 text-center">
									<?php echo get_the_post_thumbnail($post->ID,'industroz-services-grid-new'); ?>
									<figcaption>
										<div class="imghvr1-content">      
											<h4 class="wt-title"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr($post->post_title); ?></a></h4>
											<p><?php echo esc_attr(mb_substr(strip_tags($post->post_content),0,$settings['description_characters'])); ?></p>
											<a href="<?php echo esc_url(get_permalink($post->ID)); ?>" class="site-button-link site-text-primary"><?php echo esc_attr__('Read More','gridvalley-core'); ?></a>
										</div>
									</figcaption>
								</div>
							</div>
							<?php
						} ?>
					</div>
				</div>  
            </div>
			<?php
		}else if($settings['select_style'] == 'style15'){
			
			$paged = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;

			$args1 = array(
				'post_type' => 'services',
				'posts_per_page' => $settings['posts_per_page'],
				'orderby' => $settings['orderby'],
				'order' => $settings['order'],
				'paged' => $paged,
				'tax_query' => array(
					array(
						'taxonomy' => 'services_category',
						'field'    => 'post_id',
						'terms'    => $settings['service_categories'][0],
					),
				)
			);
			
			$the_query1 = new \WP_Query($args1);
			
			$args2 = array(
				'post_type' => 'services',
				'posts_per_page' => $settings['posts_per_page'],
				'orderby' => $settings['orderby'],
				'order' => $settings['order'],
				'paged' => $paged,
				'tax_query' => array(
					array(
						'taxonomy' => 'services_category',
						'field'    => 'post_id',
						'terms'    => $settings['service_categories'][1],
					),
				)
			);
			
			$the_query2 = new \WP_Query($args2);
			
			$term1 = get_term( $settings['service_categories'][0] );
			$term2 = get_term( $settings['service_categories'][1] );
			
			$cat_img1 = get_field('icon_image', $term1);
			$cat_img2 = get_field('icon_image', $term2);
			?>
			<!-- SERVICES SECTION START -->
            <div class="section-full p-t80 p-b50 service-gallery-style12-wrapper">
                    <div class="services-gallery-block-outer">
                        <div class="container">
                            <!-- TITLE START-->
                            <div class="section-head left wt-small-separator-outer">
                                <div class="wt-small-separator site-text-primary">
                                    <div><?php echo esc_attr($settings['caption']); ?></div>
                                </div>
                                <h2 class="wt-title"><?php echo esc_attr($settings['title']); ?></h2>
                            </div>
                            <!-- TITLE END-->
                        </div>
                        <div class="container">
                            <div class="services-tabs">
                                <ul class="sr-btn-filter-wrap">
                                    <li class="sr-btn-filter" data-filter=".cooling-list">
                                        <img src="<?php echo esc_url($cat_img1); ?>" alt="">
                                        <span class="wt-tilte cool-text"><?php echo  esc_attr($term1->name ); ?></span>
                                    </li>
                                    <li class="sr-btn-filter btn-active sr-btn-circle" data-filter="*"><?php echo esc_attr__('All','gridvalley-core'); ?></li>
                                    <li class="sr-btn-filter" data-filter=".heating-list">
										<img src="<?php echo esc_url($cat_img2); ?>" alt="">
                                        <span class="wt-tilte heat-text"><?php echo  esc_attr($term2->name ); ?></span>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <div class="container-fluid  services-tabs-content">
                            <div class="services-gallery-style12">
                                <div class="owl-carousel service_button_filter owl-btn-vertical-center ">
									<?php
									$current_size = 1;
									while($the_query1->have_posts()){ 
										$the_query1->the_post();
										global $post;
										$icon_class = get_field('service_icon', $post->ID);
										$icon_img = get_field('service_icon_image', $post->ID);
										
										$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),'full');
										?>
										<!-- COLUMNS 1 --> 
										<div class="item cooling-list">
											<div class="service-box-style12">
												<div class="service-media">
													<?php echo get_the_post_thumbnail($post->ID,'industroz-services-tabs'); ?>
												</div>
												<div class="service-content">
													<h3 class="service-title-large"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr($post->post_title); ?></a></h3>
												</div>
											</div>
										</div>
										<?php
									} wp_reset_postdata(); ?>
									
									<?php
									$current_size = 1;
									while($the_query2->have_posts()){ 
										$the_query2->the_post();
										global $post;
										$icon_class = get_field('service_icon', $post->ID);
										$icon_img = get_field('service_icon_image', $post->ID);
										
										$img_src = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID),'full');
										?>	
										<!-- COLUMNS 1 --> 
										<div class="item heating-list">
											<div class="service-box-style12">
												<div class="service-media">
													<?php echo get_the_post_thumbnail($post->ID,'industroz-services-tabs'); ?>
												</div>
												<div class="service-content">
													<h3 class="service-title-large"><a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr($post->post_title); ?></a></h3>
												</div>
											</div>
										</div>
										<?php
									} ?>
                                </div>
                            </div>
                        </div>                              
                    </div>
            </div>
			<?php
		}
		
		wp_reset_postdata();
	}
}