<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Team_Section extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'team-section';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Team Section', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'team_section',
			[
				'label' => __( 'Team Section', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
					'style3' => __( 'Style 3', 'gridvalley-core' ),
					'style4' => __( 'Style 4', 'gridvalley-core' ),
					'style5' => __( 'Style 5', 'gridvalley-core' ),
					'style6' => __( 'Style 6', 'gridvalley-core' ),
				],
			]
		);
		
		$team_categories = get_terms( array(
			'taxonomy' => 'team_category',
			'hide_empty' => false
		) );
		$options = [];
		foreach ( $team_categories as $category ) {
			$options[ $category->term_id ] = $category->name;
		}

		$this->add_control(
			'team_categories',
			[
				'label' => __( 'Categories', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT2,
				'options' => $options,
				'default' => [],
				'label_block' => true,
				'multiple' => true,
			]
		);
		
		$this->add_control(
			'posts_per_page',
			[
				'label' => __( 'Posts Per Page', 'gridvalley-core' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 6,
			]
		);
		
		$this->add_control(
			'orderby',
			[
				'label' => __( 'Order By', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'name',
				'options' => [
					'title' => __( 'Title', 'gridvalley-core' ),
					'name' => __( 'Name', 'gridvalley-core' ),
					'date' => __( 'Date', 'gridvalley-core' ),
					'comment_count' => __( 'Comment Count', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'order',
			[
				'label' => __( 'Order', 'gridvalley-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'asc' => __( 'ASC', 'gridvalley-core' ),
					'desc' => __( 'DESC', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'description_characters',
			[
				'label' => __( 'Description Characters To Fetch', 'gridvalley-core' ),
				'type' => Controls_Manager::NUMBER,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		$this->add_control(
			'caption',
			[
				'label' => __( 'Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style6'],
				]
			]
		);
		
		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style6'],
				]
			]
		);
		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button Url', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'gridvalley-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition' => [
					'select_style' => [ 'style6'],
				]
			]
		);
		
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		
		$paged = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;

		$args = array(
			'post_type' => 'team',
			'posts_per_page' => $settings['posts_per_page'],
			'orderby' => $settings['orderby'],
			'order' => $settings['order'],
			'paged' => $paged,
			'tax_query' => array(
				array(
					'taxonomy' => 'team_category',
					'field'    => 'post_id',
					'terms'    => $settings['team_categories'],
				),
			)
		);
		
		$the_query = get_posts( $args );
		
		if($settings['select_style'] == 'style1' || $settings['select_style'] == 'style2'){
			if($settings['select_style'] == 'style1'){ ?>
				<div class="section-full p-t80 p-b50 bg-white team-bg-section-outer">
					<div class="team-bg-map site-bg-secondry bg-repeat-x" style="background-image:url(<?php echo esc_url(get_template_directory_uri()); ?>/assets/images/bg-map2.png);"></div>
					<?php
				}else{ ?>
					<div class="section-full p-t80 p-b50 bg-white team-bg-section-outer bg-no-repeat bg-center" style="background-image:url(<?php echo esc_url(get_template_directory_uri()); ?>/assets/images/bg-map.png)">
					<?php
				} ?>
					<div class="container">
						<div class="section-content">
							<!-- TITLE START-->
							<div class="section-head center wt-small-separator-outer text-center">
								<div class="wt-small-separator site-text-primary">
									<div class="sep-leaf-left"></div>
									<div><?php echo esc_attr($settings['caption']); ?></div>
									<div class="sep-leaf-right"></div>
								</div>
								<h2><?php echo esc_attr($settings['title']); ?></h2>
							</div>
							<!-- TITLE END-->

							<div class="section-content">
								<div class="row justify-content-center">
									<?php
									$settings['description_characters'] = ($settings['description_characters'] <> '') ? $settings['description_characters']:169;
							
									$current_size = 1;
									foreach($the_query as $query){
										$designation = get_field('designation', $query->ID);
										$facebook_url = get_field('facebook_url', $query->ID);
										$twitter_url = get_field('twitter_url', $query->ID);
										$instagram_url = get_field('instagram_url', $query->ID);
										$linkedin = get_field('linkedin', $query->ID);
										
										?>
										<div class="col-lg-4 col-md-6 col-sm-12 m-b30">
											<div class="wt-team-1">
												<div class="wt-media">
													<?php echo get_the_post_thumbnail($query->ID,'full'); ?>
													<div class="team-social-center">
														<div class="team-content-holder">
															<p class="team-small-description"><?php echo esc_attr(substr($query->post_content,0,$settings['description_characters'])); ?></p>
															<ul class="team-social-bar">
																<li><a href="<?php echo esc_url($facebook_url); ?>"><i class="fa fa-facebook"></i></a></li>
																<li><a href="<?php echo esc_url($twitter_url); ?>"><i class="fa fa-twitter"></i></a></li>
																<li><a href="<?php echo esc_url($instagram_url); ?>"><i class="fa fa-instagram"></i></a></li>
																<li><a href="<?php echo esc_url($linkedin); ?>"><i class="fa fa-linkedin"></i></a></li>
															</ul>
														</div>
													</div>                                              
												</div> 
												<div class="wt-info p-a30  p-b0">
													<div class="team-detail  text-center">
														<h3 class="m-t0 team-name"><span class="<?php echo esc_attr($settings['select_style'] == 'style1' ? '' : 'site-text-secondry'); ?>"><?php echo esc_attr(get_the_title($query->ID)); ?></span></h3>
														<span class="title-style-2 team-position site-text-primary"><?php echo esc_attr($designation); ?></span>
													</div>
												</div>
											</div>
										</div>
										<?php
									} ?>
								</div>
							</div>  
						</div>
					</div>
				</div>
			<?php
		}else if($settings['select_style'] == 'style3'){ ?>
			<div class="section-full p-t80 p-b50 team-bg-section-outer ">
				<div class="section-content">
					<!-- TITLE START-->
					<div class="section-head center wt-small-separator-outer text-center">
						<div class="wt-small-separator site-text-primary">
							<div class="sep-leaf-left"></div>
							<div><?php echo esc_attr($settings['caption']); ?></div>
							<div class="sep-leaf-right"></div>
						</div>
						<h2><?php echo esc_attr($settings['title']); ?></h2>
					</div>
					<!-- TITLE END-->

					<div class="section-content">
						<div class="row justify-content-center">
							<?php
							$settings['description_characters'] = ($settings['description_characters'] <> '') ? $settings['description_characters']:169;
							$current_size = 1;
							foreach($the_query as $query){
								$designation = get_field('designation', $query->ID);
								$facebook_url = get_field('facebook_url', $query->ID);
								$twitter_url = get_field('twitter_url', $query->ID);
								$instagram_url = get_field('instagram_url', $query->ID);
								$linkedin = get_field('linkedin', $query->ID);
								
								?>
								<div class="col-lg-4 col-md-6 col-sm-6 m-b30">
									<div class="wt-team-1 p-a5 bg-white">
										<div class="wt-media">
											<?php echo get_the_post_thumbnail($query->ID,'full'); ?>
											<div class="team-social-center">
												<div class="team-content-holder">
													<p class="team-small-description"><?php echo esc_attr(substr($query->post_content,0,$settings['description_characters'])); ?></p>
													<ul class="team-social-bar">
														<li><a href="<?php echo esc_url($facebook_url); ?>"><i class="fa fa-facebook"></i></a></li>
														<li><a href="<?php echo esc_url($twitter_url); ?>"><i class="fa fa-twitter"></i></a></li>
														<li><a href="<?php echo esc_url($instagram_url); ?>"><i class="fa fa-instagram"></i></a></li>
														<li><a href="<?php echo esc_url($linkedin); ?>"><i class="fa fa-linkedin"></i></a></li>
													</ul>
												</div>                                              
											</div>                                              
										</div>
										<div class="wt-info p-a15">
											<div class="team-detail  text-center">
												<h3 class="m-t0 team-name"><span class=" site-text-secondry"><?php echo esc_attr(get_the_title($query->ID)); ?></span></h3>
												<span class="title-style-2 team-position site-text-primary"><?php echo esc_attr($designation); ?></span>
											</div>
										</div>
									</div>
								</div>
								<?php
							} ?>
						</div>
					</div>   
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style4'){ ?>
			<div class="section-full p-t80 p-b50 team-bg-section-outer">
                <div class="section-content">
                    <!-- TITLE START-->
                    <div class="section-head center wt-small-separator-outer text-center">
                        <div class="wt-small-separator site-text-primary">
                            <div class="sep-leaf-left"></div>
                            <div><?php echo esc_attr($settings['caption']); ?></div>
                            <div class="sep-leaf-right"></div>
                        </div>
                        <h2><?php echo esc_attr($settings['title']); ?></h2>
                    </div>
                    <!-- TITLE END-->
                    <div class="section-content">
                        <div class="row justify-content-center">
                            <?php
							$current_size = 1;
							foreach($the_query as $query){
								$designation = get_field('designation', $query->ID);
								$facebook_url = get_field('facebook_url', $query->ID);
								$twitter_url = get_field('twitter_url', $query->ID);
								$instagram_url = get_field('instagram_url', $query->ID);
								$linkedin = get_field('linkedin', $query->ID);
								
								?>
								<div class="col-lg-4 col-md-6 col-sm-12 m-b30">
									<div class="wt-team-10">
										<div class="wt-media">
											<?php echo get_the_post_thumbnail($query->ID,'full'); ?>
										</div> 
										<div class="wt-info">
											<div class="team-detail p-t30">
												<span class="title-style-2 team-position site-text-primary"><?php echo esc_attr($designation); ?></span>                                        
												<h3 class="m-t0 team-name"><a href="#" class="site-text-secondry"><?php echo esc_attr(get_the_title($query->ID)); ?></a></h3>
											</div>
											<div class="team-social-center">
												<ul class="team-social-bar">
													<li><a href="<?php echo esc_url($facebook_url); ?>"><i class="fa fa-facebook-f"></i></a></li>
													<li><a href="<?php echo esc_url($twitter_url); ?>"><i class="fa fa-twitter"></i></a></li>
													<li><a href="<?php echo esc_url($instagram_url); ?>"><i class="fa fa-instagram"></i></a></li>
													<li><a href="<?php echo esc_url($linkedin); ?>"><i class="fa fa-linkedin"></i></a></li>
												</ul>
											</div>                                        
										</div>
								
									</div>
								</div>                                                    
								<?php
							} ?>
                        </div>
                    </div>  
                </div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style5'){ ?>
			<div class="section-full p-t80 p-b50 arc2-team-wrapper">
                <div class="section-content">
                    
                    <!-- TITLE START-->
                    <div class="section-head center wt-small-separator-outer text-center">
                        <div class="wt-small-separator site-text-primary">
                            <div class="sep-leaf-left"></div>
                            <div><?php echo esc_attr($settings['caption']); ?></div>
                            <div class="sep-leaf-right"></div>
                        </div>
                        <h2><?php echo esc_attr($settings['title']); ?></h2>
                    </div>
                    <!-- TITLE END-->
                    <div class="section-content">
                        <div class="row justify-content-center">
							<?php
							$current_size = 1;
							foreach($the_query as $query){
								$designation = get_field('designation', $query->ID);
								$facebook_url = get_field('facebook_url', $query->ID);
								$twitter_url = get_field('twitter_url', $query->ID);
								$instagram_url = get_field('instagram_url', $query->ID);
								$linkedin = get_field('linkedin', $query->ID);
								
								?>
								<div class="col-lg-3 col-md-6 col-sm-6 m-b30">
									<div class="wt-team-arc2 wt-team-arc2-no-border">
										<div class="wt-media">
											<?php echo get_the_post_thumbnail($query->ID,'full'); ?>
											<div class="team-social-center">
												<ul class="team-social-icon">
													<?php
													if(isset($facebook_url) && $facebook_url <> ''){ ?>
														<li><a href="<?php echo esc_url($facebook_url); ?>"><i class="fa fa-facebook"></i></a></li>
														<?php
													}?>
													<?php
													if(isset($twitter_url) && $twitter_url <> ''){ ?>
														<li><a href="<?php echo esc_url($twitter_url); ?>"><i class="fa fa-twitter"></i></a></li>
														<?php
													}?>
													<?php
													if(isset($instagram_url) && $instagram_url <> ''){ ?>
														<li><a href="<?php echo esc_url($instagram_url); ?>"><i class="fa fa-instagram"></i></a></li>
														<?php
													}?>
													<?php
													if(isset($linkedin) && $linkedin <> ''){ ?>
														<li><a href="<?php echo esc_url($linkedin); ?>"><i class="fa fa-linkedin"></i></a></li>
														<?php
													}?>
												</ul>
											</div>                                                
										</div>
										<div class="wt-info bg-gray-light p-a20">
											<div class="team-detail  text-center">
												<h4 class="m-t0"><?php echo esc_attr(get_the_title($query->ID)); ?></h4>
												<p><?php echo esc_attr($designation); ?></p>
											</div>
										</div>
									</div>
								</div>
								<?php
							} ?>
                        </div>
                    </div>      
                </div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style6'){ ?>
			<!-- OUR TEAM START -->
            <div class="section-full p-t90 p-b50 ">
				<div class="section-content">
					<div class="row justify-content-center d-flex">
						<div class="col-xl-8 col-lg-7 col-md-12 m-b30">
							<div class="team-carousel-wraper">
								<div class="owl-carousel team-carousel owl-btn-bottom-left">
									<?php
									$current_size = 1;
									foreach($the_query as $query){
										$designation = get_field('designation', $query->ID);
										$facebook_url = get_field('facebook_url', $query->ID);
										$twitter_url = get_field('twitter_url', $query->ID);
										$instagram_url = get_field('instagram_url', $query->ID);
										$linkedin = get_field('linkedin', $query->ID);
										
										?>	
										<div class="item">
											<div class="wt-team-2">
												<div class="wt-media">
													<?php echo get_the_post_thumbnail($query->ID,'industroz-team-new'); ?>
													<div class="team-social-center">
														<ul class="team-social-icon">
															<?php
															if(isset($facebook_url) && $facebook_url <> ''){ ?>
																<li><a href="<?php echo esc_url($facebook_url); ?>"><i class="fa fa-facebook"></i></a></li>
																<?php
															}?>
															<?php
															if(isset($twitter_url) && $twitter_url <> ''){ ?>
																<li><a href="<?php echo esc_url($twitter_url); ?>"><i class="fa fa-twitter"></i></a></li>
																<?php
															}?>
															<?php
															if(isset($instagram_url) && $instagram_url <> ''){ ?>
																<li><a href="<?php echo esc_url($instagram_url); ?>"><i class="fa fa-instagram"></i></a></li>
																<?php
															}?>
															<?php
															if(isset($linkedin) && $linkedin <> ''){ ?>
																<li><a href="<?php echo esc_url($linkedin); ?>"><i class="fa fa-linkedin"></i></a></li>
																<?php
															}?>
														</ul>
													</div>                                                
												</div> 
												<div class="wt-info">
													<div class="team-detail  text-center">
														<h3 class="m-t0 m-b15"><?php echo esc_attr(get_the_title($query->ID)); ?></h3>
														<p><?php echo esc_attr($designation); ?></p>
													</div>
												</div>
											</div>
										</div>
										<?php
									} ?>
								</div>
							</div>
						</div> 
						<div class="col-xl-4 col-lg-5 col-md-12 m-b30">
							<!-- TITLE START-->
							<div class="section-head left wt-small-separator-outer">
								<div class="wt-small-separator site-text-primary">
									<div><?php echo esc_attr($settings['caption']); ?></div>                                
								</div>
								<h2 class="wt-title"><?php echo esc_attr($settings['title']); ?></h2>
								<p><?php echo esc_attr($settings['description']); ?></p>
								<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
							</div>                  
							<!-- TITLE END-->
						</div>                        
					</div>      
				</div> 
            </div>
			<?php
		}
		wp_reset_postdata();
	}
}