<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Testimonials extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Testimonials', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'testimonials',
			[
				'label' => __( 'Testimonials', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1' => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
					'style3' => __( 'Style 3', 'gridvalley-core' ),
					'style4' => __( 'Style 4', 'gridvalley-core' ),
					'style5' => __( 'Style 5', 'gridvalley-core' ),
					'style6' => __( 'Style 6', 'gridvalley-core' ),
					'style7' => __( 'Style 7', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'section_bg_title',
			[
				'label' => __( 'Section Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style2'],
				]
			]
		);
		
		$this->add_control(
			'element_title',
			[
				'label' => __( 'Element Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		$this->add_control(
			'element_caption',
			[
				'label' => __( 'Element Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'description',
			[
				'label' => __('Description', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1','style4'],
				]
			]
		);
		
		$this->add_control(
			'button_text',
			[
				'label' => __('Button Text', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1','style4'],
				]
			]
		);
		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button Url', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'gridvalley-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition' => [
					'select_style' => [ 'style1','style4'],
				]
			]
		);
		
		$this->add_control(
			'section_image',
			[
				'label' => __('Section Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => ['style2','style5','style6'],
				]
			]
		);
		
		$this->add_control(
			'contact_form',
			[
				'label' => __('Contact Form Shortcode', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'description' => __( 'Enter contact form 7 shortcode from here. You can get it from Contact/Contact Forms. Leave blank to hide this.', 'gridvalley-core' ),
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => 'style2',
				]
			]
		);
		
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'name', [
				'label' => __( 'Name', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Name' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'designation', [
				'label' => __( 'Designation', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Designation' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'quote',[
				'label' => __( 'Quote', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$repeater->add_control(
			'testimonial_image',[
				'label' => __('Testimonial Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
			]
		);

		$this->add_control(
			'testimonials_repeater',
			[
				'label' => __( 'Testimonials', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'name' => __( 'Enter Name', 'gridvalley-core' ),
					],
				],
				'title_field' => '{{{ name }}}',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		if($settings['select_style'] == 'style1'){
			?>
			<!-- TESTIMONIAL SECTION START -->
			<div class="section-full  p-t80 testimonial-1-outer">
				<div class="container">
					<div class="row">
						<div class="col-lg-4 col-md-12">
							<!-- TITLE START-->
							<div class="left wt-small-separator-outer">
								<div class="wt-small-separator site-text-primary">
									<div  class="sep-leaf-left"></div>
									<div><?php echo esc_attr($settings['element_caption']); ?></div>
									<div  class="sep-leaf-right"></div>
								</div>
								<h2><?php echo esc_attr($settings['element_title']); ?></h2>
								<p><?php echo esc_attr($settings['description']); ?></p>
								<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
							</div>
							<!-- TITLE END-->                        
						</div>
						<div class="col-lg-8 col-md-12">
							<div class="testimonial-1-content-outer">
								<div class="testimonial-1-content owl-carousel  owl-btn-top-right long-arrow-next-prev">
									<?php
									foreach($settings['testimonials_repeater'] as $index => $testimonial_item){
										?>
										<div class="item">
											<div class="testimonial-1 bg-white">
												<div class="testimonial-content">
													<div class="testimonial-pic-block"> 
														<div class="testimonial-pic">
															<img src="<?php echo esc_url($testimonial_item['testimonial_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
														</div>
													</div>                                            
													<div class="testimonial-text">
														<i class="fa fa-quote-left"></i>
														<p><?php echo esc_attr($testimonial_item['quote']); ?></p>
													</div>
													<div class="testimonial-detail clearfix">
														<div class="testimonial-info">
															<span class="testimonial-name  title-style-2 site-text-secondry"><?php echo esc_attr($testimonial_item['name']); ?></span>
															<span class="testimonial-position title-style-2 site-text-primary"><?php echo esc_attr($testimonial_item['designation']); ?></span>
														</div>
													</div>
												</div>
											</div>
										</div>
										<?php
									} ?>
								</div>
							</div>                     
						</div>
				   </div>
				</div>
				<div class="hilite-large-title title-style-2">
					<span><?php echo esc_attr($settings['section_bg_title']); ?></span>
				</div>
			</div>
			
			<?php
		}else if($settings['select_style'] == 'style2'){
			if($settings['contact_form'] == ''){
				$column_class = 'col-lg-12';
			}else{
				$column_class = 'col-lg-6';
			}
			?>
			<!-- TESTIMONIAL SECTION START -->
			<div class="section-full  p-t80 p-b50 bg-white testimonial-2-outer bg-bottom-right bg-no-repeat" style="background-image:url(<?php echo esc_url($settings['section_image']['url']); ?>)">
				<div class="container">
					<div class="row d-flex justify-content-center">
						<div class="<?php echo esc_attr($column_class); ?> col-md-12 m-b30">
							<!-- TITLE START-->
							<div class="left wt-small-separator-outer">
								<div class="wt-small-separator site-text-primary">
									<div  class="sep-leaf-left"></div>
									<div><?php echo esc_attr($settings['element_caption']); ?></div>
									<div  class="sep-leaf-right"></div>
								</div>
								<h2><?php echo esc_attr($settings['element_title']); ?></h2>
							</div>
							<!-- TITLE END-->
							
							<div class="testimonial-2-content-outer">
								<div class="testimonial-2-content owl-carousel  owl-btn-bottom-right long-arrow-next-prev">
									<?php
									foreach($settings['testimonials_repeater'] as $index => $testimonial_item){
										?>
										<div class="item">
											<div class="testimonial-2 bg-white">
												<div class="testimonial-content">
													<div class="testimonial-text">
														<i class="fa fa-quote-left"></i>
														<p><?php echo esc_attr($testimonial_item['quote']); ?></p>
													</div>
													<div class="testimonial-detail clearfix">
														<div class="testimonial-pic-block"> 
															<div class="testimonial-pic">
																<img src="<?php echo esc_url($testimonial_item['testimonial_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
															</div>
														</div>                                                 
														<div class="testimonial-info">
															<span class="testimonial-name  title-style-2 site-text-secondry"><?php echo esc_attr($testimonial_item['name']); ?></span>
															<span class="testimonial-position title-style-2 site-text-primary"><?php echo esc_attr($testimonial_item['designation']); ?></span>
														</div>
													</div>
												</div>
											</div>
										</div>
										<?php
									} ?>
								</div>
							</div> 
						</div>
						<?php 
						if($settings['contact_form'] <> ''){ ?>
							<div class="col-lg-6 col-md-12 m-b30">
								<div class="home-contact-section site-bg-primary m-b30 p-a40">
									<?php echo do_shortcode($settings['contact_form']); ?>                                        
								</div>
							</div>	
							<?php
						} ?>
				   </div>
				</div>
				<div class="hilite-large-title title-style-2">
					<span><?php echo esc_attr($settings['section_bg_title']); ?></span>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style3'){ ?>
			<div class="section-full  p-t80 p-b50">
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer">
					<div class="wt-small-separator site-text-primary">
						<div  class="sep-leaf-left"></div>
						<div><?php echo esc_attr($settings['element_caption']); ?></div>
						<div  class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['element_title']); ?></h2>
				</div>
				<!-- TITLE END-->
				
				<div class="testimonial-2-content-outer">
					<div class="testimonial-3-content owl-carousel  owl-btn-vertical-center long-arrow-next-prev">
						<?php
						foreach($settings['testimonials_repeater'] as $index => $testimonial_item){
							?>
							<div class="item">
								<div class="testimonial-2 bg-white">
									<div class="testimonial-content">
										<div class="testimonial-text">
											<i class="fa fa-quote-left"></i>
											<p><?php echo esc_attr($testimonial_item['quote']); ?></p>
										</div>
										<div class="testimonial-detail clearfix">
											<div class="testimonial-pic-block"> 
												<div class="testimonial-pic">
													<img src="<?php echo esc_url($testimonial_item['testimonial_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
												</div>
											</div>                                                 
											<div class="testimonial-info">
												<span class="testimonial-name  title-style-2 site-text-secondry"><?php echo esc_attr($testimonial_item['name']); ?></span>
												<span class="testimonial-position title-style-2 site-text-primary"><?php echo esc_attr($testimonial_item['designation']); ?></span>
											</div>
										</div>
									</div>
								</div>
							</div>
							<?php
						} ?>
					</div>
				</div> 
            </div>
			<?php
		}else if($settings['select_style'] == 'style4'){ ?>
			<!-- TESTIMONIAL SECTION START -->
            <div class="section-full  p-t80 p-b50 testimonial-4-outer bg-gray-light">
				<div class="container">
				<div class="row justify-content-center">
					<div class="col-lg-6 col-md-12 m-b30 d-flex align-items-center">
						<div class="testimonial-4-left-section">
							<!-- TITLE START-->
							<div class="left wt-small-separator-outer">
								<div class="wt-small-separator site-text-primary">
									<div  class="sep-leaf-left"></div>
									<div><?php echo esc_attr($settings['element_caption']); ?></div>
									<div  class="sep-leaf-right"></div>
								</div>
								<h2><?php echo esc_attr($settings['element_title']); ?></h2>
								<p><?php echo esc_attr($settings['description']); ?></p>
								<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
							</div>
							<!-- TITLE END--> 
						</div>                       
					</div>
					<div class="col-lg-6 col-md-12 m-b30">
						<div class="testimonial-4-content-outer">
							<div class="testimonial-4-content owl-carousel  owl-btn-vertical-center long-arrow-next-prev">
								<?php
								foreach($settings['testimonials_repeater'] as $index => $testimonial_item){
									?>
									<div class="item">
										<div class="testimonial-4 bg-white">
											<div class="testimonial-content">
												<div class="testimonial-pic-block"> 
													<div class="testimonial-pic">
														<img src="<?php echo esc_url($testimonial_item['testimonial_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
													</div>
												</div>                                            
												<div class="testimonial-text">
													<p><?php echo esc_attr($testimonial_item['quote']); ?></p>
												</div>
												<div class="testimonial-detail clearfix">
													<div class="testimonial-info">
														<span class="testimonial-name  title-style-2 site-text-secondry"><?php echo esc_attr($testimonial_item['name']); ?></span>
														<span class="testimonial-position title-style-2 site-text-primary"><?php echo esc_attr($testimonial_item['designation']); ?></span>
													</div>
												</div>
											</div>
										</div>
									</div>
									<?php
								} ?>
							</div>
						</div>                     
					</div>
			   </div>
			   </div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style5'){ ?>
			<div class="section-full  p-t80 p-b50 bg-no-repeat bg-center" style="background-image:url(<?php echo esc_url($settings['section_image']['url']); ?>)">
				<!-- TITLE START-->
				<div class="section-head center wt-small-separator-outer">
					<div class="wt-small-separator site-text-primary">
						<div  class="sep-leaf-left"></div>
						<div><?php echo esc_attr($settings['element_caption']); ?></div>
						<div  class="sep-leaf-right"></div>
					</div>
					<h2><?php echo esc_attr($settings['element_title']); ?></h2>
				</div>
				<!-- TITLE END-->
                    
				<div class="testimonial-slider-two">
					<div class="testimonial-carousel-5 owl-carousel owl-theme owl-btn-bottom-center">
                        <?php
						foreach($settings['testimonials_repeater'] as $index => $testimonial_item){
							?>
                            <div class="item">
                                <div class="testimonial-slider-content clearfix">
                                    <div class="testimonial-5 clearfix">
                                        <div class="testimonial-text shadow-sm">
  
                                            <div class="testimonial-paragraph">
                                                <div class="quote-left"></div>
                                                <p><?php echo esc_attr($testimonial_item['quote']); ?></p>
                                            </div>
                                            <div class="testimonial-detail ">
                                                <h4 class="testimonial-name"><?php echo esc_attr($testimonial_item['name']); ?></h4>
                                            </div>
                                            <div class="testimonial-detail ">
                                                <span class="testimonial-position"><?php echo esc_attr($testimonial_item['designation']); ?></span>
                                            </div>
                                        </div>
                                        <div class="testimonial-pic-block"> 
                                            <div class="testimonial-pic">
                                               	<img src="<?php echo esc_url($testimonial_item['testimonial_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
                                            </div>
                                        </div>
                                    </div>                                    
                                </div>
                            </div>
                            <?php
						} ?>
					</div>
				</div> 
            </div>
			<?php
		}else if($settings['select_style'] == 'style6'){ ?>
			<!-- TESTIMONIALS SECTION START -->
            <div class="section-full bg-cover p-t80 p-b50" style="background-image:url(<?php echo esc_url($settings['section_image']['url']); ?>);">
                <div class="container">
					<div class="testimonial11-outer m-b30 bg-white">
						<!-- TITLE START-->
						<div class="section-head center wt-small-separator-outer">
							<div class="wt-small-separator site-text-primary">
								<div><?php echo esc_attr($settings['element_caption']); ?> </div>
							</div>
							<h2 class="wt-title"><?php echo esc_attr($settings['element_title']); ?></h2>
						</div>
						<!-- TITLE END-->
						<div class="section-content">
							<div class="testimonial-11-content owl-carousel owl-btn-bottom-center">
								<?php
								foreach($settings['testimonials_repeater'] as $index => $testimonial_item){ ?>   
									<!--block 5-->    
									<div class="item">
										<div class="testimonial-11">
											<div class="testimonial-content">
												<div class="testimonial-detail clearfix">
													<div class="testimonial-pic-block"> 
														<div class="testimonial-pic">
															<img src="<?php echo esc_url($testimonial_item['testimonial_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
														</div>
													</div>                                          
													<div class="testimonial-info">
														<span class="testimonial-name"><?php echo esc_attr($testimonial_item['name']); ?></span>
														<span class="testimonial-position"><?php echo esc_attr($testimonial_item['designation']); ?></span>
													</div>
												</div>
												<div class="testimonial-text">
													<p><?php echo esc_attr($testimonial_item['quote']); ?></p>
													<i class="fa fa-quote-right"></i>                                                 
												</div>
											</div>
										</div>
									</div>
									<?php
								} ?>
							</div>
						</div>
					</div>
                </div>    
            </div>
			<?php
		}else if($settings['select_style'] == 'style7'){ ?>
			<!-- TESTIMONIAL SECTION START -->
            <div class="section-full  p-t80 p-b50 testimonial-12-outer" style="background-image:url(<?php echo esc_url($settings['section_image']['url']); ?>);">
                <div class="container">
                    <!-- TITLE START-->
                    <div class="section-head center wt-small-separator-outer">
                        <div class="wt-small-separator site-text-primary">
                            <div><?php echo esc_attr($settings['element_caption']); ?></div>                                
                        </div>
                        <h2 class="wt-title"><?php echo esc_attr($settings['element_title']); ?></h2>
                    </div>
                    <!-- TITLE END-->
                </div>
                <div class="container">
                    <div class="section-content"> 
                    <div class="testimonial-12-content owl-carousel">
						<?php
						foreach($settings['testimonials_repeater'] as $index => $testimonial_item){ ?>  
                            <div class="item">
                                <div class="testimonial-12 bg-white">
                                    <div class="testimonial-content">
                                        <div class="testimonial-detail clearfix">
                                            <div class="testimonial-pic-block"> 
                                                <div class="testimonial-pic">
                                                    <img src="<?php echo esc_url($testimonial_item['testimonial_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
                                                </div>
                                            </div>                                          
                                            <div class="testimonial-info">
                                                <span class="testimonial-name"><?php echo esc_attr($testimonial_item['name']); ?> </span>
                                                <span class="testimonial-position"><?php echo esc_attr($testimonial_item['designation']); ?></span>
                                            </div>
                                        </div>
                                        <div class="testimonial-text">
                                            <p><?php echo esc_attr($testimonial_item['quote']); ?></p>
                                            <i class="fa fa-quote-right"></i>                                                
                                        </div> 
                                    </div>
                                </div>
                            </div>
							<?php
						} ?>
                        </div>
                    </div>
                </div>                
            </div>
			<?php
		}
	}
}