<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Welcome_Section extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'welcome-section';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Welcome Section', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'welcome_section',
			[
				'label' => __( 'Welcome Section', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1'  => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
					'style3' => __( 'Style 3', 'gridvalley-core' ),
					'style4' => __( 'Style 4', 'gridvalley-core' ),
					'style5' => __( 'Style 5', 'gridvalley-core' ),
					'style6' => __( 'Style 6', 'gridvalley-core' ),
					'style7' => __( 'Style 7', 'gridvalley-core' ),
					'style8' => __( 'Style 8', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		$this->add_control(
			'caption',
			[
				'label' => __( 'Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3', 'style4', 'style5', 'style7', 'style8'],
				]
			]
		);
		
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'info_title', [
				'label' => __( 'Enter Info Title', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Info Title' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'info_description', [
				'label' => __( 'Enter Info Description', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Info Description' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'info_icon', [
				'label' => __( 'Enter Info Icon Class', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Info Icon Class(Works for Style 5 only)' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);


		$this->add_control(
			'infos',
			[
				'label' => __( 'About Info', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'service_title' => __( 'About Info', 'gridvalley-core' ),
					],
				],
				'title_field' => '{{{ info_title }}}',
				'condition' => [
					'select_style' => [ 'style5', 'style6'],
				]
			]
		);
		
		$this->add_control(
			'description2',
			[
				'label' => __( 'Description 2', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => 'style5',
				]
			]
		);
		
		$this->add_control(
			'name',
			[
				'label' => __( 'Name', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => 'style1',
				]
			]
		);
		
		$this->add_control(
			'designation',
			[
				'label' => __('Designation', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => 'style1',
				]
			]
		);
		
		$this->add_control(
			'signature_image',
			[
				'label' => __('Signature Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => [ 'style1', 'style6'],
				]
			]
		);
		
		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'button_url',
			[
				'label' => __( 'Button Url', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'gridvalley-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
		
		$this->add_control(
			'since_text',
			[
				'label' => __( 'Since Text', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3'],
				]
			]
		);
		
		$this->add_control(
			'since_year',
			[
				'label' => __( 'Since Year', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3'],
				]
			]
		);
		
		$this->add_control(
			'section_image',
			[
				'label' => __('Section Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => [ 'style1', 'style2', 'style3','style5','style6','style7','style8'],
				]
			]
		);
		
		$this->add_control(
			'video_url',
			[
				'label' => __( 'Video Url', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'gridvalley-core' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition' => [
					'select_style' => [ 'style7'],
				]
			]
		);
		
		$this->add_control(
			'image_title',
			[
				'label' => __( 'Image Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style5', 'style6', 'style8'],
				]
			]
		);
		$this->add_control(
			'image_icon_class',
			[
				'label' => __( 'Image Icon Class', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style6','style8'],
				]
			]
		);
		$this->add_control(
			'image_caption',
			[
				'label' => __( 'Image Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
				'condition' => [
					'select_style' => [ 'style5','style8'],
				]
			]
		);
		
		$this->add_control(
			'section_second_image',
			[
				'label' => __('Section Second Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'select_style' => 'style2',
				]
			]
		);
		
		$this->add_control(
			'section_gallery',
			[
				'label' => __('Section Gallery', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::GALLERY,
				'condition' => [
					'select_style' => 'style4',
				]
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		global $industroz_allowed_html;
		
		if($settings['select_style'] == 'style1'){ ?>
			<div class="container">
				<div class="row">
					<div class="col-lg-6 col-md-12">
						<div class="img-colarge">
							<div class="colarge-1">
								<img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>" class="slide-righ">
							</div>
							<div class="since-year-outer">
								<div class="since-year">
									<?php
									if($settings['since_text'] <> ''){ ?>
										<span><?php echo esc_attr($settings['since_text']); ?></span>
										<?php
									} ?>
									<?php
									if($settings['since_year'] <> ''){ ?>
										<strong><?php echo esc_attr($settings['since_year']); ?></strong>
										<?php
									} ?>
									
								</div>
							</div>
						</div>
					</div>  

					<div class="col-lg-6 col-md-12">
						<div class="welcom-to-section">
							<!-- TITLE START-->
							<?php
							if($settings['caption'] <> ''){ ?>
								<div class="left wt-small-separator-outer">
									<div class="wt-small-separator site-text-primary">
										<div class="sep-leaf-left"></div>
										<div><?php echo esc_attr($settings['caption']); ?></div>
										<div class="sep-leaf-right"></div>
									</div>
								</div>	
								<?php
							} ?>
							<?php
							if($settings['title'] <> ''){ ?>
								<h2><?php echo wp_kses($settings['title'],$industroz_allowed_html); ?></h2>
								<?php
							} ?>
							<?php
							if($settings['description'] <> ''){ ?>
								<?php echo wp_kses($settings['description'],$industroz_allowed_html); ?>
								<?php
							} ?>
							
							<div class="welcom-to-section-bottom d-flex justify-content-between">
								<?php
								if($settings['button_text'] <> ''){ ?>
									<div class="welcom-btn-position">
										<a  href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
									</div>	
									<?php
								} ?>
								<?php
								if($settings['signature_image']['url'] <> ''){ ?>
								<div class="welcom-sign-pic">
									<img src="<?php echo esc_url($settings['signature_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
								</div>	
									<?php
								} ?>
								<div class="welcom-sign-info">
									<?php
									if($settings['name'] <> ''){ ?>
										<strong><?php echo esc_attr($settings['name']); ?></strong>
										<?php
									} ?>
									<?php
									if($settings['designation'] <> ''){ ?>
										<span>( <?php echo esc_attr($settings['designation']); ?> )</span>
										<?php
									} ?>
									
								</div>
							</div>   
						</div>
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style2'){
			?>
			<div class="row">
				<div class="col-lg-6 col-md-12 m-b30">
					<div class="welcom-to-section">
						<!-- TITLE START-->
						<?php
						if($settings['caption'] <> ''){ ?>
							<div class="left wt-small-separator-outer">
								<div class="wt-small-separator site-text-primary">
									<div  class="sep-leaf-left"></div>
									<div><?php echo esc_attr($settings['caption']); ?></div>
									<div  class="sep-leaf-right"></div>
								</div>
							</div>	
							<?php
						} ?>
						
						<?php
						if($settings['title'] <> ''){ ?>
							<h2><?php echo wp_kses($settings['title'],$industroz_allowed_html); ?></h2>
								
							<?php
						} ?>
						<?php
						if($settings['description'] <> ''){ ?>
							<?php echo wp_kses($settings['description'],$industroz_allowed_html); ?>
							<?php
						} ?>
						
						<?php
						if($settings['button_text'] <> ''){ ?>
							<div class="welcom-to-section-bottom d-flex justify-content-between">
								<div class="welcom-btn-position">
									<a  href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
								</div>
							</div> 	
							<?php
						} ?>
						  
					</div>
				</div>
				<div class="col-lg-6 col-md-12 m-b30">
					<div class="img-colarge2">
						<div class="colarge-2 slide-right">
							<img src="<?php echo esc_url($settings['section_second_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
						</div>
						<div class="colarge-2-1">
							<img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
						</div>
						<div class="since-year-outer2">
							<div class="since-year2">
								<?php
								if($settings['since_text'] <> ''){ ?>
									<span><?php echo esc_attr($settings['since_text']); ?></span>
									<?php
								} ?>
								
								<?php
								if($settings['since_year'] <> ''){ ?>
									<strong><?php echo esc_attr($settings['since_year']); ?></strong>
									<?php
								} ?>
								
							</div>
						</div>
						
					</div>
				</div>
			</div>
			<?php
		}else if($settings['select_style'] == 'style3'){
			?>
			<!-- ABOUT SECTION START -->
            <div class="section-full welcome-section-outer">
            	<div class="welcome-section-top bg-white p-t80 p-b40">
					<div class="container">
						<div class="row">
							<div class="col-lg-6 col-md-12">
								<div class="img-colarge-new">
									<div class="colarge-1-new">
										<img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>" class="slide-righ">
									</div>
								</div>
							</div>
							<div class="col-lg-6 col-md-12">
								<div class="welcom-to-section-new">
									<!-- TITLE START-->
									<?php
									if($settings['caption'] <> ''){ ?>
										<div class="left wt-small-separator-outer">
											<div class="wt-small-separator site-text-primary">
												<div  class="sep-leaf-left"></div>
												<div><?php echo esc_attr($settings['caption']); ?></div>
												<div  class="sep-leaf-right"></div>
											</div>
										</div>	
										<?php
									} ?>
									
									<?php
									if($settings['title'] <> ''){ ?>
										<h2><?php echo wp_kses($settings['title'],$industroz_allowed_html); ?></h2>
											
										<?php
									} ?>
									<?php
									if($settings['description'] <> ''){ ?>
										<?php echo wp_kses($settings['description'],$industroz_allowed_html); ?>
										<?php
									} ?>
									
									<?php
									if($settings['button_text'] <> ''){ ?>
										<div class="welcom-to-section-bottom d-flex justify-content-between">
											<div class="welcom-btn-position">
												<a  href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
											</div>
										</div> 	
										<?php
									} ?>
									  
								</div>
							</div>

						</div>
					</div>
                </div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style4'){
			?>
			<div class="section-full p-t80 p-b50 bg-white">
				<div class="section-content">
                    <div class="row d-flex justify-content-center flex-wrap">
                            <div class="col-lg-6 col-md-12 m-b30">
                            	<div class="arc-home-about-right masonry-wrap">
                                	<div class="row">
                                    	<?php 
										foreach($settings['section_gallery'] as $gallery){ ?>
											<div class="col-md-6 col-sm-6 masonry-item">
												<div class="wt-media m-b20  img-reflection">
													<img src="<?php echo esc_url($gallery['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
												</div>
											</div>	
											<?php
										} ?>
                                    </div>		
                                </div>
                            </div> 
                            <div class="col-lg-6 col-md-12 m-b40">
                                <div class="whatWedo-info-section">
                                    <!-- TITLE START-->
                                    <div class="left wt-small-separator-outer">
                                        <?php
										if($settings['caption'] <> ''){ ?>
											<div class="wt-small-separator site-text-primary">
												<div  class="sep-leaf-left"></div>
												<div><?php echo esc_attr($settings['caption']); ?></div>
												<div  class="sep-leaf-right"></div>
											</div>	
											<?php
										} ?>
                                        <?php
										if($settings['title'] <> ''){ ?>
											<h2><?php echo wp_kses($settings['title'],$industroz_allowed_html); ?></h2>
											<?php
										} ?>
                                        <?php
										if($settings['description'] <> ''){ ?>
											<?php echo wp_kses($settings['description'],$industroz_allowed_html); ?>
											<?php
										} ?>
                                    </div>
                                    <?php
									if($settings['button_text'] <> ''){ ?>
										<div class="welcom-to-section-bottom d-flex justify-content-between">
											<div class="welcom-btn-position">
												<a  href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
											</div>
										</div>	
										<?php
									} ?>
                                </div>                        
                            </div>
                    </div>
				</div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style5'){
			?>
			<!-- ABOUT ONE SECTION START -->
            <div class="section-full p-t80 p-b50 bg-no-repeat bg-center bg-white">
                <div class="about-section-two">
					<div class="section-content">                 
						<div class="row justify-content-center d-flex">
							<div class="col-lg-6 col-md-12 m-b30">
								<div class="about-section-two-right">
									<!-- TITLE START-->
									<div class="left wt-small-separator-outer">
										<?php
										if($settings['caption'] <> ''){ ?>
											<div class="wt-small-separator site-text-primary">
												<div  class="sep-leaf-left"></div>
												<div><?php echo esc_attr($settings['caption']); ?></div>
												<div  class="sep-leaf-right"></div>
											</div>
											<?php
										} ?>
										<?php
										if($settings['title'] <> ''){ ?>
											<h2><?php echo wp_kses($settings['title'],$industroz_allowed_html); ?></h2>
											<?php
										} ?>
										<div class="ab-two-info">
											<?php
											if($settings['description'] <> ''){ ?>
												<?php echo wp_kses($settings['description'],$industroz_allowed_html); ?>
												<?php
											} ?>
										</div>
									</div>                                    
									<!-- TITLE END-->
									<?php  
									if(isset($settings['infos']) && !empty($settings['infos'])){ ?>
										<div class="row ab-two-icon-section"> 
											<?php 
											foreach($settings['infos'] as $info){ ?>
												<div class="col-lg-6 col-md-12">
													<div class="wt-icon-box-wraper center m-b30 bg-gray p-a20">
														<span class="icon-md p-t10">
															<i class="<?php echo esc_attr($info['info_icon']); ?> site-text-primary"></i>
														</span>
														<div class="icon-content">
															<h3 class="wt-tilte"><?php echo esc_attr($info['info_title']); ?></h3>
															<p><?php echo esc_attr($info['info_description']); ?></p>
														</div>
													</div>
												
												</div>	
												<?php
											} ?>
										</div>	
										<?php
									}  ?>
									
									<div class="ab-two-info">
										<?php
										if($settings['description2'] <> ''){ ?>
											<?php echo wp_kses($settings['description2'],$industroz_allowed_html); ?>
											<?php
										} ?>
										<?php
										if($settings['button_text'] <> ''){ ?>
											<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button-secondry site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
											<?php
										} ?>
										  
									</div>
								</div>
							</div>

							<div class="col-lg-6 col-md-12 m-b30">
								<div class="about-max-two">
									<div class="about-max-two-media">
										<img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
									</div>
									<div class="about-two">
										<div class="about-year">
											<div class="about-year-info">
												<span><?php echo esc_attr($settings['image_title']); ?></span>
												<p><?php echo esc_attr($settings['image_caption']); ?></p>
											</div> 
										</div>
									</div>
								</div>
							</div>                                 
                        </div>
                    </div>
                </div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style6'){ ?>
			<!-- ABOUT ONE SECTION START -->
            <div class="section-full p-t80 p-b50 bg-no-repeat bg-center bg-white">
                <div class="about-section-three">
					<div class="section-content">                 
						<div class="row justify-content-center d-flex">
							<div class="col-lg-6 col-md-12 m-b30">
								<div class="about-max-three">
									<div class="about-max-three-media">
										<img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
									</div>
									<div class="about-three">
										<div class="about-year">
											<div class="about-year-info">
												<span class="icon-md p-t10">
													<i class="<?php echo esc_attr($settings['image_icon_class']); ?>"></i>
												</span>
												<h3 class="wt-tilte"><?php echo esc_attr($settings['image_title']); ?></h3>
											</div> 
										</div>
									</div>
								</div>
							</div>	
							<div class="col-lg-6 col-md-12 m-b30">
								<div class="about-section-three-right">
									<!-- TITLE START-->
									<div class="left wt-small-separator-outer">
										<?php
										if($settings['caption'] <> ''){ ?>
											<div class="wt-small-separator site-text-primary">
												<div  class="sep-leaf-left"></div>
												<div><?php echo esc_attr($settings['caption']); ?></div>
												<div  class="sep-leaf-right"></div>
											</div>
											<?php
										} ?>
										<?php
										if($settings['title'] <> ''){ ?>
											<h2><?php echo wp_kses($settings['title'],$industroz_allowed_html); ?></h2>
											<?php
										} ?>
									</div>                                    
									<!-- TITLE END-->
									 <!-- Accordian -->
									<?php  
									if(isset($settings['infos']) && !empty($settings['infos'])){ ?>	
										<div class="wt-accordion acc-bg-gray m-b50 about-section-three-acc" id="accordion">
											<?php 
											$custom_counter = 0;
											foreach($settings['infos'] as $info){ ?>
												<div class="panel wt-panel">
													<div class="acod-head <?php echo esc_attr($custom_counter == 0 ? 'acc-actives' : ''); ?>">
														<h5 class="acod-title">
															<a class="<?php echo esc_attr($custom_counter == 0 ? '' : 'collapsed'); ?>" data-toggle="collapse" href="#collaps-<?php echo esc_attr($custom_counter); ?>" aria-expanded="<?php echo esc_attr($custom_counter == 0 ? 'true' : 'false'); ?>" aria-controls="collapse-<?php echo esc_attr($custom_counter); ?>">
																<?php echo esc_attr($info['info_title']); ?>
																<span class="indicator"><i class="fa"></i></span>
															</a>
														</h5>
													</div>
													<div id="collapse-<?php echo esc_attr($custom_counter); ?>" class="collapse <?php echo esc_attr($custom_counter == 0 ? 'show' : ''); ?>" aria-labelledby="headingOne" data-parent="#accordion">
														<div class="acod-content p-tb15">
															<?php echo esc_attr($info['info_description']); ?>
														</div>
													</div>
												</div>
												<?php
												$custom_counter++;
											} ?>
										</div>                                    
										<?php
									} ?>
									<div class="ab-three-info d-flex justify-content-between">
									   <?php
										if($settings['button_text'] <> ''){ ?>
											<div class="welcom-btn-position m-t20">
												<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
											</div>
											<?php
										} ?>
										<img src="<?php echo esc_url($settings['signature_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
									</div>  
								</div> 
							</div>
						</div>
					</div> 
                </div>
            </div> 
			<?php
		}else if($settings['select_style'] == 'style7'){ ?>
			<!-- ABOUT ONE SECTION START -->
            <div class="section-full p-t90 p-b50 bg-no-repeat bg-bottom-left" >
            	<div class="about-section-11">
                    <div class="container">
                        <div class="section-content">                 
                            <div class="row justify-content-center d-flex">
                            
                                <div class="col-lg-6 col-md-12 m-b30">
                                    <div class="about-section-11-right">
                                        <!-- TITLE START-->
                                        <div class="section-head left wt-small-separator-outer">
                                            <div class="wt-small-separator site-text-primary">
                                                <div><?php echo esc_attr($settings['caption']); ?></div>
                                            </div>
                                            <h2><?php echo wp_kses($settings['title'],$industroz_allowed_html); ?></h2>
                                        </div>
                                        <!-- TITLE END-->

                                        
										<?php
										if($settings['description'] <> ''){ ?>
											<div class="about-one">
												<?php echo wp_kses($settings['description'],$industroz_allowed_html); ?>
											</div>
											<?php
										} ?>
                                        <a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a> 
                                   </div>
                               </div>
                                <div class="col-lg-6 col-md-12 m-b30 about-max-12-position">
                                    <div class="about-max-12">
                                        <span class="ipad-pencil"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/assets/images/ipad-pencil.png" class="ipad-pencil-jump"></span>
                                        <div class="ser-ipad-warp">
                                            <span class="ser-ipad-cam"></span>
                                            <div class="ser-ipad-pic" style="background-image:url(<?php echo esc_url($settings['section_image']['url']); ?>)">
                                              <div class="ser-ipad-overlay"></div>
                                              <a href="<?php echo esc_url($settings['video_url']['url']); ?>" class="mfp-video play-now-video">
                                                <i class="icon fa fa-play"></i>
                                                <span class="ripple"></span>
                                            </a>
                                            </div>
                                            <span class="ser-ipad-btn"></span>
                                        </div>
                                    </div>
                                </div>
                           </div>
                        </div> 
                    </div>
                </div>
            </div>
			<?php
		}else if($settings['select_style'] == 'style8'){ ?>
			<div class="section-full p-t80 p-b50 bg-no-repeat bg-bottom-left">
            	<div class="about-section-11">
					<div class="section-content">                 
						<div class="row justify-content-center d-flex">
						
							<div class="col-lg-6 col-md-12 m-b30 about-max-11-position">
								<div class="about-max-11">
									<div class="about-max-11-media"><img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="img"></div>
									<div class="ab-call-us">
										<div class="wt-icon-box-wraper left bg-white p-a30">
											<div class="icon-xl text-primary radius">
												<span class="icon-cell  site-text-primary"><i class="<?php echo esc_attr($settings['image_icon_class']); ?>"></i></span>
											</div>
											<div class="icon-content">
												<h3 class="wt-tilte text-uppercase"><?php echo esc_attr($settings['image_title']); ?></h3>
												<p><?php echo esc_attr($settings['image_caption']); ?></p>
											</div>
										</div>
									</div>
								</div>
							</div>  
							<div class="col-lg-6 col-md-12 m-b30">
								<div class="about-section-11-right">
									<!-- TITLE START-->
									<div class="section-head left wt-small-separator-outer">
										<div class="wt-small-separator site-text-primary">
											<div><?php echo esc_attr($settings['caption']); ?></div>
										</div>
										<h2><?php echo wp_kses($settings['title'],$industroz_allowed_html); ?></h2>
									</div>
									<!-- TITLE END-->

									<?php
									if($settings['description'] <> ''){ ?>
										<div class="about-one">
											<?php echo wp_kses($settings['description'],$industroz_allowed_html); ?>
										</div>
										<?php
									} ?>
									<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="site-button site-btn-effect"><?php echo esc_attr($settings['button_text']); ?></a>
								</div>
							</div>
						</div>
					</div> 
                </div>
            </div>
			<?php
		}
	}

}