<?php
namespace ElementorGridValley\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class What_We_Do extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'what-we-do';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'What We Do', 'gridvalley-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-industry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'industroz' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'what_we_do',
			[
				'label' => __( 'What We Do', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => [
					'style1'  => __( 'Style 1', 'gridvalley-core' ),
					'style2' => __( 'Style 2', 'gridvalley-core' ),
				],
			]
		);
		
		$this->add_control(
			'section_bg_title',
			[
				'label' => __( 'Section Background Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		$this->add_control(
			'caption',
			[
				'label' => __( 'Caption', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'service_title', [
				'label' => __( 'Enter Service Title', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Service Title' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'service_description', [
				'label' => __( 'Enter Service Description', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Service Description' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'service_icon', [
				'label' => __( 'Enter Service Icon Class', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Service Icon Class' , 'gridvalley-core' ),
				'label_block' => true,
			]
		);


		$this->add_control(
			'services',
			[
				'label' => __( 'Services', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'service_title' => __( 'Enter Service Title', 'gridvalley-core' ),
					],
				],
				'title_field' => '{{{ service_title }}}',
			]
		);
		
		$this->add_control(
			'image_title',
			[
				'label' => __( 'Image Title', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'image_description',
			[
				'label' => __('Image Description', 'gridvalley-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '', 'gridvalley-core' ),
			]
		);
		
		$this->add_control(
			'section_image',
			[
				'label' => __('Section Image', 'gridvalley-core' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'image_title', 'none' );
		$this->add_inline_editing_attributes( 'image_description', 'none' );
		$this->add_inline_editing_attributes( 'title', 'none' );
		$this->add_inline_editing_attributes( 'caption', 'none' );
		$this->add_inline_editing_attributes( 'description', 'none' );
		
		if($settings['select_style'] == 'style1'){ ?>
			<div class="section-full p-t80 p-b60 what-we-do-section">
				<div class="container">                      
					<div class="section-content what-we-do-content">
						<div class="row">
							<div class="col-lg-6 col-md-12">
								<div class="whatWedo-media-section">
									<div class="wt-media">
										<img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
									</div>
									<div class="whatWedo-media-content text-white">
										<div class="whatWedo-media-inner">
											<h3 <?php echo $this->get_render_attribute_string( 'image_title' ); ?>><?php echo $settings['image_title']; ?></h3>
											<p <?php echo $this->get_render_attribute_string( 'image_description' ); ?>><?php echo $settings['image_description']; ?></p>
										</div>
									</div>
								</div>
							</div> 

							<div class="col-lg-6 col-md-12">
								<div class="whatWedo-info-section">
									<!-- TITLE START-->
									<div class="left wt-small-separator-outer">
										<div class="wt-small-separator site-text-primary">
											<div class="sep-leaf-left"></div>
											<div <?php echo $this->get_render_attribute_string( 'caption' ); ?>><?php echo $settings['caption']; ?></div>
											<div class="sep-leaf-right"></div>
										</div>
										<h2 <?php echo $this->get_render_attribute_string( 'title' ); ?>><?php echo $settings['title']; ?></h2>
										<p <?php echo $this->get_render_attribute_string( 'description' ); ?>><?php echo $settings['description']; ?></p>

									</div>
									<!-- TITLE END-->
									<div class="wt-icon-card-outer">
										<?php
										foreach($settings['services'] as $index => $service_item){
											?>
											<div class="wt-icon-card bg-white shadow">
												<div class="wt-card-header">
													<i class="<?php echo esc_attr($service_item['service_icon']); ?> site-text-primary"></i>
													<span class="title-style-2 site-text-secondry"><?php echo $service_item['service_title']; ?></span>
												</div>
												<div class="wt-card-content"><p><?php echo $service_item['service_description']; ?></p></div>
											</div>
											<?php
										} ?>
									</div>
								</div>                        
							</div> 
						</div>
					</div>                                        
				</div>
			</div>
			<?php
		}else{ ?>
			<!-- WHAT WE DO SECTION START -->
            <div class="section-full p-t80 p-b40 bg-white what-we-do-section2-new">
				<div class="container">   
				<div class="section-content what-we-do-content-new">
					<div class="row d-flex justify-content-center flex-wrap">
						<div class="col-lg-6 col-md-12 m-b30">
							<div class="whatWedo-media-section-new">
								<div class="wt-media">
									<img src="<?php echo esc_url($settings['section_image']['url']); ?>" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
								</div>
								<div class="whatWedo-media-content-new text-white">
									<div class="whatWedo-media-inner-new site-bg-primary">
										<h3 <?php echo $this->get_render_attribute_string( 'image_title' ); ?>><?php echo $settings['image_title']; ?></h3>
										<p <?php echo $this->get_render_attribute_string( 'image_description' ); ?>><?php echo $settings['image_description']; ?></p>
									</div>
								</div>
							</div>
						</div>
						<div class="col-lg-6 col-md-12 m-b40">
							<div class="whatWedo-info-section-new">
								<!-- TITLE START-->
								<div class="left wt-small-separator-outer">
									<div class="wt-small-separator site-text-primary">
										<div  class="sep-leaf-left"></div>
										<div <?php echo $this->get_render_attribute_string( 'caption' ); ?>><?php echo $settings['caption']; ?></div>
										<div  class="sep-leaf-right"></div>
									</div>
									<h2 <?php echo $this->get_render_attribute_string( 'title' ); ?>><?php echo $settings['title']; ?></h2>
									<p <?php echo $this->get_render_attribute_string( 'description' ); ?>><?php echo $settings['description']; ?></p>
									
								</div>
								<!-- TITLE END-->
								<div class="wt-icon-card-outer-new">
									<?php
									foreach($settings['services'] as $index => $service_item){
										?>
										<div class="wt-icon-card-new bg-gray-light">
											<div class="wt-card-header-new">
												<i class="<?php echo esc_attr($service_item['service_icon']); ?> site-text-primary"></i>
												<span class="title-style-2 site-text-secondry"><?php echo $service_item['service_title']; ?></span>
											</div>
											<div class="wt-card-content-new">
												<p><?php echo $service_item['service_description']; ?></p>
											</div>
										</div>
										<?php
									} ?>
								</div>
							</div>                        
						</div> 
					</div>
				</div> 
				</div> 
            </div> 
			<?php
		}
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _content_template() {
		
		?>
		<#
		view.addInlineEditingAttributes( 'image_title', 'none' );
		view.addInlineEditingAttributes( 'image_description', 'none' );
		view.addInlineEditingAttributes( 'title', 'none' );
		view.addInlineEditingAttributes( 'caption', 'none' );
		view.addInlineEditingAttributes( 'description', 'none' );
		#>
		
		<#
		if ( 'style1' === settings.select_style) { #>
			<div class="section-full p-t80 p-b60 what-we-do-section">
				<div class="container">                      
					<div class="section-content what-we-do-content">
						<div class="row">
							<div class="col-lg-6 col-md-12">
								<div class="whatWedo-media-section">
									<div class="wt-media">
										<img src="{{{ settings.section_image.url }}}" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
									</div>
									<div class="whatWedo-media-content text-white">
										<div class="whatWedo-media-inner">
											<h3 {{{ view.getRenderAttributeString( 'image_title' ) }}}>{{{ settings.image_title }}}</h3>
											<p {{{ view.getRenderAttributeString( 'image_description' ) }}}>{{{ settings.image_description }}}</p>
										</div>
									</div>
								</div>
							</div> 

							<div class="col-lg-6 col-md-12">
								<div class="whatWedo-info-section">
									<!-- TITLE START-->
									<div class="left wt-small-separator-outer">
										<div class="wt-small-separator site-text-primary">
											<div class="sep-leaf-left"></div>
											<div {{{ view.getRenderAttributeString( 'caption' ) }}}>{{{ settings.caption }}}</div>
											<div class="sep-leaf-right"></div>
										</div>
										<h2 {{{ view.getRenderAttributeString( 'title' ) }}}>{{{ settings.title }}}</h2>
										<p {{{ view.getRenderAttributeString( 'description' ) }}}>{{{ settings.description }}}</p>

									</div>
									<!-- TITLE END-->
									<div class="wt-icon-card-outer">
										<#
										if ( settings.services ) {
											_.each( settings.services, function( item, index ) {
											#>
											<div class="wt-icon-card bg-white shadow">
												<div class="wt-card-header">
													<i class="{{{ item.service_icon }}} site-text-primary"></i>
													<span class="title-style-2 site-text-secondry">{{{ item.service_title }}}</span>
												</div>
												<div class="wt-card-content"><p>{{{ item.service_description }}}</p></div>
											</div>
											<#
											} );
										}
										#>
									</div>
								</div>                        
							</div> 


						</div>
					</div>                                        
				</div>
			</div>
		<# } else if ( 'style2' === settings.select_style) { #>
			<div class="section-full p-t80 p-b40 bg-white what-we-do-section2-new">
				<div class="container">   
				<div class="section-content what-we-do-content-new">
					<div class="row d-flex justify-content-center flex-wrap">
						<div class="col-lg-6 col-md-12 m-b30">
							<div class="whatWedo-media-section-new">
								<div class="wt-media">
									<img src="{{{ settings.section_image.url }}}" alt="<?php echo esc_attr__('img','gridvalley-core'); ?>">
								</div>
								<div class="whatWedo-media-content-new text-white">
									<div class="whatWedo-media-inner-new site-bg-primary">
										<h3 {{{ view.getRenderAttributeString( 'image_title' ) }}}>{{{ settings.image_title }}}</h3>
										<p {{{ view.getRenderAttributeString( 'image_description' ) }}}>{{{ settings.image_description }}}</p>
									</div>
								</div>
							</div>
						</div>
						<div class="col-lg-6 col-md-12 m-b40">
							<div class="whatWedo-info-section-new">
								<!-- TITLE START-->
								<div class="left wt-small-separator-outer">
									<div class="wt-small-separator site-text-primary">
										<div  class="sep-leaf-left"></div>
										<div {{{ view.getRenderAttributeString( 'caption' ) }}}>{{{ settings.caption }}}</div>
										<div  class="sep-leaf-right"></div>
									</div>
									<h2 {{{ view.getRenderAttributeString( 'title' ) }}}>{{{ settings.title }}}</h2>
									<p {{{ view.getRenderAttributeString( 'description' ) }}}>{{{ settings.description }}}</p>
								</div>
								<!-- TITLE END-->
								<div class="wt-icon-card-outer-new">
									<#
									if ( settings.services ) {
										_.each( settings.services, function( item, index ) {
										#>
										<div class="wt-icon-card-new bg-gray-light">
											<div class="wt-card-header-new">
												<i class="{{{ item.service_icon }}} site-text-primary"></i>
												<span class="title-style-2 site-text-secondry">{{{ item.service_title }}}</span>
											</div>
											<div class="wt-card-content-new"><p>{{{ item.service_description }}}</p></div>
										</div>
										<#
										} );
									}
									#>
								</div>
							</div>                        
						</div> 
					</div>
				</div> 
				</div> 
            </div> 
		<# } #>
		<?php
	}
}