<?php if ( ! defined( 'ABSPATH' ) ) { die( 'Direct access forbidden.' ); }
	
add_action( 'widgets_init', 'industroz_services_widget' );
if( !function_exists('industroz_services_widget') ){
	function industroz_services_widget() {
		register_widget( 'Widget_Services' );
	}
}	
	
class Widget_Services extends WP_Widget {

	/**
	 * @internal
	 */
	public function __construct() {
		$widget_ops = array( 'description' => '' );
		parent::__construct( false, esc_attr__( 'Industroz: Services', 'gridvalley-core' ), $widget_ops );
	}

	/**
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		extract( $args );
		
		$title = apply_filters( 'widget_title', $instance['title'] );
		$category = $instance['category'];
		$service_style = $instance['service_style'];
		$num_fetch = $instance['num_fetch'];
		$order = $instance['order'];
		$orderby = $instance['orderby'];
		
		$current_post = get_the_ID();		
		$query_args = array('post_type' => 'services');
		$query_args['posts_per_page'] = $num_fetch;
		$query_args['orderby'] = $orderby;
		$query_args['order'] = $order;
		$query_args['services_category'] = $category;
		$query = new WP_Query( $query_args );
		
		include ('views/widget.php');
	}

	/**
	 * @param array $new_instance
	 * @param array $old_instance
	 *
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		return $new_instance;
	}

	/**
	 * @param array $instance
	 *
	 * @return string|void
	 */
	public function form( $instance ) {
		$title = isset($instance['title'])? $instance['title']: '';
		$category = isset($instance['category'])? $instance['category']: '';
		$service_style = isset($instance['service_style'])? $instance['service_style']: '';
		$num_fetch = isset($instance['num_fetch'])? $instance['num_fetch']: 3;
		$order = isset($instance['order'])? $instance['order']: 'DESC';
		$orderby = isset($instance['orderby'])? $instance['orderby']: 'date';
		?>
		<!-- Post Category -->
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('service_style')); ?>"><?php echo esc_attr__('Style :', 'gridvalley-core'); ?></label>		
			<select class="widefat" name="<?php echo esc_attr($this->get_field_name('service_style')); ?>" id="<?php echo esc_attr($this->get_field_id('service_style')); ?>">
				<option value="style-1" <?php if ($service_style == 'style-1'){ echo esc_attr__(' selected ','gridvalley-core');} ?>><?php echo esc_attr__('Style 1', 'gridvalley-core') ?></option>
				<option value="style-2" <?php if ($service_style == 'style-2'){ echo esc_attr__(' selected ','gridvalley-core');} ?>><?php echo esc_attr__('Style 2', 'gridvalley-core') ?></option>
			</select> 
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php echo esc_attr__('Title :', 'gridvalley-core'); ?></label> 
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>		

		<!-- Post Category -->
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('category')); ?>"><?php echo esc_attr__('Category :', 'gridvalley-core'); ?></label>		
			<select class="widefat" name="<?php echo esc_attr($this->get_field_name('category')); ?>" id="<?php echo esc_attr($this->get_field_id('category')); ?>">
				<option value="" <?php if(empty($category)) echo esc_attr__(' selected ','gridvalley-core'); ?>><?php echo esc_attr__('All', 'gridvalley-core') ?></option>
				<?php 	
				$category_list = get_terms('services_category');
				foreach($category_list as $term){ ?>
					<option value="<?php echo esc_attr($term->slug); ?>" <?php if ($category == $term->slug){ echo esc_attr__(' selected ','gridvalley-core');} ?>><?php echo esc_attr($term->name); ?></option>				
					<?php 
				} ?>	
			</select> 
		</p>
			
		<!-- Show Num --> 
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('num_fetch')); ?>"><?php echo esc_attr__('Num Fetch :', 'gridvalley-core'); ?></label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id('num_fetch')); ?>" name="<?php echo esc_attr($this->get_field_name('num_fetch')); ?>" type="text" value="<?php echo esc_attr($num_fetch); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('order')); ?>"><?php echo esc_attr__('Order :', 'gridvalley-core'); ?></label>		
			<select class="widefat" name="<?php echo esc_attr($this->get_field_name('order')); ?>" id="<?php echo esc_attr($this->get_field_id('order')); ?>">
				<option value="ASC" <?php if ($order == 'ASC'){ echo esc_attr__(' selected ','gridvalley-core');} ?>><?php echo esc_attr__('ASC', 'gridvalley-core') ?></option>
				<option value="DESC" <?php if ($order == 'DESC'){ echo esc_attr__(' selected ','gridvalley-core');} ?>><?php echo esc_attr__('DESC', 'gridvalley-core') ?></option>
			</select> 
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('orderby')); ?>"><?php echo esc_attr__('Orderby :', 'gridvalley-core'); ?></label>		
			<select class="widefat" name="<?php echo esc_attr($this->get_field_name('orderby')); ?>" id="<?php echo esc_attr($this->get_field_id('orderby')); ?>">
				<option value="title" <?php if ($orderby == 'title'){ echo esc_attr__(' selected ','gridvalley-core');} ?>><?php echo esc_attr__('Title', 'gridvalley-core') ?></option>
				<option value="name" <?php if ($orderby == 'name'){ echo esc_attr__(' selected ','gridvalley-core');} ?>><?php echo esc_attr__('Name', 'gridvalley-core') ?></option>
				<option value="date" <?php if ($orderby == 'date'){ echo esc_attr__(' selected ','gridvalley-core');} ?>><?php echo esc_attr__('Post Date', 'gridvalley-core') ?></option>
				<option value="rand" <?php if ($orderby == 'rand'){ echo esc_attr__(' selected ','gridvalley-core');} ?>><?php echo esc_attr__('Random', 'gridvalley-core') ?></option>
				<option value="comment_count" <?php if ($orderby == 'comment_count'){ echo esc_attr__(' selected ','gridvalley-core');} ?>><?php echo esc_attr__('Comment Count', 'gridvalley-core') ?></option>
			</select> 
		</p>
		<?php
	}
}