<?php
	/**
	 * Custom Includes this theme.
	 *
	 * @package WordPress
	 * @subpackage Industroz
	 * @since 1.0.0
	 */
	
	require get_template_directory() . '/inc/template-tags.php';
	// Custom comment walker.
	require get_template_directory() . '/classes/class-industroz-walker-comment.php';
	// styles-scripts.
	require get_template_directory() . '/inc/register-scripts.php';
	// color-scheme.
	require get_template_directory() . '/inc/color-scheme.php';
	// Widget Areas
	require get_template_directory() . '/inc/register-widget-areas.php';
	// TGM Library
	require get_template_directory() . '/inc/tgmpa/tgm_plugins.php';

	/**
	 * @param FW_Ext_Backups_Demo[] $demos
	 * @return FW_Ext_Backups_Demo[]
	 */
	function industroz_filter_theme_fw_ext_backups_demos($demos) {
		$demos_array = array(
			'industroz-dummy' => array(
				'title' => esc_attr__('Industroz', 'industroz'),
				'screenshot' => get_template_directory_uri() . '/screenshot.png',
				'preview_link' => 'https://gridvalley.net/wp/industroz'
			),
			'industroz-industry-dummy' => array(
				'title' => esc_attr__('Industry / Industry New Layout', 'industroz'),
				'screenshot' => get_template_directory_uri() . '/assets/images/industroz-industry.png',
				'preview_link' => 'https://gridvalley.net/wp/industroz/industry'
			),
			'industroz-construction-dummy' => array(
				'title' => esc_attr__('Construction', 'industroz'),
				'screenshot' => get_template_directory_uri() . '/assets/images/industroz-construction.png',
				'preview_link' => 'https://gridvalley.net/wp/industroz/construction'
			),
			'industroz-transport-dummy' => array(
				'title' => esc_attr__('Transport / Factory Layout', 'industroz'),
				'screenshot' => get_template_directory_uri() . '/assets/images/industroz-transport.png',
				'preview_link' => 'https://gridvalley.net/wp/industroz/transport'
			),
			'industroz-agriculture-dummy' => array(
				'title' => esc_attr__('Agriculture', 'industroz'),
				'screenshot' => get_template_directory_uri() . '/assets/images/agriculture.png',
				'preview_link' => 'https://gridvalley.net/wp/industroz/agriculture'
			),
			'industroz-solar-energy-dummy' => array(
				'title' => esc_attr__('Solar Energy', 'industroz'),
				'screenshot' => get_template_directory_uri() . '/assets/images/solar-energy.png',
				'preview_link' => 'https://gridvalley.net/wp/industroz/solar-energy'
			),
			'industroz-oil-gas-dummy' => array(
				'title' => esc_attr__('Oil Gas Plant', 'industroz'),
				'screenshot' => get_template_directory_uri() . '/assets/images/oil-gas-plant.png',
				'preview_link' => 'https://gridvalley.net/wp/industroz/oil-gas-plant'
			),
			'industroz-air-conditioning-repair' => array(
				'title' => esc_attr__('Air Conditioning Repair / Construction New Layout', 'industroz'),
				'screenshot' => get_template_directory_uri() . '/assets/images/air-conditioning-repair.png',
				'preview_link' => 'https://gridvalley.net/wp/industroz/air-conditioning-repair'
			)
			// ...
		);

		$download_url = 'https://gridvalley.net/industroz_importer/';

		foreach ($demos_array as $id => $data) {
			$demo = new FW_Ext_Backups_Demo($id, 'piecemeal', array(
				'url' => $download_url,
				'file_id' => $id,
			));
			$demo->set_title($data['title']);
			$demo->set_screenshot($data['screenshot']);
			$demo->set_preview_link($data['preview_link']);

			$demos[ $demo->get_id() ] = $demo;

			unset($demo);
		}

		return $demos;
	}
	add_filter('fw:ext:backups-demo:demos', 'industroz_filter_theme_fw_ext_backups_demos');
	
	/**
	 * Overwrite default more tag with styling and screen reader markup.
	 *
	 * @param string $html The default output HTML for the more tag.
	 *
	 * @return string $html
	 */
	if(!function_exists('industroz_read_more_tag')){
		function industroz_read_more_tag( $html ) {
			return preg_replace( '/<a(.*)>(.*)<\/a>/iU', sprintf( '<div class="read-more-button-wrap"><a$1><span class="faux-button">$2</span> <span class="screen-reader-text">"%1$s"</span></a></div>', esc_attr(get_the_title( get_the_ID() ) )), $html );
		}
	}

	add_filter( 'the_content_more_link', 'industroz_read_more_tag' );
	/**
	 * Register custom fonts.
	 */
	if(!function_exists('industroz_fonts_url')){
		function industroz_fonts_url() {
			$fonts_url = '';
			$font_families = array();
			$font_families[] = 'Teko:300,400,500,600,700';
			$font_families[] = 'Roboto:100,100i,300,300i,400,400i,500,500i,700,700i,900,900i';
			$font_families[] = 'Poppins:300,300i,400,400i,600,600i,500,500i,700,700i,900,900i';

			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => '',
			);

			$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
			
			return esc_url_raw( $fonts_url );
		}
	}
	
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	
	if(!function_exists('industroz_theme_support')){
		function industroz_theme_support() {

			// Add default posts and comments RSS feed links to head.
			add_theme_support( 'automatic-feed-links' );
			
			if(class_exists('WooCommerce')){
				add_theme_support( 'woocommerce' );
				add_theme_support( 'wc-product-gallery-zoom' );
				add_theme_support( 'wc-product-gallery-lightbox' );
				add_theme_support( 'wc-product-gallery-slider' );
			}
			
			// Custom background color.
			add_theme_support(
				'custom-background',
				array(
					'default-color' => 'f5efe0',
				)
			);

			// Set content-width.
			global $content_width;
			if ( ! isset( $content_width ) ) {
				$content_width = 580;
			}

			/*
			 * Enable support for Post Thumbnails on posts and pages.
			 *
			 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
			 */
			add_theme_support( 'post-thumbnails' );

			// Set post thumbnail size.
			set_post_thumbnail_size( 1200, 9999 );

			// Add custom image size used in industroz.
			add_image_size( 'industroz-fullscreen', 1980, 9999, true );
			add_image_size( 'industroz-news-grid', 447, 268, true );
			add_image_size( 'industroz-projects-masonary', 235, 282, true );
			add_image_size( 'industroz-projects-carousel', 366, 416, true );
			add_image_size( 'industroz-projects-carousel2', 373, 469, true );
			add_image_size( 'industroz-projects-medium', 500, 500, true );
			add_image_size( 'industroz-news-medium', 486, 503, true );
			add_image_size( 'industroz-news-grid-new', 480, 310, true );
			add_image_size( 'industroz-news-projects-new', 370, 518, true );
			add_image_size( 'industroz-projects-new-carousel', 257, 310, true );
			add_image_size( 'industroz-news-large-grid', 524, 563, true );
			add_image_size( 'industroz-services-grid-new', 350, 379, true );
			add_image_size( 'industroz-services-tabs', 373, 404, true );
			add_image_size( 'industroz-services-half', 333, 360, true );
			add_image_size( 'industroz-team-new', 320, 410, true );
			add_image_size( 'industroz-news-vertical', 274, 352, true );
			// Custom logo.
			$logo_width  = 120;
			$logo_height = 90;

			// If the retina setting is active, double the recommended width and height.
			if ( get_theme_mod( 'retina_logo', false ) ) {
				$logo_width  = floor( $logo_width * 2 );
				$logo_height = floor( $logo_height * 2 );
			}

			add_theme_support(
				'custom-logo',
				array(
					'height'      => $logo_height,
					'width'       => $logo_width,
					'flex-height' => true,
					'flex-width'  => true,
				)
			);

			/*
			 * Let WordPress manage the document title.
			 * By adding theme support, we declare that this theme does not use a
			 * hard-coded <title> tag in the document head, and expect WordPress to
			 * provide it for us.
			 */
			add_theme_support( 'title-tag' );

			/*
			 * Switch default core markup for search form, comment form, and comments
			 * to output valid HTML5.
			 */
			add_theme_support(
				'html5',
				array(
					'search-form',
					'comment-form',
					'comment-list',
					'gallery',
					'caption',
					'script',
					'style',
				)
			);

			// Add support for full and wide align images.
			add_theme_support( 'align-wide' );

			// Add theme support for selective refresh for widgets.
			add_theme_support( 'customize-selective-refresh-widgets' );

		}	
	} 
	
	add_action( 'after_setup_theme', 'industroz_theme_support' );

	add_action( 'init', 'industroz_load_theme_textdomain' );
  
	/**
	 * Load theme textdomain.
	 */
	function industroz_load_theme_textdomain() {
	  load_theme_textdomain( 'industroz', get_template_directory() . '/languages' ); 
	}
	global $industroz_allowed_html;
	$industroz_allowed_html = 
		array(
		'a' => array(
				'id' => array(),
				'class' => array(),
				'rel' => array(),
				'data-commentid' => array(),
				'data-postid' => array(),
				'data-belowelement' => array(),
				'data-respondelement' => array(),
				'aria-label' => array(),
				'href' => array(),
				'title' => array()
			),
		'div' => array('id' => array(),'class' => array()),
		'h1' => array('id' => array(),'class' => array()),
		'h2' => array('id' => array(),'class' => array()),
		'h3' => array('id' => array(),'class' => array()),
		'h4' => array('id' => array(),'class' => array()),
		'h5' => array('id' => array(),'class' => array()),
		'h6' => array('id' => array(),'class' => array()),
		'p' => array('id' => array(),'class' => array()),
		'i' => array('id' => array(),'class' => array()),
		'ins' => array('id' => array(),'class' => array()),
		'ul' => array('id' => array(),'class' => array()),
		'del' => array('id' => array(),'class' => array()),
		'li' => array('id' => array(),'class' => array()),
		'span' => array('id' => array(),'class' => array()),
		'br' => array(),
		'em' => array(),
		'strong' => array(),
	);

	if( function_exists('acf_add_options_page') ) {
		
		acf_add_options_page(array(
			'page_title' 	=> esc_attr__('Theme Options','industroz'),
			'menu_title'	=> esc_attr__('Theme Options','industroz'),
			'menu_slug' 	=> 'theme-general-Options',
			'capability'	=> 'edit_posts',
			'redirect'		=> false
		));
	}

	/**
	 * Register navigation menus uses wp_nav_menu in five places.
	 */
	if(!function_exists('industroz_menus')){
		function industroz_menus() {

			$locations = array(
				'primary'  => esc_attr__( 'Main Menu', 'industroz' ),
				'footer_menu'  => esc_attr__( 'Footer Menu', 'industroz' ),
			);

			register_nav_menus( $locations );
		}	
	}
	

	add_action( 'init', 'industroz_menus' );
	
	add_filter('wp_generate_tag_cloud', 'gridvalley_tag_cloud',10,3);

	function gridvalley_tag_cloud($tag_string){
	  return preg_replace('/style=("|\')(.*?)("|\')/','',$tag_string);
	}

	if ( ! function_exists( 'wp_body_open' ) ) {

		/**
		 * Shim for wp_body_open, ensuring backwards compatibility with versions of WordPress older than 5.2.
		 */
		function wp_body_open() {
			do_action( 'wp_body_open' );
		}
	}

	// Breadcrumbs
	if(!function_exists('industroz_breadcrumbs')){
		function industroz_breadcrumbs() {
			   
			// Settings
			$separator          = '';
			$breadcrums_id      = 'breadcrumbs';
			$breadcrums_class   = 'wt-breadcrumb breadcrumb-style-2';
			$home_title         = esc_attr__('Home','industroz');
			  
			// Get the query & post information
			global $post,$wp_query,$industroz_allowed_html;
			   
			// Do not display on the homepage
			if ( !is_front_page() ) {
			   
				// Build the breadcrums
				echo '<ul id="' . esc_attr($breadcrums_id) . '" class="' . esc_attr($breadcrums_class) . '">';
				   
				// Home page
				echo '<li class="item-home"><a class="bread-link bread-home" href="' . esc_url(get_home_url()) . '" title="' . esc_attr($home_title) . '">' . esc_attr($home_title) . '</a></li>';
				
				   
				if ( is_archive() && !is_tax() && !is_category() && !is_tag() ) {
					  
					echo '<li class="item-current item-archive"><strong class="bread-current bread-archive">' . get_the_archive_title() . '</strong></li>';
					  
				} else if ( is_archive() && is_tax() && !is_category() && !is_tag() ) {
					  
					// If post is a custom post type
					$post_type = get_post_type();
					  
					// If it is a custom post type display name and link
					if($post_type != 'post') {
						  
						$post_type_object = get_post_type_object($post_type);
						$post_type_archive = get_post_type_archive_link($post_type);
					  
						echo '<li class="item-cat item-custom-post-type-' . esc_attr($post_type) . '"><a class="bread-cat bread-custom-post-type-' . esc_attr($post_type) . '" href="' . esc_url($post_type_archive) . '" title="' . esc_attr($post_type_object->labels->name) . '">' . esc_attr($post_type_object->labels->name) . '</a></li>';
					}
					  
					$industroz_tax_name = get_queried_object()->name;
					echo '<li class="item-current item-archive"><strong class="bread-current bread-archive">' . esc_attr($industroz_tax_name) . '</strong></li>';
					  
				} else if ( is_single() ) {
					  
					// If post is a custom post type
					$post_type = get_post_type();
					  
					// If it is a custom post type display name and link
					if($post_type != 'post') {
						  
						$post_type_object = get_post_type_object($post_type);
						$post_type_archive = get_post_type_archive_link($post_type);
					  
						echo '<li class="item-cat item-custom-post-type-' . esc_attr($post_type) . '"><a class="bread-cat bread-custom-post-type-' . esc_attr($post_type) . '" href="' . esc_url($post_type_archive) . '" title="' . esc_attr($post_type_object->labels->name) . '">' . esc_attr($post_type_object->labels->name) . '</a></li>';
					}
					  
					// Get post category info
					$category = get_the_category();
					 
					if(!empty($category)) {
					  
						// Get last category post is in
						$last_category = end($category);
						  
						// Get parent any categories and create array
						$get_cat_parents = rtrim(get_category_parents($last_category->term_id, true, ','),',');
						$cat_parents = explode(',',$get_cat_parents);
						  
						// Loop through parent categories and store in variable $cat_display
						$cat_display = '';
						foreach($cat_parents as $parents) {
							$cat_display .= '<li class="item-cat">'.$parents.'</li>';
						}
					 
					}
					
					// If you have any custom post types with custom taxonomies, put the taxonomy name below (e.g. product_cat)
					if($post_type == 'services'){
						$industroz_taxonomy    = 'services_category';
					}else if($post_type == 'projects'){
						$industroz_taxonomy    = 'projects_category';
					}else if($post_type == 'product'){
						$industroz_taxonomy    = 'services_category';
					}else if($post_type == 'team'){
						$industroz_taxonomy    = 'team_category';
					}else if($post_type == 'post'){
						$industroz_taxonomy    = 'category';
					}
					
					  
					// If it's a custom post type within a custom taxonomy
					$taxonomy_exists = taxonomy_exists($industroz_taxonomy);
					if(empty($last_category) && !empty($industroz_taxonomy) && $taxonomy_exists) {
						   
						$taxonomy_terms = get_the_terms( $post->ID, $industroz_taxonomy );
						$cat_id         = $taxonomy_terms[0]->term_id;
						$cat_nicename   = $taxonomy_terms[0]->slug;
						$cat_link       = get_term_link($taxonomy_terms[0]->term_id, $industroz_taxonomy);
						$cat_name       = $taxonomy_terms[0]->name;
					   
					}
					  
					// Check if the post is in a category
					if(!empty($last_category)) {
						echo wp_kses($cat_display,$industroz_allowed_html);
						echo '<li class="item-current item-' . esc_attr($post->ID) . '"><span class="bread-current bread-' . esc_attr($post->ID) . '" title="' . esc_attr(get_the_title()) . '">' . wp_kses(get_the_title(),$industroz_allowed_html) . '</span></li>';
						  
					// Else if post is in a custom taxonomy
					} else if(!empty($cat_id)) {
						  
						echo '<li class="item-cat item-cat-' . esc_attr($cat_id) . ' item-cat-' . esc_attr($cat_nicename) . '"><a class="bread-cat bread-cat-' . esc_attr($cat_id) . ' bread-cat-' . esc_attr($cat_nicename) . '" href="' . esc_url($cat_link) . '" title="' . esc_attr($cat_name) . '">' . esc_attr($cat_name) . '</a></li>';
						echo '<li class="item-current item-' . esc_attr($post->ID) . '"><span class="bread-current bread-' . esc_attr($post->ID) . '" title="' . esc_attr(get_the_title()) . '">' . esc_attr(get_the_title()) . '</span></li>';
					  
					} else {
						echo '<li class="item-current item-' . esc_attr($post->ID) . '"><span class="bread-current bread-' . esc_attr($post->ID) . '" title="' . esc_attr(get_the_title()) . '">' . wp_kses(get_the_title(),$industroz_allowed_html) . '</span></li>';
					}
					  
				} else if ( is_category() ) {
					   
					// Category page
					echo '<li class="item-current item-cat"><span class="bread-current bread-cat">' . single_cat_title('', false) . '</span></li>';
					   
				} else if ( is_page() ) {
					   
					// Standard page
					if( $post->post_parent ){
						   
						// If child page, get parents 
						$anc = get_post_ancestors( $post->ID );
						   
						// Get parents in the right order
						$anc = array_reverse($anc);
						   
						// Parent page loop
						if ( !isset( $parents ) ) $parents = null;
						foreach ( $anc as $ancestor ) {
							$parents .= '<li class="item-parent item-parent-' . esc_attr($ancestor) . '"><a class="bread-parent bread-parent-' . esc_attr($ancestor) . '" href="' . esc_url(get_permalink($ancestor)) . '" title="' . esc_attr(get_the_title($ancestor)) . '">' . esc_attr(get_the_title($ancestor)) . '</a></li>';
						}
						   
						// Display parent pages
						echo wp_kses($parents,$industroz_allowed_html);
						   
						// Current page
						echo '<li class="item-current item-' . esc_attr($post->ID) . '"><span title="' . esc_attr(get_the_title()) . '"> ' . wp_kses(get_the_title(),$industroz_allowed_html) . '</span></li>';
						   
					} else {
						   
						// Just display current page if not parents
						echo '<li class="item-current item-' . esc_attr($post->ID) . '"><span class="bread-current bread-' . esc_attr($post->ID) . '"> ' . wp_kses(get_the_title(),$industroz_allowed_html) . '</span></li>';
						   
					}
					   
				} else if ( is_tag() ) {
					   
					// Tag page
					   
					// Get tag information
					$term_id        = get_query_var('tag_id');
					$taxonomy       = 'post_tag';
					$args           = 'include=' . $term_id;
					$terms          = get_terms( $taxonomy, $args );
					$get_term_id    = $terms[0]->term_id;
					$get_term_slug  = $terms[0]->slug;
					$get_term_name  = $terms[0]->name;
					   
					// Display the tag name
					echo '<li class="item-current item-tag-' . esc_attr($get_term_id). ' item-tag-' . esc_attr($get_term_slug) . '"><strong class="bread-current bread-tag-' . esc_attr($get_term_id) . ' bread-tag-' . esc_attr($get_term_slug) . '">' . esc_attr($get_term_name) . '</strong></li>';
				   
				} elseif ( is_day() ) {
					   
					// Day archive
					   
					// Year link
					echo '<li class="item-year item-year-' . esc_attr(get_the_time('Y')) . '"><a class="bread-year bread-year-' . esc_attr(get_the_time('Y')) . '" href="' . esc_url(get_year_link( get_the_time('Y') )) . '" title="' . esc_attr(get_the_time('Y')) . '">' . esc_attr(get_the_time('Y')) . esc_attr__('Archives','industroz') . '</a></li>';
					 
					// Month link
					echo '<li class="item-month item-month-' . esc_attr(get_the_time('m')) . '"><a class="bread-month bread-month-' . esc_attr(get_the_time('m')) . '" href="' . get_month_link( get_the_time('Y'), get_the_time('m') ) . '" title="' . esc_attr(get_the_time('M')) . '">' . esc_attr(get_the_time('M')) . esc_attr__('Archives','industroz') . '</a></li>';
					 
					// Day display
					echo '<li class="item-current item-' . esc_attr(get_the_time('j')) . '"><strong class="bread-current bread-' . esc_attr(get_the_time('j')) . '"> ' . esc_attr(get_the_time('jS')) . ' ' . esc_attr(get_the_time('M'))  . esc_attr__('Archives','industroz'). '</strong></li>';
					   
				} else if ( is_month() ) {
					   
					// Month Archive
					   
					// Year link
					echo '<li class="item-year item-year-' . esc_attr(get_the_time('Y')) . '"><a class="bread-year bread-year-' . esc_attr(get_the_time('Y')) . '" href="' . esc_url(get_year_link( get_the_time('Y') )) . '" title="' . esc_attr(get_the_time('Y')) . '">' . esc_attr(get_the_time('Y')) . esc_attr__('Archives','industroz'). '</a></li>';
					  
					// Month display
					echo '<li class="item-month item-month-' . esc_attr(get_the_time('m')) . '"><strong class="bread-month bread-month-' . esc_attr(get_the_time('m')) . '" title="' . esc_attr(get_the_time('M')) . '">' . esc_attr(get_the_time('M')) . esc_attr__('Archives','industroz'). '</strong></li>';
					   
				} else if ( is_year() ) {
					   
					// Display year archive
					echo '<li class="item-current item-current-' . esc_attr(get_the_time('Y')) . '"><strong class="bread-current bread-current-' . esc_attr(get_the_time('Y')) . '" title="' . esc_attr(get_the_time('Y')) . '">' . esc_attr(get_the_time('Y')) . esc_attr__('Archives','industroz') .'</strong></li>';
					   
				} else if ( is_author() ) {
					   
					// Auhor archive
					   
					// Get the author information
					global $author;
					$userdata = get_userdata( $author );
					   
					// Display author name
					echo '<li class="item-current item-current-' . esc_attr($userdata->user_nicename) . '"><strong class="bread-current bread-current-' . esc_attr($userdata->user_nicename) . '" title="' . esc_attr($userdata->display_name) . '">' . esc_attr__('Author: ','industroz') . esc_attr($userdata->display_name) . '</strong></li>';
				   
				} else if ( get_query_var('paged') ) {
					   
					// Paginated archives
					echo '<li class="item-current item-current-' . get_query_var('paged') . '"><strong class="bread-current bread-current-' . get_query_var('paged') . '" title="Page ' . get_query_var('paged') . '">'.esc_attr__('Page','industroz') . ' ' . get_query_var('paged') . '</strong></li>';
					   
				} else if ( is_search() ) {
				   
					// Search results page
					echo '<li class="item-current item-current-' . get_search_query() . '"><strong class="bread-current bread-current-' . get_search_query() . '" title="Search results for: ' . get_search_query() . '">' . esc_attr__(' Search results for: ','industroz') . get_search_query() . '</strong></li>';
				   
				} elseif ( is_404() ) {
					   
					// 404 page
					echo '<li>' . esc_attr__('Error 404','industroz') . '</li>';
				}
				echo '</ul>';  
			}  
		}	
	}
	
	if(!function_exists('industroz_get_post_thumbnail')){
		function industroz_get_post_thumbnail($post_id,$post_format,$format_value,$thumbnail_size){
			
			$return = '';
			
			if($post_format == 'gallery'){
				$return .= '
				<div id="post-slider" class="owl-carousel owl-theme"> ';
					foreach($format_value as $gallery){
						$return .= '
							<div class="item">
								'.wp_get_attachment_image( $gallery['attachment_id'], $thumbnail_size).'
							</div>';	
					}
					$return .= '
				</div> ';
				
			}else if($post_format == 'youtube-video'){
				$return = '<div class="video-thumb"> <a data-rel="prettyPhoto[]" href="'.esc_attr($format_value).'"><i class="far fa-play-circle"></i></a>'.wp_get_attachment_image( get_post_thumbnail_id($post_id), $thumbnail_size).'</div>';
			}else if($post_format == 'vimeo-video'){
				$return = '<div class="video-thumb"> <a data-rel="prettyPhoto[]" href="'.esc_attr($format_value).'"><i class="far fa-play-circle"></i></a>'.wp_get_attachment_image( get_post_thumbnail_id($post_id), $thumbnail_size).'</div>';
			}else if($post_format == 'soundcloud-audio'){
				$return = $format_value;
			}else{
				$return = get_the_post_thumbnail($post_id,$thumbnail_size );
			}
			return $return;
		}
	}
	
	if( in_array('woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option('active_plugins' )))){
		
		/**
		 * Remove the breadcrumbs 
		 */
		add_action( 'init', 'industroz_remove_wc_actions' );
		if(!function_exists('industroz_remove_wc_actions')){
			function industroz_remove_wc_actions() {
				remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
				remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20, 0 );
				add_action( 'woocommerce_after_single_product', 'woocommerce_output_related_products', 20, 0 );
			}
		}
		
		
		/**
		 * Change number or products per row
		*/
		
		add_filter('loop_shop_columns', 'industroz_loop_columns');
		if (!function_exists('industroz_loop_columns')) {
			function industroz_loop_columns() {
				if(class_exists('ACF')) {
					$products_per_row = get_field('products_per_row','option');
					if(isset($products_per_row) && !empty($products_per_row)){
						$products_per_row = $products_per_row;
					}else{
						$products_per_row = '3';
					}
				} else {
					$products_per_row = '3';
				}
				return $products_per_row; // 3 products per row
			}
		}
		
		/**
		 * Change number of products that are displayed per page (shop page)
		 */
		add_filter( 'loop_shop_per_page', 'industroz_new_loop_shop_per_page', 20 );
		if (!function_exists('industroz_new_loop_shop_per_page')) {
			function industroz_new_loop_shop_per_page( $cols ) {
				// Return the number of products you wanna show per page.
				if(class_exists('ACF')) {
					$products_per_page = get_field('products_per_page','option');
					if(isset($products_per_page) && !empty($products_per_page)){
						$products_per_page = $products_per_page;
					}else{
						$products_per_page = '6';
					}
				} else {
					$products_per_page = '6';
				}
					
				return $products_per_page;
			}
		}
	}
	
	if(class_exists('ACF')) {
		//// ADD FAVICON //////
		function gridvalley_favicon() {
			$favicon = get_field('favicon','option');
			?>
			<link rel="shortcut icon" href="<?php echo esc_url($favicon); ?>" >
			<?php 
		}
		add_action('wp_head', 'gridvalley_favicon');
	}