<?php
/**
 * Register Scripts for this theme.
 *
 * @package WordPress
 * @subpackage Industroz
 * @since 1.0.0
 */

/**
 * Register and Enqueue Styles.
 */
function industroz_register_styles() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'industroz-fonts', industroz_fonts_url(), array(), null );
	$theme_version = wp_get_theme()->get( 'Version' );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css', null, $theme_version);
	wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/css/fontawesome/css/font-awesome.min.css', null, $theme_version);
	wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.min.css', null, $theme_version);
	wp_enqueue_style( 'bootstrap-select', get_template_directory_uri() . '/assets/css/bootstrap-select.min.css', null, $theme_version);
	wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.min.css', null, $theme_version);
	wp_enqueue_style( 'lc_lightbox', get_template_directory_uri() . '/assets/css/lc_lightbox.css', null, $theme_version);
	wp_enqueue_style( 'loader', get_template_directory_uri() . '/assets/css/loader.min.css', null, $theme_version);
	wp_enqueue_style( 'industroz-style', get_stylesheet_uri(), array(), $theme_version );
	wp_enqueue_style( 'flaticon', get_template_directory_uri() . '/assets/css/flaticon.min.css', null, $theme_version);
	wp_enqueue_style( 'industroz-wp-styling', get_template_directory_uri() . '/assets/css/wp-styling.css', null, $theme_version);
	wp_enqueue_style( 'industroz-responsive', get_template_directory_uri() . '/assets/css/responsive.css', null, $theme_version);
	wp_enqueue_style( 'industroz-skin-9', get_template_directory_uri() . '/assets/css/skin/skin-9.css', null, $theme_version);
	// Add print CSS.
	wp_enqueue_style( 'industroz-print-style', get_template_directory_uri() . '/assets/css/print.css', null, $theme_version, 'print' );
}

add_action( 'wp_enqueue_scripts', 'industroz_register_styles' );

/**
 * Register and Enqueue Scripts.
 */
function industroz_register_scripts() {

	$theme_version = wp_get_theme()->get( 'Version' );

	if ( ( ! is_admin() ) && is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_script( 'popper', get_template_directory_uri() . '/assets/js/popper.min.js', array('jquery'), $theme_version, true );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), $theme_version, true );
	wp_enqueue_script( 'bootstrap-select', get_template_directory_uri() . '/assets/js/bootstrap-select.min.js', array('jquery'), $theme_version, true );
	wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/js/magnific-popup.min.js', array('jquery'), $theme_version, true );
	wp_enqueue_script( 'lc_lightbox.lite', get_template_directory_uri() . '/assets/js/lc_lightbox.lite.js', array('jquery'), $theme_version, true );
	wp_enqueue_script( 'waypoints', get_template_directory_uri() . '/assets/js/waypoints.min.js', array('jquery'), $theme_version, true );
	if(in_array('elementor/elementor.php', apply_filters( 'active_plugins', get_option('active_plugins' )))){
		wp_enqueue_script( 'waypoints-sticky', get_template_directory_uri() . '/assets/js/waypoints-sticky.min.js', array('elementor-waypoints'), $theme_version, true );
	}else{
		wp_enqueue_script( 'waypoints-sticky', get_template_directory_uri() . '/assets/js/waypoints-sticky.min.js', array(), $theme_version, true );
	}
	
	wp_enqueue_script( 'counterup', get_template_directory_uri() . '/assets/js/counterup.min.js', array('jquery'), $theme_version, true );
	wp_enqueue_script( 'isotope', get_template_directory_uri() . '/assets/js/isotope.pkgd.min.js', array(), $theme_version, true );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.min.js', array(), $theme_version, true );
	wp_enqueue_script( 'stellar', get_template_directory_uri() . '/assets/js/stellar.min.js', array(), $theme_version, true );
	wp_enqueue_script( 'theia-sticky-sidebar', get_template_directory_uri() . '/assets/js/theia-sticky-sidebar.js', array(), $theme_version, true );
	wp_enqueue_script( 'bootstrap-touchspin', get_template_directory_uri() . '/assets/js/jquery.bootstrap-touchspin.js', array(), $theme_version, true );
	wp_enqueue_script( 'industroz-js', get_template_directory_uri() . '/assets/js/index.js', array(), $theme_version, true );
	wp_script_add_data( 'industroz-js', 'async', true );
	wp_enqueue_script('industroz-functions', get_template_directory_uri().'/assets/js/functions.js', array('jquery'), $theme_version, true);
	
	// Localize the script with new data
    $script_array = array(
        'ajaxurl' => admin_url('admin-ajax.php'),
        'security' => wp_create_nonce("subscribe_user"),
    );
    wp_localize_script( 'industroz-functions', 'aw', $script_array );
}

add_action( 'wp_enqueue_scripts', 'industroz_register_scripts');